/****************************************************************************
 *
 *  Rohde & Schwarz MOX Oscilloscope instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSMXO_HEADER
#define __RSMXO_HEADER

#include "rscore.h"
#include "rsmxo_attributes.h"
#include "rsmxo_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#ifndef UINT_MAX
#define UINT_MAX 4294967295
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/
#define RSMXO_SIMULATION_ID_QUERY      "Rohde&Schwarz,MXO,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSMXO_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSMXO_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSMXO_OPC_TIMEOUT              50000L   /* Maximum time to wait for OPC in milliseconds */

 /****************************************************************************
  *----------------- Instrument Driver Revision Information -----------------*
  ****************************************************************************/

      /* Class Driver Identification */

#define RSMXO_CLASS_DRIVER_DESCRIPTION           ""
#define RSMXO_CLASS_DRIVER_PREFIX                ""
#define RSMXO_CLASS_DRIVER_VENDOR                ""
#define RSMXO_CLASS_DRIVER_REVISION              ""
#define RSMXO_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSMXO_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSMXO_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSMXO_SPECIFIC_DRIVER_PREFIX             "RSMXO"
#define RSMXO_SPECIFIC_DRIVER_LOCATOR            ""
#define RSMXO_SPECIFIC_DRIVER_VENDOR             ""
#define RSMXO_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSMXO_MINOR_VERSION                      1L    /* Instrument driver minor version          */
#define RSMXO_MINOR_MINOR_VERSION                1L    /* Instrument driver minor minor version    */
/* Driver Capabilities */

#define RSMXO_SUPPORTED_INSTRUMENT_MODELS        "MXO" /* Instrument driver supported model(s)     */
#define RSMXO_GROUP_CAPABILITIES                 ""
#define RSMXO_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

 /*- Inherent Instrument Specific Attributes ----------------------------*/

     /* User Options */

#define RSMXO_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSMXO_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSMXO_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSMXO_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSMXO_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSMXO_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSMXO_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSMXO_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSMXO_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSMXO_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSMXO_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSMXO_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSMXO_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSMXO_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSMXO_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSMXO_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSMXO_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSMXO_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSMXO_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSMXO_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSMXO_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSMXO_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSMXO_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSMXO_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */

        /* Driver Setup */

#define RSMXO_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSMXO_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSMXO_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSMXO_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSMXO_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSMXO_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME

/* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSMXO_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSMXO_ATTR_VERTICAL_SHOW_CHANNEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSMXO_ATTR_VERTICAL_SCALE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 633
#define RSMXO_ATTR_VERTICAL_RANGE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1274
#define RSMXO_ATTR_VERTICAL_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 634
#define RSMXO_ATTR_VERTICAL_SKEW                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 635
#define RSMXO_ATTR_VERTICAL_POSITION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSMXO_ATTR_VERTICAL_COUPLING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSMXO_ATTR_VERTICAL_INVERT_CHANNEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSMXO_ATTR_VERTICAL_BANDWIDTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSMXO_ATTR_VERTICAL_EXTERNAL_ATTENUATION_SCALE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSMXO_ATTR_VERTICAL_EXTERNAL_ATTENUATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSMXO_ATTR_VERTICAL_POWER_CALCULATION_IMPEDANCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSMXO_ATTR_PROBE_STATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSMXO_ATTR_PROBE_NAME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define RSMXO_ATTR_PROBE_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define RSMXO_ATTR_PROBE_PREDEFINED_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1275
#define RSMXO_ATTR_PROBE_BANDWIDTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSMXO_ATTR_PROBE_VERTICAL_UNIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSMXO_ATTR_PROBE_AUTO_ATTENUATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSMXO_ATTR_PROBE_MANUAL_ATTENUATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSMXO_ATTR_PROBE_SET_OFFSET_TO_MEAN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSMXO_ATTR_PROBE_AUTO_ZERO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSMXO_ATTR_PROBE_USE_AUTO_ZERO                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSMXO_ATTR_PROBE_MICRO_BUTTON                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSMXO_ATTR_PROBE_IMPEDANCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1276
#define RSMXO_ATTR_PROBE_CAPACITANCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1277
#define RSMXO_ATTR_PROBE_PART_NUMBER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1278
#define RSMXO_ATTR_PROBE_PRODUCTION_DATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1279
#define RSMXO_ATTR_PROBE_SERIAL_NUMBER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1280
#define RSMXO_ATTR_PROBE_SOFTWARE_VERSION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1281
#define RSMXO_ATTR_PROBE_CM_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1282
#define RSMXO_ATTR_PROBE_RTZA15_ATTENUATOR_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1283
#define RSMXO_ATTR_PROBE_DISPLAY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1284
#define RSMXO_ATTR_PROBE_SOUND_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1285
#define RSMXO_ATTR_PROBE_BANDWIDTH_LIMIT_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1286
#define RSMXO_ATTR_PROBE_VOLTAGE_RANGE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1287
#define RSMXO_ATTR_PROBE_METER_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1288
#define RSMXO_ATTR_PROBE_METER_SET_TO_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1289
#define RSMXO_ATTR_PROBE_AC_COUPLING_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1290
#define RSMXO_ATTR_PROBE_MANUAL_GAIN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1291
#define RSMXO_ATTR_PROBE_PREDEFINED_GAIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1292
#define RSMXO_ATTR_PROBE_ZERO_ADJUST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1293
#define RSMXO_ATTR_PROBE_DEGAUSS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1294
#define RSMXO_ATTR_PROBE_SAVE_TO_PROBE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1295
#define RSMXO_ATTR_PROBE_DIFFERENTIAL_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1706
#define RSMXO_ATTR_PROBE_NEGATIVE_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1707
#define RSMXO_ATTR_PROBE_POSITIVE_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1708
#define RSMXO_ATTR_PROBE_MODULAR_MEASUREMENT_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1709
#define RSMXO_ATTR_PROBE_TERMINATION_VOLTAGE_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1710
#define RSMXO_ATTR_PROBE_TERMINATION_VOLTAGE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1711
#define RSMXO_ATTR_PROBE_TERMINATION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1712
#define RSMXO_ATTR_PROBE_RESULTS_SINGLE_ENDED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define RSMXO_ATTR_PROBE_RESULTS_COMMON                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSMXO_ATTR_PROBE_RESULTS_DIFFERENTIAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSMXO_ATTR_PROBE_RESULTS_POSITIVE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1296
#define RSMXO_ATTR_PROBE_RESULTS_NEGATIVE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1297
#define RSMXO_ATTR_PROBE_RESULTS_MODULAR_VOLTAGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1713
#define RSMXO_ATTR_HORIZONTAL_TIME_SCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 658
#define RSMXO_ATTR_HORIZONTAL_TIMEBASE_RANGE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSMXO_ATTR_HORIZONTAL_POSITION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 660
#define RSMXO_ATTR_HORIZONTAL_REFERENCE_POINT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define RSMXO_ATTR_HORIZONTAL_DIVISIONS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define RSMXO_ATTR_HORIZONTAL_ROLL_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1522
#define RSMXO_ATTR_HORIZONTAL_ROLL_ACQUISITION_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1523
#define RSMXO_ATTR_HORIZONTAL_ROLL_STATUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1524
#define RSMXO_ATTR_HORIZONTAL_REFERENCE_CLOCK_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define RSMXO_ATTR_HORIZONTAL_REFERENCE_CLOCK_OUTPUT_10_MHZ_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 665
#define RSMXO_ATTR_ZOOM_STATE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define RSMXO_ATTR_ZOOM_DIAGRAM                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define RSMXO_ATTR_ZOOM_COUNT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSMXO_ATTR_ZOOM_MODE_HORIZONTAL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 669
#define RSMXO_ATTR_ZOOM_X_ABSOLUTE_SPAN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define RSMXO_ATTR_ZOOM_X_ABSOLUTE_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define RSMXO_ATTR_ZOOM_X_ABSOLUTE_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define RSMXO_ATTR_ZOOM_X_ABSOLUTE_START                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 673
#define RSMXO_ATTR_ZOOM_X_ABSOLUTE_STOP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 674
#define RSMXO_ATTR_ZOOM_X_RELATIVE_SPAN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 675
#define RSMXO_ATTR_ZOOM_X_RELATIVE_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 676
#define RSMXO_ATTR_ZOOM_X_RELATIVE_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 677
#define RSMXO_ATTR_ZOOM_X_RELATIVE_START                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 678
#define RSMXO_ATTR_ZOOM_X_RELATIVE_STOP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 679
#define RSMXO_ATTR_ZOOM_MODE_VERTICAL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 680
#define RSMXO_ATTR_ZOOM_Y_ABSOLUTE_SPAN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 681
#define RSMXO_ATTR_ZOOM_Y_ABSOLUTE_RANGE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 682
#define RSMXO_ATTR_ZOOM_Y_ABSOLUTE_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 683
#define RSMXO_ATTR_ZOOM_Y_ABSOLUTE_START                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define RSMXO_ATTR_ZOOM_Y_ABSOLUTE_STOP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 685
#define RSMXO_ATTR_ZOOM_Y_RELATIVE_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 686
#define RSMXO_ATTR_ZOOM_Y_RELATIVE_SPAN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 687
#define RSMXO_ATTR_ZOOM_Y_RELATIVE_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define RSMXO_ATTR_ZOOM_Y_RELATIVE_START                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define RSMXO_ATTR_ZOOM_Y_RELATIVE_STOP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSMXO_ATTR_ZOOM_SET_TO_SCREEN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1714
#define RSMXO_ATTR_TRIGGER_ON                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define RSMXO_ATTR_TRIGGER_FORCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define RSMXO_ATTR_TRIGGER_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define RSMXO_ATTR_TRIGGER_SEQUENCE_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1298
#define RSMXO_ATTR_TRIGGER_SEQUENCE_DELAY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1299
#define RSMXO_ATTR_TRIGGER_SEQUENCE_B_EVENT_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1300
#define RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_EVENT_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1301
#define RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_TIME_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1302
#define RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_TIMEOUT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1303
#define RSMXO_ATTR_TRIGGER_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define RSMXO_ATTR_TRIGGER_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define RSMXO_ATTR_TRIGGER_FIND_LEVEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define RSMXO_ATTR_TRIGGER_EVENT_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 697
#define RSMXO_ATTR_TRIGGER_EDGE_SLOPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 698
#define RSMXO_ATTR_TRIGGER_GLITCH_POLARITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define RSMXO_ATTR_TRIGGER_GLITCH_RANGE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define RSMXO_ATTR_TRIGGER_GLITCH_WIDTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define RSMXO_ATTR_TRIGGER_WIDTH_POLARITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 702
#define RSMXO_ATTR_TRIGGER_WIDTH_RANGE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 703
#define RSMXO_ATTR_TRIGGER_WIDTH_WIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 704
#define RSMXO_ATTR_TRIGGER_WIDTH_DELTA                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 705
#define RSMXO_ATTR_TRIGGER_RUNT_POLARITY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define RSMXO_ATTR_TRIGGER_RUNT_RANGE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define RSMXO_ATTR_TRIGGER_RUNT_WIDTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define RSMXO_ATTR_TRIGGER_RUNT_DELTA                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define RSMXO_ATTR_TRIGGER_RUNT_LOWER_LIMIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 710
#define RSMXO_ATTR_TRIGGER_RUNT_UPPER_LIMIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 711
#define RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define RSMXO_ATTR_TRIGGER_WINDOW_TIME_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define RSMXO_ATTR_TRIGGER_WINDOW_WIDTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define RSMXO_ATTR_TRIGGER_WINDOW_DELTA                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define RSMXO_ATTR_TRIGGER_WINDOW_LOWER_LIMIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define RSMXO_ATTR_TRIGGER_WINDOW_UPPER_LIMIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define RSMXO_ATTR_TRIGGER_TIMEOUT_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define RSMXO_ATTR_TRIGGER_TIMEOUT_RANGE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 719
#define RSMXO_ATTR_TRIGGER_INTERVAL_SLOPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define RSMXO_ATTR_TRIGGER_INTERVAL_RANGE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define RSMXO_ATTR_TRIGGER_INTERVAL_DELTA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define RSMXO_ATTR_TRIGGER_SLEW_RATE_SLOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define RSMXO_ATTR_TRIGGER_SLEW_RATE_RANGE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define RSMXO_ATTR_TRIGGER_SLEW_RATE_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 726
#define RSMXO_ATTR_TRIGGER_SLEW_RATE_DELTA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define RSMXO_ATTR_TRIGGER_SLEW_RATE_LOWER_LIMIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define RSMXO_ATTR_TRIGGER_SLEW_RATE_UPPER_LIMIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_EDGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 730
#define RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_CLOCK_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 731
#define RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_CLOCK_SOURCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 732
#define RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_HOLD_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 733
#define RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_SETUPTIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 734
#define RSMXO_ATTR_TRIGGER_STATE_SLOPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1304
#define RSMXO_ATTR_TRIGGER_STATE_OPERATOR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1305
#define RSMXO_ATTR_TRIGGER_STATE_DIGITAL_STATE_OPERATOR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1704
#define RSMXO_ATTR_TRIGGER_STATE_DIGITAL_CHANNEL_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1606
#define RSMXO_ATTR_TRIGGER_STATE_CHANNEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1306
#define RSMXO_ATTR_TRIGGER_PATTERN_OPERATOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1307
#define RSMXO_ATTR_TRIGGER_PATTERN_STATE_SOURCES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1607
#define RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_STATE_OPERATOR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1608
#define RSMXO_ATTR_TRIGGER_PATTERN_CHANNEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1308
#define RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_CHANNEL_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1609
#define RSMXO_ATTR_TRIGGER_EDGE_COUPLING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 735
#define RSMXO_ATTR_TRIGGER_EDGE_LEVEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1309
#define RSMXO_ATTR_TRIGGER_EDGE_FILTER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 736
#define RSMXO_ATTR_TRIGGER_EDGE_LOW_PASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 737
#define RSMXO_ATTR_TRIGGER_EDGE_HIGH_PASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 738
#define RSMXO_ATTR_TRIGGER_EDGE_NOISE_REJECT_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 740
#define RSMXO_ATTR_TRIGGER_HOLDOFF_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 741
#define RSMXO_ATTR_TRIGGER_HOLDOFF_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define RSMXO_ATTR_TRIGGER_HOLDOFF_EVENTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 743
#define RSMXO_ATTR_TRIGGER_HOLDOFF_MINIMUM_TIME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 744
#define RSMXO_ATTR_TRIGGER_HOLDOFF_MAXIMUM_TIME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 745
#define RSMXO_ATTR_TRIGGER_HOLDOFF_AUTO_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 746
#define RSMXO_ATTR_TRIGGER_HOLDOFF_AUTO_TIME_SCALING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 747
#define RSMXO_ATTR_TRIGGER_HYSTERESIS_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 748
#define RSMXO_ATTR_TRIGGER_HW_HYSTERESIS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 749
#define RSMXO_ATTR_TRIGGER_HYSTERESIS_SIZE_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 750
#define RSMXO_ATTR_TRIGGER_HYSTERESIS_ABSOLUTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 751
#define RSMXO_ATTR_TRIGGER_HYSTERESIS_RELATIVE_PERCENTAGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define RSMXO_ATTR_TRIGGER_HYSTERESIS_RELATIVE_DIVS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 753
#define RSMXO_ATTR_TRIGGER_FILTER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 754
#define RSMXO_ATTR_TRIGGER_FILTER_LF_REJECT_BW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 755
#define RSMXO_ATTR_TRIGGER_FILTER_RF_REJECT_BW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 756
#define RSMXO_ATTR_TRIGGER_ACTION_TRIGGER_OUT_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 757
#define RSMXO_ATTR_TRIGGER_ACTION_POLARITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 758
#define RSMXO_ATTR_TRIGGER_ACTION_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 759
#define RSMXO_ATTR_TRIGGER_ACTION_PULSE_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define RSMXO_ATTR_TRIGGER_ACTION_SIGNAL_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1715
#define RSMXO_ATTR_ACQUISITION_RUN_CONTINUOUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define RSMXO_ATTR_ACQUISITION_STOP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define RSMXO_ATTR_ACQUISITION_RUN_SINGLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 763
#define RSMXO_ATTR_ACQUISITION_RUN_SINGLE_NO_WAIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1521
#define RSMXO_ATTR_ACQUISITION_AUTOSCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 764
#define RSMXO_ATTR_ACQUISITION_SAMPLE_RATE_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 765
#define RSMXO_ATTR_ACQUISITION_SAMPLE_RATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 766
#define RSMXO_ATTR_ACQUISITION_MINIMUM_SAMPLE_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 767
#define RSMXO_ATTR_ACQUISITION_RECORD_LENGTH_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 768
#define RSMXO_ATTR_ACQUISITION_RECORD_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 769
#define RSMXO_ATTR_ACQUISITION_RECORD_LENGTH_LIMIT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 770
#define RSMXO_ATTR_ACQUISITION_N_SINGLE_AVERAGE_COUNT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 771
#define RSMXO_ATTR_ACQUISITION_RESOLUTION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 772
#define RSMXO_ATTR_ACQUISITION_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 773
#define RSMXO_ATTR_ACQUISITION_INTERPOLATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 774
#define RSMXO_ATTR_ACQUISITION_AVAILABLE_ACQUISITIONS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 775
#define RSMXO_ATTR_ACQUISITION_ADC_RATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 776
#define RSMXO_ATTR_ACQUISITION_REAL_SAMPLE_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 777
#define RSMXO_ATTR_ACQUISITION_CURRENT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1310
#define RSMXO_ATTR_ACQUISITION_AVERAGE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1311
#define RSMXO_ATTR_ACQUISITION_ROLL_MODE_OFF_SCREEN_CAPTURE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1525
#define RSMXO_ATTR_ACQUISITION_ROLL_MODE_POINTS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1526
#define RSMXO_ATTR_ACQUISITION_SEGMENTED_FAST_SEGMENTATION_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 778
#define RSMXO_ATTR_ACQUISITION_SEGMENTED_ACQUIRE_MAXIMUM_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 779
#define RSMXO_ATTR_ACQUISITION_HIGH_DEFINITION_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 780
#define RSMXO_ATTR_ACQUISITION_HIGH_DEFINITION_BANDWIDTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 781
#define RSMXO_ATTR_ACQUISITION_HIGH_DEFINITION_RESOLUTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 782
#define RSMXO_ATTR_ACQUISITION_SHOW_HISTORY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 783
#define RSMXO_ATTR_ACQUISITION_HISTORY_REPLAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 784
#define RSMXO_ATTR_ACQUISITION_HISTORY_PLAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 785
#define RSMXO_ATTR_ACQUISITION_HISTORY_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 786
#define RSMXO_ATTR_ACQUISITION_HISTORY_STOP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 787
#define RSMXO_ATTR_ACQUISITION_HISTORY_DISPLAY_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 788
#define RSMXO_ATTR_ACQUISITION_HISTORY_SELECT_CURRENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 789
#define RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_ABSOLUTE_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 790
#define RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_ABSOLUTE_DATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 791
#define RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_RELATIVE_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 792
#define RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_REFERENCE_RELATIVE_TIME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 793
#define RSMXO_ATTR_MEASUREMENT_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 794
#define RSMXO_ATTR_MEASUREMENT_COUNT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1312
#define RSMXO_ATTR_MEASUREMENT_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 795
#define RSMXO_ATTR_MEASUREMENT_SOURCE_1                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1313
#define RSMXO_ATTR_MEASUREMENT_SOURCE_2                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1314
#define RSMXO_ATTR_MEASUREMENT_GATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1315
#define RSMXO_ATTR_MEASUREMENT_ENVELOPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1316
#define RSMXO_ATTR_MEASUREMENT_STATISTICS_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 797
#define RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1318
#define RSMXO_ATTR_MEASUREMENT_STATISTICS_MAXIMUM_EVENTS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1319
#define RSMXO_ATTR_MEASUREMENT_STATISTICS_CLEAR_RESULTS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 798
#define RSMXO_ATTR_MEASUREMENT_FIT_TO_SCREEN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1527
#define RSMXO_ATTR_MEASUREMENT_AUTOSCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1528
#define RSMXO_ATTR_MEASUREMENT_TRACK_WAVEFORM_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1529
#define RSMXO_ATTR_MEASUREMENT_TRACK_SCALE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1530
#define RSMXO_ATTR_MEASUREMENT_TRACK_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1531
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_CLOCK_SLOPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 799
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_PULSE_SLOPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 800
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_PULSE_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 801
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_EDGES_SLOPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1320
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_DIRECTION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 803
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_SLOPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 802
#define RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_TO_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1321
#define RSMXO_ATTR_REFERENCE_LEVEL_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1716
#define RSMXO_ATTR_REFERENCE_LEVEL_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 804
#define RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_LOWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 805
#define RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_MIDDLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 806
#define RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_UPPER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 807
#define RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_HYSTERESIS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 808
#define RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 809
#define RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_LOWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 810
#define RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MIDDLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 811
#define RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_UPPER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 812
#define RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_HYSTERESIS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 813
#define RSMXO_ATTR_REFERENCE_LEVEL_SET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1717
#define RSMXO_ATTR_RESULTS_START                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 814
#define RSMXO_ATTR_RESULTS_STOP                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 815
#define RSMXO_ATTR_RESULTS_COUNT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 816
#define RSMXO_ATTR_RESULTS_EVENT_COUNT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1322
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_CURRENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 822
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 823
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 824
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_MEAN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 825
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_RMS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 826
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_STANDARD_DEVIATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 827
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_EVENT_COUNT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 828
#define RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_WAVE_COUNT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 829
#define RSMXO_ATTR_GATE_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1326
#define RSMXO_ATTR_GATE_DISPLAY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1327
#define RSMXO_ATTR_GATE_COUPLING_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1328
#define RSMXO_ATTR_GATE_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1329
#define RSMXO_ATTR_GATE_ABSOLUTE_START                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1330
#define RSMXO_ATTR_GATE_ABSOLUTE_STOP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1331
#define RSMXO_ATTR_GATE_RELATIVE_START                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1332
#define RSMXO_ATTR_GATE_RELATIVE_STOP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1333
#define RSMXO_ATTR_GATE_CURSOR                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1334
#define RSMXO_ATTR_CURSOR_SHOW                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 831
#define RSMXO_ATTR_CURSOR_DISABLE_ALL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1336
#define RSMXO_ATTR_CURSOR_STYLE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 832
#define RSMXO_ATTR_CURSOR_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 833
#define RSMXO_ATTR_CURSOR_COUNT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1337
#define RSMXO_ATTR_CURSOR_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 834
#define RSMXO_ATTR_CURSOR_SOURCE_2_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 835
#define RSMXO_ATTR_CURSOR_SOURCE_2                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 836
#define RSMXO_ATTR_CURSOR_X1_POSITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 837
#define RSMXO_ATTR_CURSOR_X2_POSITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 838
#define RSMXO_ATTR_CURSOR_Y1_POSITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 839
#define RSMXO_ATTR_CURSOR_Y2_POSITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 840
#define RSMXO_ATTR_CURSOR_ENVELOPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1338
#define RSMXO_ATTR_CURSOR_ENVELOPE_2                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1339
#define RSMXO_ATTR_CURSOR_TRACK_WAVEFORM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 841
#define RSMXO_ATTR_CURSOR_SHOW_VALUES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1718
#define RSMXO_ATTR_CURSOR_RESET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1719
#define RSMXO_ATTR_CURSOR_ADVANCED_X_COUPLING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 842
#define RSMXO_ATTR_CURSOR_ADVANCED_Y_COUPLING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 843
#define RSMXO_ATTR_CURSOR_ADVANCED_SHOW_IN_ALL_DIAGRAMS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 844
#define RSMXO_ATTR_CURSOR_ADVANCED_SHOW_LABEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 846
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_CENTER_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 847
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_ABSOLUTE_PEAK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 848
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 849
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT_PEAK_LEFT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 850
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT_PEAK_RIGHT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 851
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_SET_CENTER_TO_CURSOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 852
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1340
#define RSMXO_ATTR_CURSOR_PEAK_SEARCH_EXCURSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1341
#define RSMXO_ATTR_CURSOR_RESULTS_DELTA_X                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 853
#define RSMXO_ATTR_CURSOR_RESULTS_DELTA_X_INVERSE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 854
#define RSMXO_ATTR_CURSOR_RESULTS_DELTA_Y                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 855
#define RSMXO_ATTR_CURSOR_RESULTS_DELTA_Y_INVERSE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 856
#define RSMXO_ATTR_CURSOR_HORIZONTAL_LABEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1720
#define RSMXO_ATTR_CURSOR_VERTICAL_LABEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1721
#define RSMXO_ATTR_SPECTRUM_DISPLAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 857
#define RSMXO_ATTR_SPECTRUM_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 858
#define RSMXO_ATTR_SPECTRUM_CENTER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 859
#define RSMXO_ATTR_SPECTRUM_SPAN                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 860
#define RSMXO_ATTR_SPECTRUM_START                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 861
#define RSMXO_ATTR_SPECTRUM_STOP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 862
#define RSMXO_ATTR_SPECTRUM_AUTO_RBW                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 863
#define RSMXO_ATTR_SPECTRUM_RBW                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 864
#define RSMXO_ATTR_SPECTRUM_SPAN_RBW_RATIO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 865
#define RSMXO_ATTR_SPECTRUM_TRACES_NORMAL_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 866
#define RSMXO_ATTR_SPECTRUM_TRACES_MIN_HOLD_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 867
#define RSMXO_ATTR_SPECTRUM_TRACES_MAX_HOLD_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 868
#define RSMXO_ATTR_SPECTRUM_TRACES_AVERAGE_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 869
#define RSMXO_ATTR_SPECTRUM_TRACES_AVERAGE_COUNT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 870
#define RSMXO_ATTR_SPECTRUM_PRESET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 871
#define RSMXO_ATTR_SPECTRUM_WINDOW_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 872
#define RSMXO_ATTR_SPECTRUM_GATE_START                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1342
#define RSMXO_ATTR_SPECTRUM_GATE_STOP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1343
#define RSMXO_ATTR_SPECTRUM_GATE_POSITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1344
#define RSMXO_ATTR_SPECTRUM_GATE_WIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1345
#define RSMXO_ATTR_SPECTRUM_SCALE_VERTICAL_RANGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 873
#define RSMXO_ATTR_SPECTRUM_SCALE_MAGNITUDE_UNIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 874
#define RSMXO_ATTR_SPECTRUM_SCALE_VERTICAL_MAXIMUM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 875
#define RSMXO_ATTR_SPECTRUM_SCALE_VERTICAL_SCALE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 876
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_SHOW_TABLE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 882
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_FRAME_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 883
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 884
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_PEAK_EXCURSION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 885
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_MAX_RESULTS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 886
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_LABEL_MAX_RESULTS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 887
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_RESULT_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 888
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_SHOW_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 889
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 890
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1532
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_LABELS_INVERT_COLORS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1533
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_LABELS_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1534
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_CURRENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1535
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_SORT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1536
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_SORT_ORDER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1537
#define RSMXO_ATTR_SPECTRUM_PEAK_LIST_DISPLAY_PEAKS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1538
#define RSMXO_ATTR_MATH_DISPLAY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 891
#define RSMXO_ATTR_MATH_EXPRESSION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 892
#define RSMXO_ATTR_MATH_SIGNAL_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1346
#define RSMXO_ATTR_MATH_VERTICAL_SCALE_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1347
#define RSMXO_ATTR_MATH_VERTICAL_SCALE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 893
#define RSMXO_ATTR_MATH_VERTICAL_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 894
#define RSMXO_ATTR_MATH_ENVELOPE_WAVEFORM_SELECTION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1348
#define RSMXO_ATTR_MATH_LABEL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1722
#define RSMXO_ATTR_MATH_USER_UNIT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1723
#define RSMXO_ATTR_PROTOCOL_SERIAL_BUS_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 895
#define RSMXO_ATTR_PROTOCOL_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 896
#define RSMXO_ATTR_PROTOCOL_SHOW_DECODE_TABLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 897
#define RSMXO_ATTR_PROTOCOL_DATA_FORMAT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 898
#define RSMXO_ATTR_PROTOCOL_ZOOM_COUPLING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 899
#define RSMXO_ATTR_PROTOCOL_SHOW_THRESHOLD_LINES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 900
#define RSMXO_ATTR_PROTOCOL_SET_REFERENCE_LEVELS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 902
#define RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 903
#define RSMXO_ATTR_PROTOCOL_I2C_FRAME_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 904
#define RSMXO_ATTR_PROTOCOL_I2C_SDA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 905
#define RSMXO_ATTR_PROTOCOL_I2C_SDA_THRESHOLD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 906
#define RSMXO_ATTR_PROTOCOL_I2C_SDA_HYSTERESIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 907
#define RSMXO_ATTR_PROTOCOL_I2C_SDA_POSITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1724
#define RSMXO_ATTR_PROTOCOL_I2C_SDA_VERTICAL_SCALE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1725
#define RSMXO_ATTR_PROTOCOL_I2C_SCL_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 908
#define RSMXO_ATTR_PROTOCOL_I2C_SCL_THRESHOLD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 909
#define RSMXO_ATTR_PROTOCOL_I2C_SCL_HYSTERESIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 910
#define RSMXO_ATTR_PROTOCOL_I2C_SHOW_SYMBOLS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1610
#define RSMXO_ATTR_PROTOCOL_I2C_SYMBOL_LIST_FILE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1611
#define RSMXO_ATTR_PROTOCOL_I2C_POSITION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1726
#define RSMXO_ATTR_PROTOCOL_I2C_SCALE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1727
#define RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FIELD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 912
#define RSMXO_ATTR_PROTOCOL_I2C_SELECTED_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 913
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 914
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_FRAME_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 915
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_FIELD_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 916
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_FRAME_CHECK_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1728
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_FRAME_CLEAR_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1729
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_INVERTS_CURRENT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1730
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_INDEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 917
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_START_INDEX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 918
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_END_INDEX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 919
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_DATA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 920
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_START_DATA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 921
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_END_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 922
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_ERROR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 923
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 924
#define RSMXO_ATTR_PROTOCOL_I2C_FILTER_RESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1731
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 925
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_NACK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 926
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_WRITE_NACK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 927
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_READ_NACK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 928
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 929
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 930
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_R_W_BIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 931
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 932
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 933
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 934
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 935
#define RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 938
#define RSMXO_ATTR_PROTOCOL_I2C_SELECTED_BYTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 940
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 941
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_FRAME_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 942
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_FRAME_END                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 943
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_SYMBOL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 944
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 945
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_START                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 946
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 947
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_ACK_BIT_START                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 948
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_ACK_BIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 949
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_COMPLETE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 950
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_DEVICE_ADDRESS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 951
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 952
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 953
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BIT_RATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 954
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 955
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 956
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 957
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_COMPLETE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 958
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_ACK_BIT_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 959
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_ACK_BIT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 960
#define RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_DATA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 961
#define RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 962
#define RSMXO_ATTR_PROTOCOL_SPI_FRAME_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 963
#define RSMXO_ATTR_PROTOCOL_SPI_MOSI_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 964
#define RSMXO_ATTR_PROTOCOL_SPI_MOSI_POLARITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 965
#define RSMXO_ATTR_PROTOCOL_SPI_MOSI_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 966
#define RSMXO_ATTR_PROTOCOL_SPI_MOSI_HYSTERESIS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 967
#define RSMXO_ATTR_PROTOCOL_SPI_MOSI_POSITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1732
#define RSMXO_ATTR_PROTOCOL_SPI_MOSI_SCALE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1733
#define RSMXO_ATTR_PROTOCOL_SPI_MISO_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 968
#define RSMXO_ATTR_PROTOCOL_SPI_MISO_POLARITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 969
#define RSMXO_ATTR_PROTOCOL_SPI_MISO_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 970
#define RSMXO_ATTR_PROTOCOL_SPI_MISO_HYSTERESIS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2067
#define RSMXO_ATTR_PROTOCOL_SPI_MISO_POSITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1734
#define RSMXO_ATTR_PROTOCOL_SPI_MISO_SCALE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 971
#define RSMXO_ATTR_PROTOCOL_SPI_SCLK_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 972
#define RSMXO_ATTR_PROTOCOL_SPI_SCLK_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 973
#define RSMXO_ATTR_PROTOCOL_SPI_SCLK_HYSTERESIS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 974
#define RSMXO_ATTR_PROTOCOL_SPI_CS_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 975
#define RSMXO_ATTR_PROTOCOL_SPI_CS_POLARITY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 976
#define RSMXO_ATTR_PROTOCOL_SPI_CS_THRESHOLD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 977
#define RSMXO_ATTR_PROTOCOL_SPI_CS_HYSTERESIS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 978
#define RSMXO_ATTR_PROTOCOL_SPI_BIT_ORDER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 979
#define RSMXO_ATTR_PROTOCOL_SPI_WORD_LENGTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 980
#define RSMXO_ATTR_PROTOCOL_SPI_FRAME_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 981
#define RSMXO_ATTR_PROTOCOL_SPI_TIMEOUT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 982
#define RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FIELD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 983
#define RSMXO_ATTR_PROTOCOL_SPI_SELECTED_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 984
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 985
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_FRAME_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 986
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_FRAME_CHECK_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1735
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_FRAME_CLEAR_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1736
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_INVERTS_CURRENT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1737
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_FIELD_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 987
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_INDEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 988
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_START_INDEX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 989
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_END_INDEX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 990
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_DATA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 991
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_START_DATA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 992
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_END_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 993
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 994
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_ERROR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 995
#define RSMXO_ATTR_PROTOCOL_SPI_FILTER_RESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1738
#define RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 996
#define RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_SEARCH_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 997
#define RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 998
#define RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_DATA_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 999
#define RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_DATA_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1002
#define RSMXO_ATTR_PROTOCOL_SPI_SELECTED_WORD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1005
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1006
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FRAME_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1007
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FRAME_END                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1008
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_WORD_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1009
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_WORD_END                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1010
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1011
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_MOSI_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1012
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_MISO_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1013
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FORMATED_MOSI                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1014
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FORMATED_MISO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1015
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_BIT_RATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1016
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1017
#define RSMXO_ATTR_PROTOCOL_SPI_RESULTS_DATA_WORD_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1018
#define RSMXO_ATTR_PROTOCOL_UART_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1019
#define RSMXO_ATTR_PROTOCOL_UART_POLARITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1020
#define RSMXO_ATTR_PROTOCOL_UART_RX_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1021
#define RSMXO_ATTR_PROTOCOL_UART_RX_THRESHOLD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1022
#define RSMXO_ATTR_PROTOCOL_UART_RX_HYSTERESIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1023
#define RSMXO_ATTR_PROTOCOL_UART_RX_POSITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1739
#define RSMXO_ATTR_PROTOCOL_UART_RX_SCALE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1740
#define RSMXO_ATTR_PROTOCOL_UART_TX_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1024
#define RSMXO_ATTR_PROTOCOL_UART_TX_THRESHOLD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1025
#define RSMXO_ATTR_PROTOCOL_UART_TX_HYSTERESIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1026
#define RSMXO_ATTR_PROTOCOL_UART_TX_POSITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1741
#define RSMXO_ATTR_PROTOCOL_UART_TX_SCALE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1742
#define RSMXO_ATTR_PROTOCOL_UART_BIT_ORDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1612
#define RSMXO_ATTR_PROTOCOL_UART_BIT_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1027
#define RSMXO_ATTR_PROTOCOL_UART_DATA_BITS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1028
#define RSMXO_ATTR_PROTOCOL_UART_PARITY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1029
#define RSMXO_ATTR_PROTOCOL_UART_STOP_BITS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1030
#define RSMXO_ATTR_PROTOCOL_UART_TIMEOUT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1031
#define RSMXO_ATTR_PROTOCOL_UART_PACKETS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1032
#define RSMXO_ATTR_PROTOCOL_UART_END_WORD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1033
#define RSMXO_ATTR_PROTOCOL_UART_SELECTED_FIELD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1034
#define RSMXO_ATTR_PROTOCOL_UART_SELECTED_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1035
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_FRAME_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1037
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_FRAME_CHECK_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1743
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_FRAME_CLEAR_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1744
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_INVERTS_CURRENT_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1745
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_FIELD_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1038
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1039
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_START_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1040
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_END_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1041
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1042
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_START_DATA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1043
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_END_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1044
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1045
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_ERROR_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1046
#define RSMXO_ATTR_PROTOCOL_UART_FILTER_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1746
#define RSMXO_ATTR_PROTOCOL_UART_TRIGGER_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1047
#define RSMXO_ATTR_PROTOCOL_UART_TRIGGER_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1048
#define RSMXO_ATTR_PROTOCOL_UART_TRIGGER_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1049
#define RSMXO_ATTR_PROTOCOL_UART_TRIGGER_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1050
#define RSMXO_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1051
#define RSMXO_ATTR_PROTOCOL_UART_TRIGGER_OPERATOR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1053
#define RSMXO_ATTR_PROTOCOL_UART_SELECTED_WORD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1055
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_WORD_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1056
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1057
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_START                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1058
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_STOP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1613
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_TX_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1059
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_RX_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1060
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_DATA_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1061
#define RSMXO_ATTR_PROTOCOL_UART_RESULTS_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1062
#define RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1349
#define RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1539
#define RSMXO_ATTR_PROTOCOL_CAN_SELECTED_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1699
#define RSMXO_ATTR_PROTOCOL_CAN_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1350
#define RSMXO_ATTR_PROTOCOL_CAN_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1351
#define RSMXO_ATTR_PROTOCOL_CAN_TRANSCEIVER_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1614
#define RSMXO_ATTR_PROTOCOL_CAN_SIC_THRESHOLD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1615
#define RSMXO_ATTR_PROTOCOL_CAN_FAST_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1616
#define RSMXO_ATTR_PROTOCOL_CAN_SIC_HYSTERESIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1617
#define RSMXO_ATTR_PROTOCOL_CAN_FAST_HYSTERESIS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1618
#define RSMXO_ATTR_PROTOCOL_CAN_NOMINAL_BIT_RATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1354
#define RSMXO_ATTR_PROTOCOL_CAN_SAMPLE_POINT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1619
#define RSMXO_ATTR_PROTOCOL_CAN_FD_BIT_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1355
#define RSMXO_ATTR_PROTOCOL_CAN_FD_SAMPLE_POINT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1356
#define RSMXO_ATTR_PROTOCOL_CAN_DECODED_FRAMES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1540
#define RSMXO_ATTR_PROTOCOL_CAN_XL_BITRATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1541
#define RSMXO_ATTR_PROTOCOL_CAN_XL_SAMPLE_POINT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1542
#define RSMXO_ATTR_PROTOCOL_CAN_SHOW_SYMBOLS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1620
#define RSMXO_ATTR_PROTOCOL_CAN_SYMBOL_LIST_FILE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1621
#define RSMXO_ATTR_PROTOCOL_CAN_POSITION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1747
#define RSMXO_ATTR_PROTOCOL_CAN_SCALE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1748
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1622
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1623
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_FIELD_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1624
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_CHECK_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1749
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_CLEAR_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1750
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_INVERTS_CURRENT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1751
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_ERROR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1625
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_OPERATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1626
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_DATA_OPERATOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1627
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_START_DATA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1628
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_END_DATA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1629
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_INDEX_OPERATOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1630
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_START_INDEX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1631
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_END_INDEX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1632
#define RSMXO_ATTR_PROTOCOL_CAN_FILTER_RESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1752
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1357
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1358
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1359
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1360
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_MINIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1361
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_MAXIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1362
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1363
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_MINIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1364
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1365
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_CHECKSUM_ERROR_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1366
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_FORM_ERROR_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1367
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_BIT_STUFFING_ERROR_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1368
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_ACK_ERROR_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1369
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_STUFF_COUNT_ERROR_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1370
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_BRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1372
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_ESI                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1373
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DLC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1376
#define RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DLC_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1377
#define RSMXO_ATTR_PROTOCOL_CAN_XL_TRIGGER_SEC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1543
#define RSMXO_ATTR_PROTOCOL_CAN_XL_AF_TRIGGER_CONDITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1544
#define RSMXO_ATTR_PROTOCOL_CAN_XL_SDT_TRIGGER_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1549
#define RSMXO_ATTR_PROTOCOL_CAN_XL_VCID_TRIGGER_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1554
#define RSMXO_ATTR_PROTOCOL_CAN_SELECTED_BYTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1378
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1379
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1380
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1381
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1382
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_SYMBOL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1633
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1383
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1384
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1385
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1386
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1387
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BYTE_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1388
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BYTE_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1389
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_CRC_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1390
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_CRC_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1391
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DLC_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1392
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DLC_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1393
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BIT_STUFFING_ERROR_POSITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1394
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FORM_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1395
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA_BYTES_NUMBER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1396
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1397
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_PATTERN_DATA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1398
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_SYMBOLIC_DATA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1399
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_SYMBOLIC_DATA_EXPORT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1400
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_STUFF_COUNT_FIELD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1402
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FIELD_BRS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1559
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FIELD_ESI                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1560
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAMES_COUNT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1753
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA_BIT_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1754
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_NOMINAL_BIT_RATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1755
#define RSMXO_ATTR_PROTOCOL_CAN_RESULTS_STUFF_BIT_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1756
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_ACCEPTANCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1561
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_PCRC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1562
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SBC                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1563
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SERVICE_DATA_UNIT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1564
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SEC                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1565
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_VCID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1566
#define RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_FRAME_CRC                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1757
#define RSMXO_ATTR_PROTOCOL_LIN_STANDARD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1634
#define RSMXO_ATTR_PROTOCOL_LIN_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1635
#define RSMXO_ATTR_PROTOCOL_LIN_THRESHOLD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1636
#define RSMXO_ATTR_PROTOCOL_LIN_HYSTERESIS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1637
#define RSMXO_ATTR_PROTOCOL_LIN_POLARITY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1638
#define RSMXO_ATTR_PROTOCOL_LIN_BIT_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1639
#define RSMXO_ATTR_PROTOCOL_LIN_POSITION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1758
#define RSMXO_ATTR_PROTOCOL_LIN_SCALE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1759
#define RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1700
#define RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FIELD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1701
#define RSMXO_ATTR_PROTOCOL_LIN_SELECTED_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1702
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FRAME_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1641
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FRAME_CHECK_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1760
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FRAME_CLEAR_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1761
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_INVERTS_CURRENT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1762
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1642
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_OPERATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1643
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_DATA_OPERATOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1644
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_START_DATA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1645
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_END_DATA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1646
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_INDEX_OPERATOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1647
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_END_INDEX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1648
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_START_INDEX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1649
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_ERROR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1650
#define RSMXO_ATTR_PROTOCOL_LIN_FILTER_RESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1763
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1651
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_PARITY_ERROR_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1652
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_SYNC_ERROR_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1653
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_CHECKSUM_ERROR_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1654
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1655
#define RSMXO_ATTR_PROTOCOL_LIN_DATA_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1656
#define RSMXO_ATTR_PROTOCOL_LIN_DATA_POSITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1657
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1658
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_FRAME_ID_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1659
#define RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_FRAME_ID_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1660
#define RSMXO_ATTR_PROTOCOL_LIN_SELECTED_BYTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1661
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1662
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1663
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1664
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_END                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1665
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1703
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BITRATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1667
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_CHECKSUM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1668
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1669
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1670
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_PARITY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1671
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_PROTECTED_IDENTIFIER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1764
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1672
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1673
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_VALUE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1674
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_FORMATTED_VALUE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1675
#define RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_LABEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1676
#define RSMXO_ATTR_PROTOCOL_SPMI_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1765
#define RSMXO_ATTR_PROTOCOL_SPMI_USE_GSID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1766
#define RSMXO_ATTR_PROTOCOL_SPMI_GSID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1767
#define RSMXO_ATTR_PROTOCOL_SPMI_USE_GLITCH_FILTER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1768
#define RSMXO_ATTR_PROTOCOL_SPMI_GLITCH_FILTER_WIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1769
#define RSMXO_ATTR_PROTOCOL_SPMI_CLOCK_LINE_HYSTERESIS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1770
#define RSMXO_ATTR_PROTOCOL_SPMI_CLOCK_LINE_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1771
#define RSMXO_ATTR_PROTOCOL_SPMI_CLOCK_LINE_THRESHOLD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1772
#define RSMXO_ATTR_PROTOCOL_SPMI_SOURCE_DATA_HYSTERESIS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1773
#define RSMXO_ATTR_PROTOCOL_SPMI_SOURCE_DATA_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1774
#define RSMXO_ATTR_PROTOCOL_SPMI_SOURCE_DATA_THRESHOLD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1775
#define RSMXO_ATTR_PROTOCOL_SPMI_POSITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1776
#define RSMXO_ATTR_PROTOCOL_SPMI_SCALE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1777
#define RSMXO_ATTR_PROTOCOL_SPMI_SELECTED_FIELD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1778
#define RSMXO_ATTR_PROTOCOL_SPMI_SELECTED_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1779
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_FRAME_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1780
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_FRAME_CHECK_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1781
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_FRAME_CLEAR_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1782
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_INVERTS_CURRENT_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1783
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_FIELD_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1784
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1785
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_START_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1786
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_END_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1787
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1788
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_START_DATA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1789
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_END_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1790
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1791
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_ERROR_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1792
#define RSMXO_ATTR_PROTOCOL_SPMI_FILTER_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1793
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1794
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1795
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_END                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1796
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_READ_BIT_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1797
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_WRITE_BIT_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1798
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_ADDRESS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1799
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1800
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_ADDRESS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1801
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_BC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1802
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1803
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FD_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1804
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_FORMATED_VALUE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1805
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_LABEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1806
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1807
#define RSMXO_ATTR_PROTOCOL_SPMI_RESULTS_FRAME_VALUE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1808
#define RSMXO_ATTR_PROTOCOL_TNOS_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1809
#define RSMXO_ATTR_PROTOCOL_TNOS_HYSTERESIS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1810
#define RSMXO_ATTR_PROTOCOL_TNOS_POSITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1811
#define RSMXO_ATTR_PROTOCOL_TNOS_SCALE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1812
#define RSMXO_ATTR_PROTOCOL_TNOS_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1813
#define RSMXO_ATTR_PROTOCOL_TNOS_SHOW_SYMBOLS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1814
#define RSMXO_ATTR_PROTOCOL_TNOS_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1815
#define RSMXO_ATTR_PROTOCOL_TNOS_SYMBOL_LIST_FILE_LOAD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1816
#define RSMXO_ATTR_PROTOCOL_TNOS_THRESHOLD_LOWER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1817
#define RSMXO_ATTR_PROTOCOL_TNOS_THRESHOLD_UPPER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1818
#define RSMXO_ATTR_PROTOCOL_TNOS_SELECTED_FIELD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1819
#define RSMXO_ATTR_PROTOCOL_TNOS_SELECTED_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1820
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_FRAME_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1821
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1822
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_FRAME_CHECK_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1823
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_FRAME_CLEAR_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1824
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_INVERTS_CURRENT_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1825
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_FIELD_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1826
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1827
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_START_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1828
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_END_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1829
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1830
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_START_DATA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1831
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_END_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1832
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_ERROR_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1833
#define RSMXO_ATTR_PROTOCOL_TNOS_FILTER_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1834
#define RSMXO_ATTR_PROTOCOL_TNOS_SELECTED_BYTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1835
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1836
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1837
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_END                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1838
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1839
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1840
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_BIT_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1841
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_BYTE_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1842
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_BYTE_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1843
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_BYTE_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1844
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_BYTE_VALUE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1845
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_BYTE_FORMATTED_VALUE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1846
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_BYTE_LABEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1847
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1848
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_CRC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1849
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_DESTINATION_ADDRESS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1850
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_DESTINATION_SYMBOL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1851
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_FORMATED_CRC                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1852
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_FORMATED_DATA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1853
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_FORMATED_DESTINATION_ADDRESS               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1854
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_FORMATED_SRC_ADDRESS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1855
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_FRAME_FORMATED_TYPE_LENGTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1856
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_SOURCE_ADDRESS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1857
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_SOURCE_SYMBOL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1858
#define RSMXO_ATTR_PROTOCOL_TNOS_RESULTS_TYPE_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1859
#define RSMXO_ATTR_PROTOCOL_HBTO_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1860
#define RSMXO_ATTR_PROTOCOL_HBTO_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1861
#define RSMXO_ATTR_PROTOCOL_HBTO_POLARITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1862
#define RSMXO_ATTR_PROTOCOL_HBTO_POSITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1863
#define RSMXO_ATTR_PROTOCOL_HBTO_SCALE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1864
#define RSMXO_ATTR_PROTOCOL_HBTO_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1865
#define RSMXO_ATTR_PROTOCOL_HBTO_SHOW_SYMBOLS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1866
#define RSMXO_ATTR_PROTOCOL_HBTO_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1867
#define RSMXO_ATTR_PROTOCOL_HBTO_SYMBOL_LIST_FILE_LOAD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1868
#define RSMXO_ATTR_PROTOCOL_HBTO_SELECTED_FIELD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1869
#define RSMXO_ATTR_PROTOCOL_HBTO_SELECTED_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1870
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_FRAME_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1871
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1872
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_FRAME_CHECK_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1873
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_FRAME_CLEAR_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1874
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_INVERTS_CURRENT_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1875
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_FIELD_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1876
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1877
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_START_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1878
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_END_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1879
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1880
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_START_DATA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1881
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_END_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1882
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_ERROR_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1883
#define RSMXO_ATTR_PROTOCOL_HBTO_FILTER_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1884
#define RSMXO_ATTR_PROTOCOL_HBTO_SELECTED_BYTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1885
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1886
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1887
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_END                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1888
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1889
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1890
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_BIT_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1891
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_BYTE_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1892
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_BYTE_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1893
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_BYTE_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1894
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_BYTE_VALUE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1895
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_BYTE_FORMATTED_VALUE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1896
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_BYTE_LABEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1897
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1898
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_CRC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1899
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_DESTINATION_ADDRESS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1900
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_DESTINATION_SYMBOL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1901
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_FORMATED_CRC                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1902
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_FORMATED_DATA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1903
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_FORMATED_DESTINATION_ADDRESS               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1904
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_FORMATED_SRC_ADDRESS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1905
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_FRAME_FORMATED_TYPE_LENGTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1906
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_SOURCE_ADDRESS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1907
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_SOURCE_SYMBOL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1908
#define RSMXO_ATTR_PROTOCOL_HBTO_RESULTS_TYPE_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1909
#define RSMXO_ATTR_PROTOCOL_EXPORT_SAVE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1063
#define RSMXO_ATTR_PROTOCOL_EXPORT_INCLUDE_TIMING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1064
#define RSMXO_ATTR_PROTOCOL_EXPORT_INCLUDE_DETAILS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1065
#define RSMXO_ATTR_PROTOCOL_EXPORT_EXTENSION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1910
#define RSMXO_ATTR_PROTOCOL_EXPORT_PATH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1911
#define RSMXO_ATTR_LOGIC_STATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1066
#define RSMXO_ATTR_LOGIC_SHOW_DIGITAL_SIGNALS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1067
#define RSMXO_ATTR_LOGIC_TECHNOLOGY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1068
#define RSMXO_ATTR_LOGIC_LEVEL_COUPLING                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1069
#define RSMXO_ATTR_LOGIC_SKEW                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1070
#define RSMXO_ATTR_LOGIC_CLEAR                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1071
#define RSMXO_ATTR_LOGIC_BUS_SHOW                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1077
#define RSMXO_ATTR_LOGIC_BUS_DATA_FORMAT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1078
#define RSMXO_ATTR_LOGIC_POSITION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1567
#define RSMXO_ATTR_LOGIC_SIZE_OF_THE_DISPLAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1568
#define RSMXO_ATTR_LOGIC_DIGITAL_CHANNEL_VERTICAL_POSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1569
#define RSMXO_ATTR_LOGIC_DIGITAL_CHANNEL_SIZE_OF_THE_DISPLAY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1570
#define RSMXO_ATTR_LOGIC_CHANNEL_GROUP_THRESHOLD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1072
#define RSMXO_ATTR_LOGIC_CHANNEL_GROUP_HYSTERESIS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1073
#define RSMXO_ATTR_LOGIC_BIT_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1076
#define RSMXO_ATTR_LOGIC_BIT_LABEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1074
#define RSMXO_ATTR_LOGIC_BIT_SKEW                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1075
#define RSMXO_ATTR_LOGIC_BUS_CLOCKED_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1079
#define RSMXO_ATTR_LOGIC_BUS_CLOCKED_SLOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1080
#define RSMXO_ATTR_LOGIC_BUS_CLOCKED_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1081
#define RSMXO_ATTR_DIGITAL_CHANNEL_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1082
#define RSMXO_ATTR_DIGITAL_CHANNEL_TECHNOLOGY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1083
#define RSMXO_ATTR_DIGITAL_CHANNEL_SKEW                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1084
#define RSMXO_ATTR_DIGITAL_CHANNEL_LABEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1085
#define RSMXO_ATTR_DIGITAL_CHANNEL_SIZE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1086
#define RSMXO_ATTR_DIGITAL_CHANNEL_TH_COUPLING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1087
#define RSMXO_ATTR_DIGITAL_CHANNEL_THRESHOLD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1088
#define RSMXO_ATTR_LOGIC_DECODE_TABLE_SHOW                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1912
#define RSMXO_ATTR_LOGIC_DECODE_TABLE_NUMBER_OF_ROWS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1913
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AUTOSCALE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1571
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_START                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1572
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_RESULT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1573
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_STATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1574
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1404
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GENERATOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1405
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_INPUT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1406
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_OUTPUT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1407
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1408
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_STOP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1409
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1410
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_TOTAL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1411
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_LOGARITHMIC                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1412
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_USER_LOAD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1413
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1414
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1415
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_REPEAT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1416
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_RESET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1417
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_RUN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1418
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MAXIMUM_PHASE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1419
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MEASUREMENT_DELAY_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1420
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DELAY_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1421
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_RBW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1422
#define RSMXO_ATTR_SELECTED_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_POINT           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1423
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_POINT_COUNT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1424
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_ADD                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1425
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_DELETE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1426
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_SORT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1427
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_AMPLITUDE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1428
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_FREQUENCY                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1429
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_VOLTAGE_CHANGE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1430
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_POINTS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1431
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_RESULT_TABLE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1432
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_MARKERS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1433
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_MARGIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1434
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1435
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_VERTICAL_SCALE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1436
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_VERTICAL_OFFSET                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1437
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1438
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_VERTICAL_SCALE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1439
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_VERTICAL_OFFSET                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1440
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1441
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_VERTICAL_SCALE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1442
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_VERTICAL_OFFSET                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1443
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_MARGIN_FREQUENCY                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1444
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_MARGIN_VALUE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1445
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_MARGIN_FREQUENCY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1446
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_MARGIN_VALUE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1447
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_DATA                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1448
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_DATA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1449
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_FREQUENCY_DATA                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1450
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_PHASE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1451
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1452
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_GAIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1453
#define RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_RESET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1454
#define RSMXO_ATTR_POWER_ANALYSIS_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1915
#define RSMXO_ATTR_POWER_ANALYSIS_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1916
#define RSMXO_ATTR_POWER_ANALYSIS_AUTO_DESKEW_ADJUSTMENT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1917
#define RSMXO_ATTR_POWER_ANALYSIS_EXPORT_RESULTS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1918
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_CURRENT_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1919
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_VOLTAGE_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1920
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_FUNDAMENTAL_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1921
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_FUNDAMENTAL_FREQUENCY_USER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1922
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_CREST_FACTOR_CURRENT            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1923
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_CREST_FACTOR_AVERAGE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1924
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_CREST_FACTOR_NEGATIVE_PEAK      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1925
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_CREST_FACTOR_POSITIVE_PEAK      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1926
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_CREST_FACTOR_RMS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1927
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_CREST_FACTOR_STANDARD_DEVIATION RS_SPECIFIC_PUBLIC_ATTR_BASE + 1928
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_PEAK_CURRENT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1929
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_PEAK_AVERAGE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1930
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_PEAK_NEGATIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1931
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_PEAK_POSITIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1932
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_PEAK_RMS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1933
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_PEAK_STANDARD_DEVIATION         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1934
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_RMS_CURRENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1935
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_RMS_AVERAGE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1936
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_RMS_NEGATIVE_PEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1937
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_RMS_POSITIVE_PEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1938
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_RMS_RMS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1939
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_CURRENT_RMS_STANDARD_DEVIATION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1940
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_APPARENT_CURRENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1941
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_APPARENT_AVERAGE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1942
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_APPARENT_NEGATIVE_PEAK            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1943
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_APPARENT_POSITIVE_PEAK            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1944
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_APPARENT_RMS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1945
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_APPARENT_STANDARD_DEVIATION       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1946
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_FACTOR_CURRENT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1947
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_FACTOR_AVERAGE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1948
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_FACTOR_NEGATIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1949
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_FACTOR_POSITIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1950
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_FACTOR_RMS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1951
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_FACTOR_STANDARD_DEVIATION         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1952
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_PHASE_CURRENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1953
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_PHASE_AVERAGE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1954
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_PHASE_NEGATIVE_PEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1955
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_PHASE_POSITIVE_PEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1956
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_PHASE_RMS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1957
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_PHASE_STANDARD_DEVIATION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1958
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_REACTIVE_CURRENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1959
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_REACTIVE_AVERAGE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1960
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_REACTIVE_NEGATIVE_PEAK            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1961
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_REACTIVE_POSITIVE_PEAK            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1962
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_REACTIVE_RMS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1963
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_REACTIVE_STANDARD_DEVIATION       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1964
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_ACTIVE_CURRENT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1965
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_ACTIVE_AVERAGE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1966
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_ACTIVE_NEGATIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1967
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_ACTIVE_POSITIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1968
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_ACTIVE_RMS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1969
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_POWER_ACTIVE_STANDARD_DEVIATION         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1970
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_CREST_FACTOR_CURRENT            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1971
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_CREST_FACTOR_AVERAGE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1972
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_CREST_FACTOR_NEGATIVE_PEAK      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1973
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_CREST_FACTOR_POSITIVE_PEAK      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1974
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_CREST_FACTOR_RMS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1975
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_CREST_FACTOR_STANDARD_DEVIATION RS_SPECIFIC_PUBLIC_ATTR_BASE + 1976
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_FREQUENCY_CURRENT               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1977
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_FREQUENCY_AVERAGE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1978
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_FREQUENCY_NEGATIVE_PEAK         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1979
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_FREQUENCY_POSITIVE_PEAK         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1980
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_FREQUENCY_RMS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1981
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_FREQUENCY_STANDARD_DEVIATION    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1982
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_PEAK_CURRENT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1983
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_PEAK_AVERAGE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1984
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_PEAK_NEGATIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1985
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_PEAK_POSITIVE_PEAK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1986
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_PEAK_RMS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1987
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_PEAK_STANDARD_DEVIATION         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1988
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_RMS_CURRENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1989
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_RMS_AVERAGE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1990
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_RMS_NEGATIVE_PEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1991
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_RMS_POSITIVE_PEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1992
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_RMS_RMS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1993
#define RSMXO_ATTR_POWER_ANALYSIS_QUALITY_RESULTS_VOLTAGE_RMS_STANDARD_DEVIATION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1994
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_CURRENT_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1995
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_VOLTAGE_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1996
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_STANDARD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1997
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_EN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1998
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_MIL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1999
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_RTCA                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2000
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_CLEAR_RESULTS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2001
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_DISPLAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2002
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_DISPLAY_FREQUENCY_START                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2003
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_DISPLAY_FREQUENCY_STOP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2004
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_SCALING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2005
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MEASURED_HARMONICS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2006
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_THDF                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2007
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_THD_RMS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2008
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_FREQUENCY_CURRENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2009
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_REAL_POWER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2010
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_VIOLATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2011
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_FREQUENCY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2012
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MAGNITUDE_MAXIMUM_PERCENT             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2013
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MAGNITUDE_MINIMUM_PERCENT             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2014
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MAGNITUDE_CURRENT_PERCENT             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2015
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MAGNITUDE_MAXIMUM_RMS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2016
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MAGNITUDE_MINIMUM_RMS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2017
#define RSMXO_ATTR_POWER_ANALYSIS_HARMONICS_RESULTS_MAGNITUDE_CURRENT_RMS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2018
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_HYSTERESIS_ABSOLUTE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2019
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_HYSTERESIS_ABSOLUTE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2020
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_ABSOLUTE_LOWER_LEVEL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2021
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_ABSOLUTE_LOWER_LEVEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2022
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_ABSOLUTE_MIDDLE_LEVEL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2023
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_ABSOLUTE_MIDDLE_LEVEL                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2024
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_ABSOLUTE_UPPER_LEVEL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2025
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_ABSOLUTE_UPPER_LEVEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2026
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_LEVEL_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2027
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_LEVEL_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2028
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_HYSTERESIS_RELATIVE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2029
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_HYSTERESIS_RELATIVE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2030
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_RELATIVE_LOWER_LEVEL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2031
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_RELATIVE_LOWER_LEVEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2032
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_RELATIVE_MIDDLE_LEVEL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2033
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_RELATIVE_MIDDLE_LEVEL                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2034
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_RELATIVE_UPPER_LEVEL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2035
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_RELATIVE_UPPER_LEVEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2036
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_HARMONICS_RELATIVE_LEVELS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2037
#define RSMXO_ATTR_POWER_ANALYSIS_REF_LEVEL_QUALITY_RELATIVE_LEVELS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2038
#define RSMXO_ATTR_POWER_ANALYSIS_DATA_HARMONICS_HEADER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2039
#define RSMXO_ATTR_POWER_ANALYSIS_DATA_QUALITY_HEADER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2040
#define RSMXO_ATTR_DIGITAL_VOLTMETER_DC_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2043
#define RSMXO_ATTR_DIGITAL_VOLTMETER_DC_RESULT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2044
#define RSMXO_ATTR_DIGITAL_VOLTMETER_AC_RMS_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2045
#define RSMXO_ATTR_DIGITAL_VOLTMETER_AC_RMS_RESULT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2046
#define RSMXO_ATTR_DIGITAL_VOLTMETER_DC_RMS_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2047
#define RSMXO_ATTR_DIGITAL_VOLTMETER_DC_RMS_RESULT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2048
#define RSMXO_ATTR_DIGITAL_VOLTMETER_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2049
#define RSMXO_ATTR_DIGITAL_VOLTMETER_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2050
#define RSMXO_ATTR_REFERENCE_WAVEFORM_SHOW                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1089
#define RSMXO_ATTR_REFERENCE_WAVEFORM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1090
#define RSMXO_ATTR_REFERENCE_WAVEFORM_NAME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1091
#define RSMXO_ATTR_REFERENCE_WAVEFORM_CREATE_UPDATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1092
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1093
#define RSMXO_ATTR_REFERENCE_WAVEFORM_SAVE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1094
#define RSMXO_ATTR_REFERENCE_WAVEFORM_ABORT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1677
#define RSMXO_ATTR_REFERENCE_WAVEFORM_OPEN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1095
#define RSMXO_ATTR_REFERENCE_WAVEFORM_CLEAR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1096
#define RSMXO_ATTR_REFERENCE_WAVEFORM_X_AXIS_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2051
#define RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1097
#define RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_RESET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1098
#define RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1099
#define RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1100
#define RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1455
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1101
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_SCALE_FACTOR                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1102
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1103
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1104
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_ENABLE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1105
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_SCALE_FACTOR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1106
#define RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1107
#define RSMXO_ATTR_GENERATOR_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1108
#define RSMXO_ATTR_GENERATOR_INVERSION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1110
#define RSMXO_ATTR_GENERATOR_FUNCTION_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1111
#define RSMXO_ATTR_GENERATOR_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1112
#define RSMXO_ATTR_GENERATOR_AMPLITUDE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1113
#define RSMXO_ATTR_GENERATOR_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1114
#define RSMXO_ATTR_GENERATOR_SYMMETRY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1115
#define RSMXO_ATTR_GENERATOR_DUTY_CYCLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1116
#define RSMXO_ATTR_GENERATOR_PERIOD                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1117
#define RSMXO_ATTR_GENERATOR_PULSE_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1118
#define RSMXO_ATTR_GENERATOR_NOISE_LEVEL_IN_PERCENT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1119
#define RSMXO_ATTR_GENERATOR_NOISE_LEVEL_ABSOLUTE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1120
#define RSMXO_ATTR_GENERATOR_NOISE_DC_LEVEL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1121
#define RSMXO_ATTR_GENERATOR_DC_LEVEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1122
#define RSMXO_ATTR_GENERATOR_LOW_VOLTAGE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1123
#define RSMXO_ATTR_GENERATOR_HIGH_VOLTAGE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1124
#define RSMXO_ATTR_GENERATOR_USER_LOAD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1125
#define RSMXO_ATTR_GENERATOR_DEFAULT_SETUP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1126
#define RSMXO_ATTR_GENERATOR_SAVE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1575
#define RSMXO_ATTR_GENERATOR_RECALL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1576
#define RSMXO_ATTR_GENERATOR_SWEEP_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1128
#define RSMXO_ATTR_GENERATOR_SWEEP_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1129
#define RSMXO_ATTR_GENERATOR_SWEEP_START_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1130
#define RSMXO_ATTR_GENERATOR_SWEEP_STOP_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1131
#define RSMXO_ATTR_GENERATOR_SWEEP_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1132
#define RSMXO_ATTR_GENERATOR_MODULATION_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1678
#define RSMXO_ATTR_GENERATOR_MODULATION_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1134
#define RSMXO_ATTR_GENERATOR_MODULATION_CARRIER_PERIOD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1136
#define RSMXO_ATTR_GENERATOR_MODULATION_CARRIER_FREQUENCY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1137
#define RSMXO_ATTR_GENERATOR_MODULATION_AM_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1138
#define RSMXO_ATTR_GENERATOR_MODULATION_AM_SIGNAL_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1139
#define RSMXO_ATTR_GENERATOR_MODULATION_AM_DEPTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1140
#define RSMXO_ATTR_GENERATOR_MODULATION_AM_DUTY_CYCLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1141
#define RSMXO_ATTR_GENERATOR_MODULATION_AM_SYMMETRY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1142
#define RSMXO_ATTR_GENERATOR_MODULATION_PWM_FREQUENCY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1143
#define RSMXO_ATTR_GENERATOR_MODULATION_PWM_SIGNAL_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1144
#define RSMXO_ATTR_GENERATOR_MODULATION_PWM_DEPTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1145
#define RSMXO_ATTR_GENERATOR_MODULATION_PWM_DUTY_CYCLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1146
#define RSMXO_ATTR_GENERATOR_MODULATION_PWM_SYMMETRY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1147
#define RSMXO_ATTR_GENERATOR_MODULATION_FM_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1148
#define RSMXO_ATTR_GENERATOR_MODULATION_FM_SIGNAL_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1149
#define RSMXO_ATTR_GENERATOR_MODULATION_FM_DEVIATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1150
#define RSMXO_ATTR_GENERATOR_MODULATION_FM_DUTY_CYCLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1151
#define RSMXO_ATTR_GENERATOR_MODULATION_FM_SYMMETRY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1152
#define RSMXO_ATTR_GENERATOR_MODULATION_FSK_FREQUENCY_1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1153
#define RSMXO_ATTR_GENERATOR_MODULATION_FSK_FREQUENCY_2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1154
#define RSMXO_ATTR_GENERATOR_MODULATION_FSK_RATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1155
#define RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_SOURCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1156
#define RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_OPEN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1157
#define RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_NAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1158
#define RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_RUN_SINGLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1577
#define RSMXO_ATTR_GENERATOR_ARBITRARY_RUN_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1159
#define RSMXO_ATTR_GENERATOR_ARBITRARY_SAMPLE_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1160
#define RSMXO_ATTR_GENERATOR_ARBITRARY_NUMBER_OF_SAMPLES                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1161
#define RSMXO_ATTR_GENERATOR_ARBITRARY_SIGNAL_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1162
#define RSMXO_ATTR_GENERATOR_SYNCHRONISATION_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1163
#define RSMXO_ATTR_GENERATOR_SYNCHRONISATION_AMPLITUDE_PARAMETERS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1165
#define RSMXO_ATTR_GENERATOR_SYNCHRONISATION_FREQUENCY_PARAMETERS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1166
#define RSMXO_ATTR_GENERATOR_SYNCHRONIZE_PHASE_SHIFT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1167
#define RSMXO_ATTR_GENERATOR_SYNCHRONISATION_COUPLING_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2052
#define RSMXO_ATTR_SAVESET_INCLUDE_PREVIEW_IMAGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1168
#define RSMXO_ATTR_SAVE_INSTRUMENT_SETTINGS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1459
#define RSMXO_ATTR_LOAD_INSTRUMENT_SETTINGS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1460
#define RSMXO_ATTR_DRIVES_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1456
#define RSMXO_ATTR_MEMORY_CATALOG_SIZE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1457
#define RSMXO_ATTR_LOAD_WAVEFORM_GENERATOR_SETTINGS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1578
#define RSMXO_ATTR_STORE_WAVEFORM_GENERATOR_SETTINGS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1579
#define RSMXO_ATTR_FILE_DELETE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1461
#define RSMXO_ATTR_DIRECTORY_DEFAULT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1466
#define RSMXO_ATTR_DIRECTORY_CREATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1467
#define RSMXO_ATTR_DIRECTORY_DELETE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1468
#define RSMXO_ATTR_SCREENSHOT_SHOW_SETUP_DIALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1177
#define RSMXO_ATTR_SCREENSHOT_WHITE_BACKGROUND                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1178
#define RSMXO_ATTR_SCREENSHOT_INCLUDE_SIGNAL_BAR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1179
#define RSMXO_ATTR_SCREENSHOT_INVERT_COLOR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1180
#define RSMXO_ATTR_SCREENSHOT_FILENAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1580
#define RSMXO_ATTR_SCREENSHOT_FILE_EXTENSION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1185
#define RSMXO_ATTR_SCREENSHOT_SAVE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1186
#define RSMXO_ATTR_SCREENSHOT_SAVE_NEXT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1187
#define RSMXO_ATTR_WAVEFORM_EXPORT_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1188
#define RSMXO_ATTR_WAVEFORM_EXPORT_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1189
#define RSMXO_ATTR_WAVEFORM_EXPORT_MANUAL_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1190
#define RSMXO_ATTR_WAVEFORM_EXPORT_MANUAL_STOP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1191
#define RSMXO_ATTR_WAVEFORM_EXPORT_GATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1192
#define RSMXO_ATTR_WAVEFORM_EXPORT_CURSOR_SET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1193
#define RSMXO_ATTR_WAVEFORM_EXPORT_FILE_NAME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1194
#define RSMXO_ATTR_WAVEFORM_EXPORT_SAVE_TO_FILE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1195
#define RSMXO_ATTR_WAVEFORM_EXPORT_ABORT_SAVE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1679
#define RSMXO_ATTR_RESULTS_EXPORT_INCLUDE_CURRENT_MEASUREMENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1471
#define RSMXO_ATTR_RESULTS_EXPORT_INCLUDE_CURSOR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1472
#define RSMXO_ATTR_RESULTS_EXPORT_FILE_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1473
#define RSMXO_ATTR_RESULTS_EXPORT_SAVE_TO_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1474
#define RSMXO_ATTR_RESULTS_EXPORT_FRA_MARGIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1581
#define RSMXO_ATTR_RESULTS_EXPORT_FRA_MARKER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1582
#define RSMXO_ATTR_RESULTS_EXPORT_FRA_RESULT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1583
#define RSMXO_ATTR_SYSTEM_NETWORK_HOSTNAME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1215
#define RSMXO_ATTR_REMOTE_TRANSFER_DATA_FORMAT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1216
#define RSMXO_ATTR_REMOTE_BITPATTERN_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1217
#define RSMXO_ATTR_REMOTE_DISPLAY_UPDATE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1218
#define RSMXO_ATTR_REMOTE_DISPLAY_MESSAGE_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1219
#define RSMXO_ATTR_REMOTE_DISPLAY_MESSAGE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1220
#define RSMXO_ATTR_COLORS_SIGNAL_NAME_CATALOG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1221
#define RSMXO_ATTR_GRID_SHOW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1225
#define RSMXO_ATTR_GRID_SHOW_LABELS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1226
#define RSMXO_ATTR_GRID_SHOW_FINE_GRID_SCALE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1227
#define RSMXO_ATTR_GRID_SHOW_CROSSHAIR                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1228
#define RSMXO_ATTR_GRID_KEEP_Y_GRID_FIXED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1229
#define RSMXO_ATTR_GRID_KEEP_X_GRID_FIXED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2053
#define RSMXO_ATTR_SMART_GRID_LAYOUT_ACTIVE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1477
#define RSMXO_ATTR_SMART_GRID_LAYOUT_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1479
#define RSMXO_ATTR_SMART_GRID_LAYOUT_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1480
#define RSMXO_ATTR_SMART_GRID_LAYOUT_LABEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1481
#define RSMXO_ATTR_SMART_GRID_SELECTED_NODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1231
#define RSMXO_ATTR_SMART_GRID_SELECTED_CONTENTS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1232
#define RSMXO_ATTR_SMART_GRID_NODE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1233
#define RSMXO_ATTR_SMART_GRID_NODE_COUNT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1234
#define RSMXO_ATTR_SMART_GRID_NODE_SPLIT_RATIO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1235
#define RSMXO_ATTR_SMART_GRID_NODE_SPLIT_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1236
#define RSMXO_ATTR_SMART_GRID_DIAGRAM_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1482
#define RSMXO_ATTR_SMART_GRID_DIAGRAM_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1483
#define RSMXO_ATTR_SMART_GRID_DIAGRAM_LABEL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1484
#define RSMXO_ATTR_SMART_GRID_DIAGRAM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1485
#define RSMXO_ATTR_SMART_GRID_NODE_ID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1237
#define RSMXO_ATTR_SMART_GRID_NODE_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1238
#define RSMXO_ATTR_DIALOG_FONT_SIZE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2054
#define RSMXO_ATTR_DIALOG_TRANSPARENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2055
#define RSMXO_ATTR_DIALOG_RESULT_FONT_SIZE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2056
#define RSMXO_ATTR_DISPLAY_SIGNAL_STYLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1239
#define RSMXO_ATTR_DISPLAY_SIGNAL_INTENSITY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1240
#define RSMXO_ATTR_DISPLAY_PERSISTENCE_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1241
#define RSMXO_ATTR_DISPLAY_PERSISTENCE_INFINITE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1242
#define RSMXO_ATTR_DISPLAY_PERSISTENCE_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1243
#define RSMXO_ATTR_DISPLAY_PERSISTENCE_RESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1244
#define RSMXO_ATTR_DISPLAY_BACKLIGHT_BRIGHTNESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1680
#define RSMXO_ATTR_DISPLAY_BACKLIGHT_DIMM_ON_USER_INACTIVITY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1681
#define RSMXO_ATTR_DISPLAY_CLEAR_RESULTS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1682
#define RSMXO_ATTR_TOOLBAR_NUMBER_OF_TOOLS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2057
#define RSMXO_ATTR_TOOLBAR_REMOVE_ALL_TOOLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2058
#define RSMXO_ATTR_TOOLBAR_RESET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2059
#define RSMXO_ATTR_CSV_DELIMITER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1245
#define RSMXO_ATTR_AUTONAMING_AUTOSAVE_ENABLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1486
#define RSMXO_ATTR_AUTONAMING_AUTOSAVE_INTERVAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1487
#define RSMXO_ATTR_AUTONAMING_USER_TEXT_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1246
#define RSMXO_ATTR_AUTONAMING_PREFIX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1247
#define RSMXO_ATTR_AUTONAMING_DATE_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1248
#define RSMXO_ATTR_AUTONAMING_INDEX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1249
#define RSMXO_ATTR_AUTONAMING_USER_TEXT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1250
#define RSMXO_ATTR_AUTONAMING_DEFAULT_PATH_FOR_ALL_FILE_OPERATIONS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1251
#define RSMXO_ATTR_AUTONAMING_RESET_PATH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1252
#define RSMXO_ATTR_AUTONAMING_RESET_ALL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1253
#define RSMXO_ATTR_EXECUTE_ALIGNMENT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1272
#define RSMXO_ATTR_ALIGNMENT_DATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1256
#define RSMXO_ATTR_ALIGNMENT_TIME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1257
#define RSMXO_ATTR_ALIGNMENT_RESULT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1258
#define RSMXO_ATTR_AUTO_POWER_UP_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1488
#define RSMXO_ATTR_CREATE_SERVICE_REPORT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2060
#define RSMXO_ATTR_SYSTEM_EXIT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2061
#define RSMXO_ATTR_SYSTEM_SHUTDOWN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2062
#define RSMXO_ATTR_SYSTEM_FILENAME_FIRMWARE_INSTALLATION_FILE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2063
#define RSMXO_ATTR_SYSTEM_START_FIRMWARE_UPDATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2064
#define RSMXO_ATTR_SYSTEM_PRESET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2065
#define RSMXO_ATTR_SYSTEM_HOSTNAME                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2066
#define RSMXO_ATTR_CHANNEL_WAVEFORM_HEADER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1196
#define RSMXO_ATTR_MATH_WAVEFORM_HEADER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1198
#define RSMXO_ATTR_DIGITAL_WAVEFORM_HEADER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1200
#define RSMXO_ATTR_LOGIC_BUS_HEADER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1202
#define RSMXO_ATTR_REFERENCE_WAVEFORM_HEADER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1204
#define RSMXO_ATTR_REFERENCE_WAVEFORM_DATA_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1206
#define RSMXO_ATTR_SPECTRUM_NORMAL_WAVEFORM_HEADER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1207
#define RSMXO_ATTR_SPECTRUM_AVERAGE_WAVEFORM_HEADER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1208
#define RSMXO_ATTR_SPECTRUM_MINIMUM_WAVEFORM_HEADER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1209
#define RSMXO_ATTR_SPECTRUM_MAXIMUM_WAVEFORM_HEADER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1210
#define RSMXO_ATTR_MEASUREMENT_TRACK_DATA_HEADER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1584
#define RSMXO_ATTR_STATUS_REGISTER_RESET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1489
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1490
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_CONDITION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1491
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_EVENT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1492
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_NEGATIVE_TRANSITION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1493
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_POSITIVE_TRANSITION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1494
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1495
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_CONDITION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1496
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_EVENT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1497
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_NEGATIVE_TRANSITION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1498
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_POSITIVE_TRANSITION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1499
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1500
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_NEGATIVE_TRANSITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1501
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_POSITIVE_TRANSITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1502
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_EVENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1503
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1504
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1586
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1587
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_EVENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1505
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_NEGATIVE_TRANSITION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1588
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_POSITIVE_TRANSITION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1589
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1590
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1591
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_EVENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1592
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_NEGATIVE_TRANSITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1593
#define RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_POSITIVE_TRANSITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1594
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1506
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1507
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_EVENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1508
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_NEGATIVE_TRANSITION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1509
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_POSITIVE_TRANSITION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1510
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1511
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1512
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_EVENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1513
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_NEGATIVE_TRANSITION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1514
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_POSITIVE_TRANSITION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1515
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1516
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1517
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_EVENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1518
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_NEGATIVE_TRANSITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1519
#define RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_POSITIVE_TRANSITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1520
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1595
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1596
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_EVENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1597
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_NEGATIVE_TRANSITION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1598
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_POSITIVE_TRANSITION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1599
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1600
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_CONDITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1601
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_EVENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1602
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_NEGATIVE_TRANSITION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1603
#define RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_POSITIVE_TRANSITION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1604
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1683
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_EVENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1684
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1685
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_POSITIVE_TRANSITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1686
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_NEGATIVE_TRANSITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1687
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1688
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_EVENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1689
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1690
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_POSITIVE_TRANSITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1691
#define RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_NEGATIVE_TRANSITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1692
#define RSMXO_ATTR_ID_QUERY_RESPONSE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1260
#define RSMXO_ATTR_SYSTEM_ERROR                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1262
#define RSMXO_ATTR_SYSTEM_ERROR_LIST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1273
#define RSMXO_ATTR_SYSTEM_VERSION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1264
#define RSMXO_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1265
#define RSMXO_ATTR_LOGGING                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1267

// RsMxo_rngAcquisitionInterpolation
#define RSMXO_VAL_ACQUISITION_INTERPOLATION_LINEAR                          0
#define RSMXO_VAL_ACQUISITION_INTERPOLATION_SINX                            1
#define RSMXO_VAL_ACQUISITION_INTERPOLATION_SMHD                            2

// RsMxo_rngAcquisitionRecordLengthMode
#define RSMXO_VAL_ACQUISITION_RECORD_LENGTH_MODE_AUTO                       0
#define RSMXO_VAL_ACQUISITION_RECORD_LENGTH_MODE_MANUAL                     1

// RsMxo_rngAcquisitionSampleRateMode
#define RSMXO_VAL_ACQUISITION_SAMPLE_RATE_MODE_AUTO                         0
#define RSMXO_VAL_ACQUISITION_SAMPLE_RATE_MODE_MANUAL                       1

// RsMxo_rngAcquisitionMode
#define RSMXO_VAL_ACQUISITION_MODE_SAMPLE                                   0
#define RSMXO_VAL_ACQUISITION_MODE_PEAK_DETECT                              1
#define RSMXO_VAL_ACQUISITION_MODE_ENVELOPE                                 2
#define RSMXO_VAL_ACQUISITION_MODE_AVERAGE                                  3

// RsMxo_rngSpectrumWindowType
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_RECTANGULAR                          0
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_HAMMING                              1
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_HANN                                 2
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_BLACKHARRIS                          3
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_GAUSSIAN                             4
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_FLATTOP2                             5
#define RSMXO_VAL_SPECTRUM_WINDOW_TYPE_KAISERBESSEL                         6

// RsMxo_rngSpectrumScaleUnit
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_LINEAR                                0
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_DBM                                   1
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_DBV                                   2
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_DBUV                                  3
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_DB                                    4
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_DBS                                   5
#define RSMXO_VAL_SPECTRUM_SCALE_UNIT_DBHZ                                  6

// RsMxo_rngPeaklistFrameType
#define RSMXO_VAL_PEAKLIST_FRAME_TYPE_NOBORDER                              0
#define RSMXO_VAL_PEAKLIST_FRAME_TYPE_FULL                                  1

// RsMxo_rngSpectrumPeakListResultMode
#define RSMXO_VAL_SPECTRUM_PEAK_LIST_RESULT_MODE_ABS                        0
#define RSMXO_VAL_SPECTRUM_PEAK_LIST_RESULT_MODE_REL                        1

// RsMxo_rngCalibrationResult
#define RSMXO_VAL_CALIBRATION_RESULT_PASSED                                 0
#define RSMXO_VAL_CALIBRATION_RESULT_FAILED                                 1
#define RSMXO_VAL_CALIBRATION_RESULT_NOALIGNDATA                            2

// RsMxo_rngVerticalBandwidth
#define RSMXO_VAL_VERTICAL_BANDWIDTH_FULL                                   0
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B1G5                                   1
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B1G                                    2
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B700                                   3
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B500                                   4
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B350                                   5
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B200                                   6
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B100                                   7
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B50                                    8
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B20                                    9
#define RSMXO_VAL_VERTICAL_BANDWIDTH_B2G                                    10

// RsMxo_rngVerticalCoupling
#define RSMXO_VAL_VERTICAL_COUPLING_DC                                      0
#define RSMXO_VAL_VERTICAL_COUPLING_DCLIMIT                                 1
#define RSMXO_VAL_VERTICAL_COUPLING_AC                                      2

// RsMxo_rngVerticalExternalAttenuationScale
#define RSMXO_VAL_VERTICAL_EXTERNAL_ATTENUATION_SCALE_LIN                   0
#define RSMXO_VAL_VERTICAL_EXTERNAL_ATTENUATION_SCALE_LOG                   1

// RsMxo_rngCursorType
#define RSMXO_VAL_CURSOR_TYPE_VERTICAL                                      0
#define RSMXO_VAL_CURSOR_TYPE_HORIZONTAL                                    1
#define RSMXO_VAL_CURSOR_TYPE_PAIRED                                        2

// RsMxo_rngSource
#define RSMXO_VAL_SOURCE_NONE                                               0
#define RSMXO_VAL_SOURCE_C1                                                 1
#define RSMXO_VAL_SOURCE_C2                                                 2
#define RSMXO_VAL_SOURCE_C3                                                 3
#define RSMXO_VAL_SOURCE_C4                                                 4
#define RSMXO_VAL_SOURCE_C5                                                 5
#define RSMXO_VAL_SOURCE_C6                                                 6
#define RSMXO_VAL_SOURCE_C7                                                 7
#define RSMXO_VAL_SOURCE_C8                                                 8
#define RSMXO_VAL_SOURCE_SBUS1                                              9
#define RSMXO_VAL_SOURCE_SBUS2                                              10
#define RSMXO_VAL_SOURCE_SBUS3                                              11
#define RSMXO_VAL_SOURCE_SBUS4                                              12
#define RSMXO_VAL_SOURCE_D0                                                 13
#define RSMXO_VAL_SOURCE_D1                                                 14
#define RSMXO_VAL_SOURCE_D2                                                 15
#define RSMXO_VAL_SOURCE_D3                                                 16
#define RSMXO_VAL_SOURCE_D4                                                 17
#define RSMXO_VAL_SOURCE_D5                                                 18
#define RSMXO_VAL_SOURCE_D6                                                 19
#define RSMXO_VAL_SOURCE_D7                                                 20
#define RSMXO_VAL_SOURCE_D8                                                 21
#define RSMXO_VAL_SOURCE_D9                                                 22
#define RSMXO_VAL_SOURCE_D10                                                23
#define RSMXO_VAL_SOURCE_D11                                                24
#define RSMXO_VAL_SOURCE_D12                                                25
#define RSMXO_VAL_SOURCE_D13                                                26
#define RSMXO_VAL_SOURCE_D14                                                27
#define RSMXO_VAL_SOURCE_D15                                                28
#define RSMXO_VAL_SOURCE_M1                                                 29
#define RSMXO_VAL_SOURCE_M2                                                 30
#define RSMXO_VAL_SOURCE_M3                                                 31
#define RSMXO_VAL_SOURCE_M4                                                 32
#define RSMXO_VAL_SOURCE_M5                                                 33
#define RSMXO_VAL_SOURCE_R1                                                 34
#define RSMXO_VAL_SOURCE_R2                                                 35
#define RSMXO_VAL_SOURCE_R3                                                 36
#define RSMXO_VAL_SOURCE_R4                                                 37
#define RSMXO_VAL_SOURCE_SPECTRUM_NORM1                                     38
#define RSMXO_VAL_SOURCE_SPECTRUM_MIN_HOLD1                                 39
#define RSMXO_VAL_SOURCE_SPECTRUM_MAX_HOLD1                                 40
#define RSMXO_VAL_SOURCE_SPECTRUM_AVERAGE1                                  41
#define RSMXO_VAL_SOURCE_MATH6                                              42
#define RSMXO_VAL_SOURCE_MATH7                                              43
#define RSMXO_VAL_SOURCE_MATH8                                              44
#define RSMXO_VAL_SOURCE_REF5                                               45
#define RSMXO_VAL_SOURCE_REF6                                               46
#define RSMXO_VAL_SOURCE_REF7                                               47
#define RSMXO_VAL_SOURCE_REF8                                               48
#define RSMXO_VAL_SOURCE_SPECTRUM_NORM0                                     49
#define RSMXO_VAL_SOURCE_SPECTRUM_MIN_HOLD0                                 50
#define RSMXO_VAL_SOURCE_SPECTRUM_MAX_HOLD0                                 51
#define RSMXO_VAL_SOURCE_SPECTRUM_AVERAGE0                                  52
#define RSMXO_VAL_SOURCE_SPECTRUM_NORM2                                     53
#define RSMXO_VAL_SOURCE_SPECTRUM_MIN_HOLD2                                 54
#define RSMXO_VAL_SOURCE_SPECTRUM_MAX_HOLD2                                 55
#define RSMXO_VAL_SOURCE_SPECTRUM_AVERAGE2                                  56
#define RSMXO_VAL_SOURCE_SPECTRUM_NORM3                                     57
#define RSMXO_VAL_SOURCE_SPECTRUM_MIN_HOLD3                                 58
#define RSMXO_VAL_SOURCE_SPECTRUM_MAX_HOLD3                                 59
#define RSMXO_VAL_SOURCE_SPECTRUM_AVERAGE3                                  60
#define RSMXO_VAL_SOURCE_SPECTRUM_NORM4                                     61
#define RSMXO_VAL_SOURCE_SPECTRUM_MIN_HOLD4                                 62
#define RSMXO_VAL_SOURCE_SPECTRUM_MAX_HOLD4                                 63
#define RSMXO_VAL_SOURCE_SPECTRUM_AVERAGE4                                  64

// RsMxo_rngCursorStyle
#define RSMXO_VAL_CURSOR_STYLE_LINES                                        0
#define RSMXO_VAL_CURSOR_STYLE_LRHOMBUS                                     1
#define RSMXO_VAL_CURSOR_STYLE_VLRHOMBUS                                    2
#define RSMXO_VAL_CURSOR_STYLE_RHOMBUS                                      3

// RsMxo_rngDisplaySignalStyle
#define RSMXO_VAL_DISPLAY_SIGNAL_STYLE_VECTORS                              0
#define RSMXO_VAL_DISPLAY_SIGNAL_STYLE_DOTS                                 1

// RsMxo_rngCSVDelimiter
#define RSMXO_VAL_CSV_DELIMITER_SEMICOLON                                   0
#define RSMXO_VAL_CSV_DELIMITER_COMMA                                       1
#define RSMXO_VAL_CSV_DELIMITER_SPACE                                       2
#define RSMXO_VAL_CSV_DELIMITER_TAB                                         3
#define RSMXO_VAL_CSV_DELIMITER_COLON                                       4

// RsMxo_rngGeneratorSynchronisation
#define RSMXO_VAL_GENERATOR_SYNCHRONISATION_NONE                            0
#define RSMXO_VAL_GENERATOR_SYNCHRONISATION_GEN12                           1

// RsMxo_rngScreenshotFileFormat
#define RSMXO_VAL_SCREENSHOT_FILE_FORMAT_PNG                                0
#define RSMXO_VAL_SCREENSHOT_FILE_FORMAT_JPG                                1

// RsMxo_rngSmartGridNodeType
#define RSMXO_VAL_SMART_GRID_NODE_TYPE_NONE                                 0
#define RSMXO_VAL_SMART_GRID_NODE_TYPE_DIAGRAM                              1
#define RSMXO_VAL_SMART_GRID_NODE_TYPE_RESULT                               2
#define RSMXO_VAL_SMART_GRID_NODE_TYPE_NODE                                 3

// RsMxo_rngSmartGridNodeSplitType
#define RSMXO_VAL_SMART_GRID_NODE_SPLIT_TYPE_NONE                           0
#define RSMXO_VAL_SMART_GRID_NODE_SPLIT_TYPE_HORIZONTAL                     1
#define RSMXO_VAL_SMART_GRID_NODE_SPLIT_TYPE_VERTICAL                       2
#define RSMXO_VAL_SMART_GRID_NODE_SPLIT_TYPE_ZOOM                           3
#define RSMXO_VAL_SMART_GRID_NODE_SPLIT_TYPE_SPECTRUM                       4
#define RSMXO_VAL_SMART_GRID_NODE_SPLIT_TYPE_BODE                           5

// RsMxo_rngAbsoluteRelative
#define RSMXO_VAL_ABSOLUTE                                                  0
#define RSMXO_VAL_RELATIVE                                                  1

// RsMxo_rngMeasurementDirection
#define RSMXO_VAL_MEASUREMENT_DIRECTION_FROM_FIRST                          0
#define RSMXO_VAL_MEASUREMENT_DIRECTION_FROM_LAST                           1

// RsMxo_rngMeasurementType
#define RSMXO_VAL_MEASUREMENT_TYPE_HIGH                                     0
#define RSMXO_VAL_MEASUREMENT_TYPE_LOW                                      1
#define RSMXO_VAL_MEASUREMENT_TYPE_AMPLITUDE                                2
#define RSMXO_VAL_MEASUREMENT_TYPE_MAXIMUM                                  3
#define RSMXO_VAL_MEASUREMENT_TYPE_MINIMUM                                  4
#define RSMXO_VAL_MEASUREMENT_TYPE_PEAK_DELTA                               5
#define RSMXO_VAL_MEASUREMENT_TYPE_MEAN                                     6
#define RSMXO_VAL_MEASUREMENT_TYPE_RMS                                      7
#define RSMXO_VAL_MEASUREMENT_TYPE_STDDEV                                   8
#define RSMXO_VAL_MEASUREMENT_TYPE_CREST                                    9
#define RSMXO_VAL_MEASUREMENT_TYPE_POS_OVERSHOOT                            10
#define RSMXO_VAL_MEASUREMENT_TYPE_NEG_OVERSHOOT                            11
#define RSMXO_VAL_MEASUREMENT_TYPE_AREA                                     12
#define RSMXO_VAL_MEASUREMENT_TYPE_RISE_TIME                                13
#define RSMXO_VAL_MEASUREMENT_TYPE_FALL_TIME                                14
#define RSMXO_VAL_MEASUREMENT_TYPE_POSITIVE_PULSE                           15
#define RSMXO_VAL_MEASUREMENT_TYPE_NEGATIVE_PULSE                           16
#define RSMXO_VAL_MEASUREMENT_TYPE_PERIOD                                   17
#define RSMXO_VAL_MEASUREMENT_TYPE_FREQUENCY                                18
#define RSMXO_VAL_MEASUREMENT_TYPE_POS_DUTY_CYCLE                           19
#define RSMXO_VAL_MEASUREMENT_TYPE_NEG_DUTY_CYCLE                           20
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_AREA                               21
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_MEAN                               22
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_RMS                                23
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_STDDEV                             24
#define RSMXO_VAL_MEASUREMENT_TYPE_PULSE_COUNT                              25
#define RSMXO_VAL_MEASUREMENT_TYPE_DELAY                                    26
#define RSMXO_VAL_MEASUREMENT_TYPE_PHASE                                    27
#define RSMXO_VAL_MEASUREMENT_TYPE_BURST_WIDTH                              28
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_MAX                                29
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_MIN                                30
#define RSMXO_VAL_MEASUREMENT_TYPE_CYCLE_PEAK_DELTA                         31
#define RSMXO_VAL_MEASUREMENT_TYPE_EDGE_COUNT                               32
#define RSMXO_VAL_MEASUREMENT_TYPE_SETUP                                    33
#define RSMXO_VAL_MEASUREMENT_TYPE_HOLD                                     34
#define RSMXO_VAL_MEASUREMENT_TYPE_SETUP_HOLD_TIME                          35
#define RSMXO_VAL_MEASUREMENT_TYPE_SETUP_HOLD_RATIO                         36
#define RSMXO_VAL_MEASUREMENT_TYPE_DELAY_TO_TRIGGER                         37
#define RSMXO_VAL_MEASUREMENT_TYPE_SLEW_RISING                              39
#define RSMXO_VAL_MEASUREMENT_TYPE_SLEW_FALLING                             40

// RsMxo_rngResultsLabelLayout
#define RSMXO_VAL_RESULTS_LABEL_LAYOUT_NOBORDER                             0
#define RSMXO_VAL_RESULTS_LABEL_LAYOUT_FULL                                 1
#define RSMXO_VAL_RESULTS_LABEL_LAYOUT_UNDERLINE                            2

// RsMxo_rngDigitalChannel
#define RSMXO_VAL_DIGITAL_CHANNEL_D0                                        0
#define RSMXO_VAL_DIGITAL_CHANNEL_D1                                        1
#define RSMXO_VAL_DIGITAL_CHANNEL_D2                                        2
#define RSMXO_VAL_DIGITAL_CHANNEL_D3                                        3
#define RSMXO_VAL_DIGITAL_CHANNEL_D4                                        4
#define RSMXO_VAL_DIGITAL_CHANNEL_D5                                        5
#define RSMXO_VAL_DIGITAL_CHANNEL_D6                                        6
#define RSMXO_VAL_DIGITAL_CHANNEL_D7                                        7
#define RSMXO_VAL_DIGITAL_CHANNEL_D8                                        8
#define RSMXO_VAL_DIGITAL_CHANNEL_D9                                        9
#define RSMXO_VAL_DIGITAL_CHANNEL_D10                                       10
#define RSMXO_VAL_DIGITAL_CHANNEL_D11                                       11
#define RSMXO_VAL_DIGITAL_CHANNEL_D12                                       12
#define RSMXO_VAL_DIGITAL_CHANNEL_D13                                       13
#define RSMXO_VAL_DIGITAL_CHANNEL_D14                                       14
#define RSMXO_VAL_DIGITAL_CHANNEL_D15                                       15

// RsMxo_rngLogicClockedSlope
#define RSMXO_VAL_LOGIC_CLOCKED_SLOPE_POSITIVE                              0
#define RSMXO_VAL_LOGIC_CLOCKED_SLOPE_NEGATIVE                              1
#define RSMXO_VAL_LOGIC_CLOCKED_SLOPE_EITHER                                2

// RsMxo_rngDataFormat
#define RSMXO_VAL_DATA_FORMAT_HEX                                           0
#define RSMXO_VAL_DATA_FORMAT_OCT                                           1
#define RSMXO_VAL_DATA_FORMAT_BIN                                           2
#define RSMXO_VAL_DATA_FORMAT_ASCII                                         3
#define RSMXO_VAL_DATA_FORMAT_SIGN                                          4
#define RSMXO_VAL_DATA_FORMAT_USIG                                          5
#define RSMXO_VAL_DATA_FORMAT_DEC                                           6
#define RSMXO_VAL_DATA_FORMAT_STRG                                          7

// RsMxo_rngLogicHysteresis
#define RSMXO_VAL_LOGIC_HYSTERESIS_MAXIMUM                                  0
#define RSMXO_VAL_LOGIC_HYSTERESIS_ROBUST                                   1
#define RSMXO_VAL_LOGIC_HYSTERESIS_NORMAL                                   2

// RsMxo_rngLogicTechnology
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V15                                      0
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V25                                      1
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V165                                     2
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V125                                     3
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V09                                      4
#define RSMXO_VAL_LOGIC_TECHNOLOGY_VM13                                     5
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V38                                      6
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V20                                      7
#define RSMXO_VAL_LOGIC_TECHNOLOGY_V0                                       8
#define RSMXO_VAL_LOGIC_TECHNOLOGY_MANUAL                                   9

// RsMxo_rngProbeVerticalUnit
#define RSMXO_VAL_PROBE_VERTICAL_UNIT_V                                     0
#define RSMXO_VAL_PROBE_VERTICAL_UNIT_A                                     1
#define RSMXO_VAL_PROBE_VERTICAL_UNIT_W                                     2

// RsMxo_rngVerticalProbeMicroButton
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_CONTINUOUS                    0
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_SINGLE                        1
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_AUTOSET                       2
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_AZERO                         3
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_OFFSET_TO_MEAN                4
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_SAVE_IMAGE                    5
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_NO_ACTION                     6
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_TRIGGER_LEVEL                 7
#define RSMXO_VAL_VERTICAL_PROBE_MICRO_BUTTON_PROBE_SETUP                   8

// RsMxo_rngVerticalProbeState
#define RSMXO_VAL_VERTICAL_PROBE_STATE_DETECTED                             0
#define RSMXO_VAL_VERTICAL_PROBE_STATE_NOT_DETECTED                         1

// RsMxo_rngRescaleHorizonalMode
#define RSMXO_VAL_RESCALE_HORIZONAL_MODE_ORIGINAL                           0
#define RSMXO_VAL_RESCALE_HORIZONAL_MODE_COUPLED                            1

// RsMxo_rngRescaleVerticalMode
#define RSMXO_VAL_RESCALE_VERTICAL_MODE_COUPLED                             0
#define RSMXO_VAL_RESCALE_VERTICAL_MODE_INDEPENDENT                         1

// RsMxo_rngReferenceLevelRelativeMode
#define RSMXO_VAL_REFERENCE_LEVEL_RELATIVE_MODE_FIVE                        0
#define RSMXO_VAL_REFERENCE_LEVEL_RELATIVE_MODE_TEN                         1
#define RSMXO_VAL_REFERENCE_LEVEL_RELATIVE_MODE_TWENTY                      2
#define RSMXO_VAL_REFERENCE_LEVEL_RELATIVE_MODE_USER                        3

// RsMxo_rngProtocolFilterBit
#define RSMXO_VAL_PROTOCOL_FILTER_BIT_ONE                                   0
#define RSMXO_VAL_PROTOCOL_FILTER_BIT_ZERO                                  1
#define RSMXO_VAL_PROTOCOL_FILTER_BIT_DC                                    2

// RsMxo_rngProcotolFilterDataOperator
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_EQUAL                       0
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_NOT_EQUAL                   1
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_LESS_THAN                   2
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_LESS_EQUAL                  3
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_GREATER_THAN                4
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_GREATER_EQUAL               5
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_IN_RANGE                    6
#define RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_OUT_OF_RANGE                7

// RsMxo_rngProtocolFilterIndexOperator
#define RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_EQUAL                      0
#define RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_INRANGE                    1
#define RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_RANG                       2

// RsMxo_rngReadWriteAccess
#define RSMXO_VAL_READ_WRITE_ACCESS_UNDEFINED                               0
#define RSMXO_VAL_READ_WRITE_ACCESS_READ                                    1
#define RSMXO_VAL_READ_WRITE_ACCESS_WRITE                                   2
#define RSMXO_VAL_READ_WRITE_ACCESS_EITHER                                  3

// RsMxo_rngProtocolResultsAddressType
#define RSMXO_VAL_PROTOCOL_RESULTS_ADDRESS_TYPE_BIT7                        0
#define RSMXO_VAL_PROTOCOL_RESULTS_ADDRESS_TYPE_BIT7RW                      1
#define RSMXO_VAL_PROTOCOL_RESULTS_ADDRESS_TYPE_BIT7_RW                     2
#define RSMXO_VAL_PROTOCOL_RESULTS_ADDRESS_TYPE_BIT10                       3
#define RSMXO_VAL_PROTOCOL_RESULTS_ADDRESS_TYPE_AUTO                        4
#define RSMXO_VAL_PROTOCOL_RESULTS_ADDRESS_TYPE_ANY                         5

// RsMxo_rngProtocolI2CResultsState
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_NOSTOPBIT                      0
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_OK                             1
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_INCOMPLETE                     2
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_ADDIFFERENT                    3
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_UNKNOWN                        4
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_UNEX                           5
#define RSMXO_VAL_PROTOCOL_I2C_RESULTS_STATE_INS                            6

// RsMxo_rngProtocolSPIBitOrder
#define RSMXO_VAL_PROTOCOL_SPI_BIT_ORDER_LSBF                               0
#define RSMXO_VAL_PROTOCOL_SPI_BIT_ORDER_MSBF                               1

// RsMxo_rngProtocolSPIResultsState
#define RSMXO_VAL_PROTOCOL_SPI_RESULTS_STATE_OK                             0
#define RSMXO_VAL_PROTOCOL_SPI_RESULTS_STATE_VOID                           1
#define RSMXO_VAL_PROTOCOL_SPI_RESULTS_STATE_INC                            2
#define RSMXO_VAL_PROTOCOL_SPI_RESULTS_STATE_LENGTH                         3

// RsMxo_rngProtocolSPIFrameCondition
#define RSMXO_VAL_PROTOCOL_SPI_FRAME_CONDITION_CS                           0
#define RSMXO_VAL_PROTOCOL_SPI_FRAME_CONDITION_CLK_TIMEOUT                  1

// RsMxo_rngProtocolSPILinePolarity
#define RSMXO_VAL_PROTOCOL_SPI_LINE_POLARITY_ACTIVE_LOW                     0
#define RSMXO_VAL_PROTOCOL_SPI_LINE_POLARITY_ACTIVE_HIGH                    1

// RsMxo_rngProtocolFilterCondition
#define RSMXO_VAL_PROTOCOL_FILTER_CONDITION_ONE                             0
#define RSMXO_VAL_PROTOCOL_FILTER_CONDITION_ZERO                            1

// RsMxo_rngProtocolUARTPacket
#define RSMXO_VAL_PROTOCOL_UART_PACKET_NONE                                 0
#define RSMXO_VAL_PROTOCOL_UART_PACKET_END_WORD                             1
#define RSMXO_VAL_PROTOCOL_UART_PACKET_TIMEOUT                              2

// RsMxo_rngProtocolUARTParity
#define RSMXO_VAL_PROTOCOL_UART_PARITY_NONE                                 0
#define RSMXO_VAL_PROTOCOL_UART_PARITY_ODD                                  1
#define RSMXO_VAL_PROTOCOL_UART_PARITY_EVEN                                 2
#define RSMXO_VAL_PROTOCOL_UART_PARITY_MARK                                 3
#define RSMXO_VAL_PROTOCOL_UART_PARITY_SPACE                                4
#define RSMXO_VAL_PROTOCOL_UART_PARITY_DONT_CARE                            5

// RsMxo_rngProtocolUARTPolarity
#define RSMXO_VAL_PROTOCOL_UART_POLARITY_IDLE_LOW                           0
#define RSMXO_VAL_PROTOCOL_UART_POLARITY_IDLE_HIGH                          1

// RsMxo_rngProtocolUARTStopBits
#define RSMXO_VAL_PROTOCOL_UART_STOP_BITS_B1                                0
#define RSMXO_VAL_PROTOCOL_UART_STOP_BITS_B15                               1
#define RSMXO_VAL_PROTOCOL_UART_STOP_BITS_B2                                2

// RsMxo_rngProtocolUARTWordState
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_OK                               0
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_FRSTART                          1
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_FREND                            2
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_FRME                             3
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_BREAK                            4
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_START_ERROR                      5
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_STOP_ERROR                       6
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_PARITY_ERROR                     7
#define RSMXO_VAL_PROTOCOL_UART_WORD_STATE_INCOMPLETE                       8

// RsMxo_rngInternalExternal
#define RSMXO_VAL_INTERNAL_EXTERNAL_INTERNAL                                0
#define RSMXO_VAL_INTERNAL_EXTERNAL_EXTERNAL                                1

// RsMxo_rngTriggerActionPolarity
#define RSMXO_VAL_TRIGGER_ACTION_POLARITY_POSITIVE                          0
#define RSMXO_VAL_TRIGGER_ACTION_POLARITY_NEGATIVE                          1

// RsMxo_rngTriggerEdgeCoupling
#define RSMXO_VAL_TRIGGER_EDGE_COUPLING_DC                                  0
#define RSMXO_VAL_TRIGGER_EDGE_COUPLING_DCLIMIT                             1
#define RSMXO_VAL_TRIGGER_EDGE_COUPLING_AC                                  2

// RsMxo_rngTriggerEdgeHighPass
#define RSMXO_VAL_TRIGGER_EDGE_HIGH_PASS_KHZ5                               0
#define RSMXO_VAL_TRIGGER_EDGE_HIGH_PASS_KHZ50                              1
#define RSMXO_VAL_TRIGGER_EDGE_HIGH_PASS_MHZ50                              2

// RsMxo_rngTriggerEdgeLowPass
#define RSMXO_VAL_TRIGGER_EDGE_LOW_PASS_KHZ5                                0
#define RSMXO_VAL_TRIGGER_EDGE_LOW_PASS_KHZ50                               1
#define RSMXO_VAL_TRIGGER_EDGE_LOW_PASS_MHZ50                               2

// RsMxo_rngTriggerEdgeFilter
#define RSMXO_VAL_TRIGGER_EDGE_FILTER_OFF                                   0
#define RSMXO_VAL_TRIGGER_EDGE_FILTER_LFREJECT                              1
#define RSMXO_VAL_TRIGGER_EDGE_FILTER_RFREJECT                              2

// RsMxo_rngSlope
#define RSMXO_VAL_SLOPE_POSITIVE                                            0
#define RSMXO_VAL_SLOPE_NEGATIVE                                            1
#define RSMXO_VAL_SLOPE_EITHER                                              2

// RsMxo_rngTriggerGlitchRange
#define RSMXO_VAL_TRIGGER_GLITCH_RANGE_SHORTER                              0
#define RSMXO_VAL_TRIGGER_GLITCH_RANGE_LONGER                               1

// RsMxo_rngTriggerIntervalRange
#define RSMXO_VAL_TRIGGER_INTERVAL_RANGE_WITHIN                             0
#define RSMXO_VAL_TRIGGER_INTERVAL_RANGE_OUTSIDE                            1
#define RSMXO_VAL_TRIGGER_INTERVAL_RANGE_SHORTER                            2
#define RSMXO_VAL_TRIGGER_INTERVAL_RANGE_LONGER                             3

// RsMxo_rngTriggerRuntRange
#define RSMXO_VAL_TRIGGER_RUNT_RANGE_ANY                                    0
#define RSMXO_VAL_TRIGGER_RUNT_RANGE_LONGER                                 1
#define RSMXO_VAL_TRIGGER_RUNT_RANGE_SHORTER                                2
#define RSMXO_VAL_TRIGGER_RUNT_RANGE_WITHIN                                 3
#define RSMXO_VAL_TRIGGER_RUNT_RANGE_OUTSIDE                                4

// RsMxo_rngTriggerEdge
#define RSMXO_VAL_TRIGGER_EDGE_POSITIVE                                     0
#define RSMXO_VAL_TRIGGER_EDGE_NEGATIVE                                     1
#define RSMXO_VAL_TRIGGER_EDGE_EITHER                                       2

// RsMxo_rngTriggerSlewRateRange
#define RSMXO_VAL_TRIGGER_SLEW_RATE_RANGE_INRANGE                           0
#define RSMXO_VAL_TRIGGER_SLEW_RATE_RANGE_OUTRANGE                          1
#define RSMXO_VAL_TRIGGER_SLEW_RATE_RANGE_LTHAN                             2
#define RSMXO_VAL_TRIGGER_SLEW_RATE_RANGE_GTHAN                             3

// RsMxo_rngTriggerTimeoutRange
#define RSMXO_VAL_TRIGGER_TIMEOUT_RANGE_HIGH                                0
#define RSMXO_VAL_TRIGGER_TIMEOUT_RANGE_LOW                                 1
#define RSMXO_VAL_TRIGGER_TIMEOUT_RANGE_EITHER                              2

// RsMxo_rngTriggerType
#define RSMXO_VAL_TRIGGER_TYPE_EDGE                                         0
#define RSMXO_VAL_TRIGGER_TYPE_GLITCH                                       1
#define RSMXO_VAL_TRIGGER_TYPE_WIDTH                                        2
#define RSMXO_VAL_TRIGGER_TYPE_RUNT                                         3
#define RSMXO_VAL_TRIGGER_TYPE_WINDOW                                       4
#define RSMXO_VAL_TRIGGER_TYPE_TIMEOUT                                      5
#define RSMXO_VAL_TRIGGER_TYPE_INTERVAL                                     6
#define RSMXO_VAL_TRIGGER_TYPE_SLEWRATE                                     7
#define RSMXO_VAL_TRIGGER_TYPE_SETHOLD                                      8
#define RSMXO_VAL_TRIGGER_TYPE_STATE                                        9
#define RSMXO_VAL_TRIGGER_TYPE_PATTERN                                      10
#define RSMXO_VAL_TRIGGER_TYPE_ANEDGE                                       11

// RsMxo_rngTriggerWidthRange
#define RSMXO_VAL_TRIGGER_WIDTH_RANGE_WITHIN                                0
#define RSMXO_VAL_TRIGGER_WIDTH_RANGE_OUTSIDE                               1
#define RSMXO_VAL_TRIGGER_WIDTH_RANGE_SHORTER                               2
#define RSMXO_VAL_TRIGGER_WIDTH_RANGE_LONGER                                3

// RsMxo_rngTriggerVerticalCondition
#define RSMXO_VAL_TRIGGER_VERTICAL_CONDITION_ENTER                          0
#define RSMXO_VAL_TRIGGER_VERTICAL_CONDITION_EXIT                           1
#define RSMXO_VAL_TRIGGER_VERTICAL_CONDITION_WITHIN                         2
#define RSMXO_VAL_TRIGGER_VERTICAL_CONDITION_OUTSIDE                        3

// RsMxo_rngTriggerTimeCondition
#define RSMXO_VAL_TRIGGER_TIME_CONDITION_WITHIN                             0
#define RSMXO_VAL_TRIGGER_TIME_CONDITION_OUTSIDE                            1
#define RSMXO_VAL_TRIGGER_TIME_CONDITION_SHORTER                            2
#define RSMXO_VAL_TRIGGER_TIME_CONDITION_LONGER                             3

// RsMxo_rngTriggerFilterMode
#define RSMXO_VAL_TRIGGER_FILTER_MODE_OFF                                   0
#define RSMXO_VAL_TRIGGER_FILTER_MODE_LFREJECT                              1
#define RSMXO_VAL_TRIGGER_FILTER_MODE_RFREJECT                              2

// RsMxo_rngTriggerHoldoffMode
#define RSMXO_VAL_TRIGGER_HOLDOFF_MODE_OFF                                  0
#define RSMXO_VAL_TRIGGER_HOLDOFF_MODE_TIME                                 1
#define RSMXO_VAL_TRIGGER_HOLDOFF_MODE_EVENTS                               2
#define RSMXO_VAL_TRIGGER_HOLDOFF_MODE_RANDOM                               3
#define RSMXO_VAL_TRIGGER_HOLDOFF_MODE_AUTO                                 4

// RsMxo_rngTriggerOn
#define RSMXO_VAL_TRIGGER_ON_SINGLE                                         0
#define RSMXO_VAL_TRIGGER_ON_SEQUENCE                                       1

// RsMxo_rngTriggerMode
#define RSMXO_VAL_TRIGGER_MODE_AUTO                                         0
#define RSMXO_VAL_TRIGGER_MODE_NORMAL                                       1
#define RSMXO_VAL_TRIGGER_MODE_FREERUN                                      2

// RsMxo_rngTriggerReadWriteAccess
#define RSMXO_VAL_TRIGGER_READ_WRITE_ACCESS_READ                            0
#define RSMXO_VAL_TRIGGER_READ_WRITE_ACCESS_WRITE                           1
#define RSMXO_VAL_TRIGGER_READ_WRITE_ACCESS_EITHER                          2

// RsMxo_rngConditionOperator
#define RSMXO_VAL_CONDITION_OPERATOR_EQUAL                                  0
#define RSMXO_VAL_CONDITION_OPERATOR_NOT_EQUAL                              1
#define RSMXO_VAL_CONDITION_OPERATOR_LESS_THAN                              2
#define RSMXO_VAL_CONDITION_OPERATOR_LESS_EQUAL                             3
#define RSMXO_VAL_CONDITION_OPERATOR_GREATER_THAN                           4
#define RSMXO_VAL_CONDITION_OPERATOR_GREATER_EQUAL                          5
#define RSMXO_VAL_CONDITION_OPERATOR_IN_RANGE                               6
#define RSMXO_VAL_CONDITION_OPERATOR_OF_RANGE                               7

// RsMxo_rngProtocolTriggerAddressType
#define RSMXO_VAL_PROTOCOL_TRIGGER_ADDRESS_TYPE_BIT7                        0
#define RSMXO_VAL_PROTOCOL_TRIGGER_ADDRESS_TYPE_BIT10                       2

// RsMxo_rngProtocolI2CTriggerType
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_START                           0
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_REPSTART                        1
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_STOP                            2
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_NACK                            3
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_ADDRESS                         4
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_DATA                            5
#define RSMXO_VAL_PROTOCOL_I2C_TRIGGER_TYPE_ADAT                            6

// RsMxo_rngTriggerSizeMode
#define RSMXO_VAL_TRIGGER_SIZE_MODE_ABS                                     0
#define RSMXO_VAL_TRIGGER_SIZE_MODE_REL                                     1

// RsMxo_rngTriggerHysteresisMode
#define RSMXO_VAL_TRIGGER_HYSTERESIS_MODE_AUTO                              0
#define RSMXO_VAL_TRIGGER_HYSTERESIS_MODE_MANUAL                            1

// RsMxo_rngTriggerSPISearchMode
#define RSMXO_VAL_TRIGGER_SPI_SEARCH_MODE_WORD                              0
#define RSMXO_VAL_TRIGGER_SPI_SEARCH_MODE_BIT                               1

// RsMxo_rngProtocolSPITriggerType
#define RSMXO_VAL_PROTOCOL_SPI_TRIGGER_TYPE_FRAME_START                     0
#define RSMXO_VAL_PROTOCOL_SPI_TRIGGER_TYPE_FRAME_END                       1
#define RSMXO_VAL_PROTOCOL_SPI_TRIGGER_TYPE_MOSI                            2
#define RSMXO_VAL_PROTOCOL_SPI_TRIGGER_TYPE_MISO                            3

// RsMxo_rngUARTSource
#define RSMXO_VAL_UART_SOURCE_TX                                            0
#define RSMXO_VAL_UART_SOURCE_RX                                            1

// RsMxo_rngUARTTriggerType
#define RSMXO_VAL_UART_TRIGGER_TYPE_START_BIT                               0
#define RSMXO_VAL_UART_TRIGGER_TYPE_PACKET_START                            1
#define RSMXO_VAL_UART_TRIGGER_TYPE_DATA                                    2
#define RSMXO_VAL_UART_TRIGGER_TYPE_PARITY_ERROR                            3
#define RSMXO_VAL_UART_TRIGGER_TYPE_BREAK_CONDITION                         4
#define RSMXO_VAL_UART_TRIGGER_TYPE_STOP_ERROR                              5

// RsMxo_rngGeneratorArbitraryRunMode
#define RSMXO_VAL_GENERATOR_ARBITRARY_RUN_MODE_SINGLE                       0
#define RSMXO_VAL_GENERATOR_ARBITRARY_RUN_MODE_REPETITIVE                   1

// RsMxo_rngArbitrarySignalSource
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C1W1                              0
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C1W2                              1
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C1W3                              2
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C2W1                              3
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C2W2                              4
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C2W3                              5
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C3W1                              6
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C3W2                              7
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C3W3                              8
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C4W1                              9
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C4W2                              10
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_C4W3                              11
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_R1                                12
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_R2                                13
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_R3                                14
#define RSMXO_VAL_ARBITRARY_SIGNAL_SOURCE_R4                                15

// RsMxo_rngArbitrarySource
#define RSMXO_VAL_ARBITRARY_SOURCE_ARBITRARY                                0
#define RSMXO_VAL_ARBITRARY_SOURCE_SCOPE                                    1

// RsMxo_rngGeneratorFunctionType
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_SINUSOID                          0
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_SQUARE                            1
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_RAMP                              2
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_DC                                3
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_PULSE                             4
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_SINC                              5
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_CARDIAC                           6
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_GAUSS                             7
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_LORNTZ                            8
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_EXPRISE                           9
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_EXPFALL                           10
#define RSMXO_VAL_GENERATOR_FUNCTION_TYPE_ARBITRARY                         11

// RsMxo_rngModulationSignalType
#define RSMXO_VAL_MODULATION_SIGNAL_TYPE_SINUSOID                           0
#define RSMXO_VAL_MODULATION_SIGNAL_TYPE_SQUARE                             1
#define RSMXO_VAL_MODULATION_SIGNAL_TYPE_RAMP                               2

// RsMxo_rngModulationType
#define RSMXO_VAL_MODULATION_TYPE_NONE                                      0
#define RSMXO_VAL_MODULATION_TYPE_AM                                        1
#define RSMXO_VAL_MODULATION_TYPE_FM                                        2
#define RSMXO_VAL_MODULATION_TYPE_PWM                                       3
#define RSMXO_VAL_MODULATION_TYPE_ASK                                       4
#define RSMXO_VAL_MODULATION_TYPE_FSK                                       5

// RsMxo_rngGeneratorUserLoad
#define RSMXO_VAL_GENERATOR_USER_LOAD_FIFTY                                 0
#define RSMXO_VAL_GENERATOR_USER_LOAD_HIZ                                   1

// RsMxo_rngGeneratorSweepType
#define RSMXO_VAL_GENERATOR_SWEEP_TYPE_LIN                                  0
#define RSMXO_VAL_GENERATOR_SWEEP_TYPE_LOG                                  1

// RsMxo_rngColorTable
#define RSMXO_VAL_COLOR_TABLE_FALSE_COLORS                                  0
#define RSMXO_VAL_COLOR_TABLE_M_HOT                                         1
#define RSMXO_VAL_COLOR_TABLE_HSV                                           2
#define RSMXO_VAL_COLOR_TABLE_M_JET                                         3
#define RSMXO_VAL_COLOR_TABLE_SPECTRUM                                      4
#define RSMXO_VAL_COLOR_TABLE_SINGLE_EVENT                                  5
#define RSMXO_VAL_COLOR_TABLE_TEMPERATURE                                   6

// RsMxo_rngProtocolType
#define RSMXO_VAL_PROTOCOL_TYPE_I2C                                         0
#define RSMXO_VAL_PROTOCOL_TYPE_SPI                                         1
#define RSMXO_VAL_PROTOCOL_TYPE_UART                                        2
#define RSMXO_VAL_PROTOCOL_TYPE_CAN                                         3
#define RSMXO_VAL_PROTOCOL_TYPE_LIN                                         4
#define RSMXO_VAL_PROTOCOL_TYPE_SPMI                                        5
#define RSMXO_VAL_PROTOCOL_TYPE_TNOS                                        6
#define RSMXO_VAL_PROTOCOL_TYPE_HBTO                                        7

// RsMxo_rngTransferDataFormat
#define RSMXO_VAL_TRANSFER_DATA_FORMAT_ASCII                                0
#define RSMXO_VAL_TRANSFER_DATA_FORMAT_REAL32                               1
#define RSMXO_VAL_TRANSFER_DATA_FORMAT_INT8                                 2
#define RSMXO_VAL_TRANSFER_DATA_FORMAT_INT16                                3
#define RSMXO_VAL_TRANSFER_DATA_FORMAT_INT32                                4

// RsMxo_rngProtocolI2CResultsAddressAck
#define RSMXO_VAL_PROTOCOL_I2_C_RESULTS_ADDRESS_ACK_INCOMPLETE              0
#define RSMXO_VAL_PROTOCOL_I2_C_RESULTS_ADDRESS_ACK_ACK                     1
#define RSMXO_VAL_PROTOCOL_I2_C_RESULTS_ADDRESS_ACK_NACK                    2
#define RSMXO_VAL_PROTOCOL_I2_C_RESULTS_ADDRESS_ACK_EITHER                  3

// RsMxo_rngWaveformExportMode
#define RSMXO_VAL_WAVEFORM_EXPORT_MODE_DISPLAY                              0
#define RSMXO_VAL_WAVEFORM_EXPORT_MODE_ALL                                  1
#define RSMXO_VAL_WAVEFORM_EXPORT_MODE_CURSOR                               2
#define RSMXO_VAL_WAVEFORM_EXPORT_MODE_GATE                                 3
#define RSMXO_VAL_WAVEFORM_EXPORT_MODE_MANUAL                               4

// RsMxo_rngCursorSet
#define RSMXO_VAL_CURSOR_SET_1                                              1
#define RSMXO_VAL_CURSOR_SET_2                                              2
#define RSMXO_VAL_CURSOR_SET_3                                              3
#define RSMXO_VAL_CURSOR_SET_4                                              4

// RsMxo_rngSpectrumTraceType
#define RSMXO_VAL_SPECTRUM_TRACE_TYPE_NORMAL                                0
#define RSMXO_VAL_SPECTRUM_TRACE_TYPE_MINIMUM                               1
#define RSMXO_VAL_SPECTRUM_TRACE_TYPE_MAXIMUM                               2
#define RSMXO_VAL_SPECTRUM_TRACE_TYPE_AVERAGE                               3

// RsMxo_rngPeakListSource
#define RSMXO_VAL_PEAK_LIST_SOURCE_SPECTRUM_NORM1                           38
#define RSMXO_VAL_PEAK_LIST_SOURCE_SPECTRUM_MIN_HOLD1                       39
#define RSMXO_VAL_PEAK_LIST_SOURCE_SPECTRUM_MAX_HOLD1                       40
#define RSMXO_VAL_PEAK_LIST_SOURCE_SPECTRUM_AVERAGE1                        41

// RsMxo_rngMeasurementStatistics
#define RSMXO_VAL_MEASUREMENT_STATISTICS_CURRENT                            0
#define RSMXO_VAL_MEASUREMENT_STATISTICS_MAX                                1
#define RSMXO_VAL_MEASUREMENT_STATISTICS_MIN                                2
#define RSMXO_VAL_MEASUREMENT_STATISTICS_MEAN                               3
#define RSMXO_VAL_MEASUREMENT_STATISTICS_RMS                                4
#define RSMXO_VAL_MEASUREMENT_STATISTICS_STANDARD_DEVIATION                 5
#define RSMXO_VAL_MEASUREMENT_STATISTICS_EVENT_COUNT                        6
#define RSMXO_VAL_MEASUREMENT_STATISTICS_WAVE_COUNT                         7

// RsMxo_rngTriggerSource
#define RSMXO_VAL_TRIGGER_SOURCE_C1                                         0
#define RSMXO_VAL_TRIGGER_SOURCE_C2                                         1
#define RSMXO_VAL_TRIGGER_SOURCE_C3                                         2
#define RSMXO_VAL_TRIGGER_SOURCE_C4                                         3
#define RSMXO_VAL_TRIGGER_SOURCE_SBUS1                                      4
#define RSMXO_VAL_TRIGGER_SOURCE_SBUS2                                      5
#define RSMXO_VAL_TRIGGER_SOURCE_SBUS3                                      6
#define RSMXO_VAL_TRIGGER_SOURCE_SBUS4                                      7
#define RSMXO_VAL_TRIGGER_SOURCE_D0                                         8
#define RSMXO_VAL_TRIGGER_SOURCE_D1                                         9
#define RSMXO_VAL_TRIGGER_SOURCE_D2                                         10
#define RSMXO_VAL_TRIGGER_SOURCE_D3                                         11
#define RSMXO_VAL_TRIGGER_SOURCE_D4                                         12
#define RSMXO_VAL_TRIGGER_SOURCE_D5                                         13
#define RSMXO_VAL_TRIGGER_SOURCE_D6                                         14
#define RSMXO_VAL_TRIGGER_SOURCE_D7                                         15
#define RSMXO_VAL_TRIGGER_SOURCE_D8                                         16
#define RSMXO_VAL_TRIGGER_SOURCE_D9                                         17
#define RSMXO_VAL_TRIGGER_SOURCE_D10                                        18
#define RSMXO_VAL_TRIGGER_SOURCE_D11                                        19
#define RSMXO_VAL_TRIGGER_SOURCE_D12                                        20
#define RSMXO_VAL_TRIGGER_SOURCE_D13                                        21
#define RSMXO_VAL_TRIGGER_SOURCE_D14                                        22
#define RSMXO_VAL_TRIGGER_SOURCE_D15                                        23
#define RSMXO_VAL_TRIGGER_SOURCE_EXTERNAL                                   24
#define RSMXO_VAL_TRIGGER_SOURCE_LINE                                       25
#define RSMXO_VAL_TRIGGER_SOURCE_C5                                         26
#define RSMXO_VAL_TRIGGER_SOURCE_C6                                         27
#define RSMXO_VAL_TRIGGER_SOURCE_C7                                         28
#define RSMXO_VAL_TRIGGER_SOURCE_C8                                         29

// RsMxo_rngMathOperator
#define RSMXO_VAL_MATH_OPERATOR_ADDITION                                    0
#define RSMXO_VAL_MATH_OPERATOR_SUBTRACTION                                 1
#define RSMXO_VAL_MATH_OPERATOR_MULTIPLICATION                              2
#define RSMXO_VAL_MATH_OPERATOR_DIVISION                                    3
#define RSMXO_VAL_MATH_OPERATOR_ABSOLUTE_VALUE                              4
#define RSMXO_VAL_MATH_OPERATOR_DIFFERENTIAL                                5
#define RSMXO_VAL_MATH_OPERATOR_INTEGRAL                                    6
#define RSMXO_VAL_MATH_OPERATOR_LOG10                                       7
#define RSMXO_VAL_MATH_OPERATOR_LOG_NATURAL                                 8
#define RSMXO_VAL_MATH_OPERATOR_BINARY_LOG                                  9
#define RSMXO_VAL_MATH_OPERATOR_SQUARE                                      10
#define RSMXO_VAL_MATH_OPERATOR_ROOT                                        11
#define RSMXO_VAL_MATH_OPERATOR_RESCALE                                     12
#define RSMXO_VAL_MATH_OPERATOR_NEGATE                                      13
#define RSMXO_VAL_MATH_OPERATOR_INVERSE                                     14

// RsMxo_rngMathSource
#define RSMXO_VAL_MATH_SOURCE_NONE                                          0
#define RSMXO_VAL_MATH_SOURCE_C1                                            1
#define RSMXO_VAL_MATH_SOURCE_C2                                            2
#define RSMXO_VAL_MATH_SOURCE_C3                                            3
#define RSMXO_VAL_MATH_SOURCE_C4                                            4
#define RSMXO_VAL_MATH_SOURCE_C5                                            5
#define RSMXO_VAL_MATH_SOURCE_C6                                            6
#define RSMXO_VAL_MATH_SOURCE_C7                                            7
#define RSMXO_VAL_MATH_SOURCE_C8                                            8
#define RSMXO_VAL_MATH_SOURCE_M1                                            29
#define RSMXO_VAL_MATH_SOURCE_M2                                            30
#define RSMXO_VAL_MATH_SOURCE_M3                                            31
#define RSMXO_VAL_MATH_SOURCE_M4                                            32
#define RSMXO_VAL_MATH_SOURCE_M5                                            33
#define RSMXO_VAL_MATH_SOURCE_R1                                            34
#define RSMXO_VAL_MATH_SOURCE_R2                                            35
#define RSMXO_VAL_MATH_SOURCE_R3                                            36
#define RSMXO_VAL_MATH_SOURCE_R4                                            37

// RsMxo_rngMathSignalType
#define RSMXO_VAL_MATH_SIGNAL_TYPE_NONE                                     0
#define RSMXO_VAL_MATH_SIGNAL_TYPE_SOURCE                                   1
#define RSMXO_VAL_MATH_SIGNAL_TYPE_CORRELATION                              2
#define RSMXO_VAL_MATH_SIGNAL_TYPE_MEASUREMENT                              3
#define RSMXO_VAL_MATH_SIGNAL_TYPE_MATH                                     4

// RsMxo_rngMathEnvelopeWaveformSelection
#define RSMXO_VAL_MATH_ENVELOPE_WAVEFORM_SELECTION_MIN                      0
#define RSMXO_VAL_MATH_ENVELOPE_WAVEFORM_SELECTION_MAX                      1
#define RSMXO_VAL_MATH_ENVELOPE_WAVEFORM_SELECTION_BOTH                     2

// RsMxo_rngMathVerticalScaleMode
#define RSMXO_VAL_MATH_VERTICAL_SCALE_MODE_MANUAL                           0
#define RSMXO_VAL_MATH_VERTICAL_SCALE_MODE_AUTO                             1

// RsMxo_rngCursorEnvelope
#define RSMXO_VAL_CURSOR_ENVELOPE_MIN                                       0
#define RSMXO_VAL_CURSOR_ENVELOPE_MAX                                       1

// RsMxo_rngFrequencyResponseAnalysisAmplitudeMode
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_MODE_CONSTANT       0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_MODE_PROFILE        1

// RsMxo_rngFrequencyResponseAnalysisAmplitudeProfileVoltageChange
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_VOLTAGE_CHANGE_SINGLE 0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_VOLTAGE_CHANGE_RAMP 1

// RsMxo_rngFrequencyResponseAnalysisUserGeneratorLoad
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_USER_GENERATOR_LOAD_FIFTY     0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_USER_GENERATOR_LOAD_HIZ       1

// RsMxo_rngFrequencyResponseAnalysisInputOutput
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C1               1
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C2               2
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C3               3
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C4               4
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C5               5
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C6               6
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C7               7
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_INPUT_OUTPUT_C8               8

// RsMxo_rngFrequencyResponseAnalysisRBW
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_RBW_HIGH                      0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_RBW_MEDIUM                    1
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_RBW_LOW                       2

// RsMxo_rngFrequencyResponseAnalysisPointsMode
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE_TOTAL             0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE_DECADE            1

// RsMxo_rngFrequencyResponseAnalysisMeasurement
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_MEASUREMENT_STOP              0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_MEASUREMENT_RUN               1

// RsMxo_rngGateCouplingMode
#define RSMXO_VAL_GATE_COUPLING_MODE_MANUAL                                 0
#define RSMXO_VAL_GATE_COUPLING_MODE_CURSOR                                 1
#define RSMXO_VAL_GATE_COUPLING_MODE_ZOOM                                   2
#define RSMXO_VAL_GATE_COUPLING_MODE_SPECTRUM                               3

// RsMxo_rngMeasurementEnvelope
#define RSMXO_VAL_MEASUREMENT_ENVELOPE_MIN                                  0
#define RSMXO_VAL_MEASUREMENT_ENVELOPE_MAX                                  1
#define RSMXO_VAL_MEASUREMENT_ENVELOPE_BOTH                                 2

// RsMxo_rngProbeVoltageRange
#define RSMXO_VAL_PROBE_VOLTAGE_RANGE_AUTO                                  0
#define RSMXO_VAL_PROBE_VOLTAGE_RANGE_HIGH                                  1
#define RSMXO_VAL_PROBE_VOLTAGE_RANGE_LOW                                   2

// RsMxo_rngProbePredefinedType
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_NONE                                0
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_USER                                1
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZC10                                2
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZC20                                3
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZC30                                4
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZD01A100                            5
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZD01A1000                           6
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZS10L                               7
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZC02100                             8
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZC021000                            9
#define RSMXO_VAL_PROBE_PREDEFINED_TYPE_ZC03                                10

// RsMxo_rngProbeDisplay
#define RSMXO_VAL_PROBE_DISPLAY_DIFFERENTIAL                                0
#define RSMXO_VAL_PROBE_DISPLAY_SINGLE_ENDED                                1

// RsMxo_rngProtocolCANFormError
#define RSMXO_VAL_PROTOCOL_CAN_FORM_ERROR_NONE                              0
#define RSMXO_VAL_PROTOCOL_CAN_FORM_ERROR_CRC_DELIMITER                     1
#define RSMXO_VAL_PROTOCOL_CAN_FORM_ERROR_ACK_DELIMITER                     2
#define RSMXO_VAL_PROTOCOL_CAN_FORM_ERROR_FIXED_STUFF_BIT                   3
#define RSMXO_VAL_PROTOCOL_CAN_FORM_ERROR_RESERVED_BIT                      4

// RsMxo_rngProtocolCANResultState
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_OK                              0
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_ERROR                           1
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_UNDEFINED                       2
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_BTST                            3
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_EOFD                            4
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_ACKD                            5
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_NOACK                           6
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_CRCD                            7
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_CRC                             8
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_SERR                            9
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_FORM                            10
#define RSMXO_VAL_PROTOCOL_CAN_RESULT_STATE_INC                             11

// RsMxo_rngProtocolCANFrameType
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_CBFF                              0
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_CBFR                              1
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_CEFF                              2
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_CEFR                              3
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_FBFF                              4
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_FEFF                              5
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_XLFF                              6
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_ERR                               7
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_OVLD                              8
#define RSMXO_VAL_PROTOCOL_CAN_FRAME_TYPE_UND                               9

// RsMxo_rngProtocolCANType
#define RSMXO_VAL_PROTOCOL_CAN_TYPE_HIGH                                    0
#define RSMXO_VAL_PROTOCOL_CAN_TYPE_LOW                                     1

// RsMxo_rngProtocolTriggerDLCOperator
#define RSMXO_VAL_PROTOCOL_TRIGGER_DLC_OPERATOR_EQUAL                       0
#define RSMXO_VAL_PROTOCOL_TRIGGER_DLC_OPERATOR_GETHAN                      1

// RsMxo_rngCANTriggerFrameType
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_CBFF                               0
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_CBFR                               1
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_CEFF                               2
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_ERROR                              3
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_OVERLOAD                           4
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_CEFR                               5
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_FBFF                               6
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_FEFF                               7
#define RSMXO_VAL_CAN_TRIGGER_FRAME_TYPE_XLFF                               8

// RsMxo_rngCANTriggerIdentifierType
#define RSMXO_VAL_CAN_TRIGGER_IDENTIFIER_TYPE_ANY                           0
#define RSMXO_VAL_CAN_TRIGGER_IDENTIFIER_TYPE_B11                           1
#define RSMXO_VAL_CAN_TRIGGER_IDENTIFIER_TYPE_B29                           2

// RsMxo_rngCANTriggerType
#define RSMXO_VAL_CAN_TRIGGER_TYPE_START                                    0
#define RSMXO_VAL_CAN_TRIGGER_TYPE_END                                      1
#define RSMXO_VAL_CAN_TRIGGER_TYPE_FRAME_TYPE                               2
#define RSMXO_VAL_CAN_TRIGGER_TYPE_IDENTIFIER                               3
#define RSMXO_VAL_CAN_TRIGGER_TYPE_IDENTIFIER_DATA                          4
#define RSMXO_VAL_CAN_TRIGGER_TYPE_ERROR_CONDITION                          5

// RsMxo_rngTriggerChannel
#define RSMXO_VAL_TRIGGER_CHANNEL_HIGH                                      0
#define RSMXO_VAL_TRIGGER_CHANNEL_LOW                                       1
#define RSMXO_VAL_TRIGGER_CHANNEL_DONTCARE                                  2

// RsMxo_rngTriggerStateOperator
#define RSMXO_VAL_TRIGGER_STATE_OPERATOR_AND                                0
#define RSMXO_VAL_TRIGGER_STATE_OPERATOR_OR                                 1

// RsMxo_rngTriggerSequenceType
#define RSMXO_VAL_TRIGGER_SEQUENCE_TYPE_A_ONLY                              0
#define RSMXO_VAL_TRIGGER_SEQUENCE_TYPE_ABR                                 1

// RsMxo_rngReferenceWaveformSource
#define RSMXO_VAL_SOURCE_M6                                                 45
#define RSMXO_VAL_SOURCE_M7                                                 46
#define RSMXO_VAL_SOURCE_M8                                                 47
#define RSMXO_VAL_SOURCE_R5                                                 48
#define RSMXO_VAL_SOURCE_R6                                                 49
#define RSMXO_VAL_SOURCE_R7                                                 50
#define RSMXO_VAL_SOURCE_R8                                                 51

// RsMxo_rngWaveformSource
#define RSMXO_VAL_SOURCE_HARMONICS1                                         42
#define RSMXO_VAL_SOURCE_HARMONICS2                                         43
#define RSMXO_VAL_SOURCE_HARMONICS3                                         44

// RsMxo_rngGenerator
#define RSMXO_VAL_GENERATOR1                                                1
#define RSMXO_VAL_GENERATOR2                                                2

// RsMxo_rngDataConditionOperator
#define RSMXO_VAL_CONDITION_OPERATOR_OFF                                    6
#define RSMXO_VAL_CONDITION_OPERATOR_ANY                                    7

// RsMxo_rngMemoryCatalogFormat
#define RSMXO_VAL_MEMORY_CATALOG_FORMAT_ALL                                 0
#define RSMXO_VAL_MEMORY_CATALOG_FORMAT_WITH_TIME                           1

// RsMxo_rngSpectrumPeakListSort
#define RSMXO_VAL_SPECTRUM_PEAK_LIST_SORT_FREQ                              0
#define RSMXO_VAL_SPECTRUM_PEAK_LIST_SORT_VAL                               1

// RsMxo_rngSpectrumPeakListSortOrder
#define RSMXO_VAL_SPECTRUM_PEAK_LIST_SORT_ORDER_ASC                         0
#define RSMXO_VAL_SPECTRUM_PEAK_LIST_SORT_ORDER_DESC                        1

// RsMxo_rngXDataConditionOperator
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_EQUAL                            0
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_NOT_EQUAL                        1
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_LESS_THAN                        2
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_LESS_EQUAL                       3
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_GREATER_THAN                     4
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_GREATER_EQUAL                    5
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_INR                              6
#define RSMXO_VAL_XDATA_CONDITION_OPERATOR_OOR                              7

// RsMxo_rngProtocolCANXDataTriggerSEC
#define RSMXO_VAL_PROTOCOL_CANX_DATA_TRIGGER_SEC_ONE                        0
#define RSMXO_VAL_PROTOCOL_CANX_DATA_TRIGGER_SEC_ZERO                       1
#define RSMXO_VAL_PROTOCOL_CANX_DATA_TRIGGER_SEC_DC                         2

// RsMxo_rngFrequencyResponseAnalysisCalibrationResult
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_RESULT_PASS       0
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_RESULT_FAIL       1
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_RESULT_RUN        2
#define RSMXO_VAL_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_RESULT_NOAL       3

// RsMxo_rngHorizontalRollEnabled
#define RSMXO_VAL_HORIZONTAL_ROLL_ENABLED_AUTO                              0
#define RSMXO_VAL_HORIZONTAL_ROLL_ENABLED_OFF                               1

// RsMxo_rngDisplayBacklightUserInactivity
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_OFF                     0
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_1MINUTE                 1
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_2MINUTES                2
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_3MINUTES                3
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_5MINUTES                4
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_10MINUTES               5
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_15MINUTES               6
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_20MINUTES               7
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_25MINUTES               8
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_30MINUTES               9
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_45MINUTES               10
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_1HOUR                   11
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_2HOURS                  12
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_3HOURS                  13
#define RSMXO_VAL_DISPLAY_BACKLIGHT_USER_INACTIVITY_4HOURS                  14

// RsMxo_rngProtocolTransceiverMode
#define RSMXO_VAL_PROTOCOL_TRANSCEIVER_MODE_SIC                             0
#define RSMXO_VAL_PROTOCOL_TRANSCEIVER_MODE_FAST                            1

// RsMxo_rngProtocolFieldOperator
#define RSMXO_VAL_PROTOCOL_FIELD_OPERATOR_ONE                               0
#define RSMXO_VAL_PROTOCOL_FIELD_OPERATOR_ZERO                              1

// RsMxo_rngProtocolLINByteState
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_OK                                0
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_WAKEUP                            1
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_CHCEKSUM                          2
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_PARITY_RERROR                     3
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_STOP_ERROR                        4
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_SYNC_ERROR                        5
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_LENGTH_ERROR                      6
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_UNKOWN                            7
#define RSMXO_VAL_PROTOCOL_LIN_BYTE_STATE_TRUNCATED                         8

// RsMxo_rngProtocolLINFrameIDState
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_OK                            0
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_WAKEUP                        1
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_CHCEKSUM                      2
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_PARITY_RERROR                 3
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_UART                          4
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_VERS                          5
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_SPERROR                       6
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_SYNC_ERROR                    7
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_LENER                         8
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_CPERROR                       9
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_INCOMPLETE                    10
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_ID_STATE_INER                          11

// RsMxo_rngProtocolLINFrameState
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_OK                               0
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_WAKEUP                           1
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_CHECKSUM                         2
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_PARITY_RERROR                    3
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_STOP_ERROR                       4
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_SYNCHRONIZATION_ERROR            5
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_LENGTH_ERROR                     6
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_UNKNOWN                          7
#define RSMXO_VAL_PROTOCOL_LIN_FRAME_STATE_INCOPMLETE                       8

// RsMxo_rngProtocolLINPolarity
#define RSMXO_VAL_PROTOCOL_LIN_POLARITY_IDLE_LOW                            0
#define RSMXO_VAL_PROTOCOL_LIN_POLARITY_IDLE_HIGH                           1

// RsMxo_rngProtocolLINStandard
#define RSMXO_VAL_PROTOCOL_LIN_STANDARD_AUTO                                0
#define RSMXO_VAL_PROTOCOL_LIN_STANDARD_V1X                                 1
#define RSMXO_VAL_PROTOCOL_LIN_STANDARD_V2X                                 2
#define RSMXO_VAL_PROTOCOL_LIN_STANDARD_J2602                               3

// RsMxo_rngProtocolUARTBitOrder
#define RSMXO_VAL_PROTOCOL_UART_BIT_ORDER_LSBF                              0
#define RSMXO_VAL_PROTOCOL_UART_BIT_ORDER_MSBF                              1

// RsMxo_rngTriggerDigitalChannelState
#define RSMXO_VAL_TRIGGER_DIGITAL_CHANNEL_STATE_HIGH                        0
#define RSMXO_VAL_TRIGGER_DIGITAL_CHANNEL_STATE_LOW                         1
#define RSMXO_VAL_TRIGGER_DIGITAL_CHANNEL_STATE_DONT_CARE                   2

// RsMxo_rngTriggerDigitalStateOperator
#define RSMXO_VAL_TRIGGER_DIGITAL_STATE_OPERATOR_AND                        0
#define RSMXO_VAL_TRIGGER_DIGITAL_STATE_OPERATOR_OR                         1

// RsMxo_rngTriggerPatternStateSources
#define RSMXO_VAL_TRIGGER_PATTERN_STATE_SOURCES_ANALOG                      0
#define RSMXO_VAL_TRIGGER_PATTERN_STATE_SOURCES_DIGITAL                     1

// RsMxo_rngProtocolLINTriggerIdentifier
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_EQUAL                     0
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_NOT_EQUAL                 1
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_LESS_THAN                 2
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_LESS_OR_EQUAL             3
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_GREATER_THAN              4
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_GREATER_OR_EQUAL          5
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_IN_RANGE                  6
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_OUT_OF_RANGE              7

// RsMxo_rngProtocolLINTriggerType
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_TYPE_SYNC                            0
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_TYPE_ID                              1
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_TYPE_ID_DATA                         2
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_TYPE_WAKEUP_FRAME                    3
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_TYPE_ERROR_CONDITION                 4

// RsMxo_rngProtocolLINTriggerDataOperator
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR_EQUAL                  0
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR_NOT_EQUAL              1
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR_LESS_THAN              2
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR_LESS_OR_EQUAL          3
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR_GREATER_THAN           4
#define RSMXO_VAL_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR_GREATER_OR_EQUAL       5

// RsMxo_rngPowerAnalysisType
#define RSMXO_VAL_POWER_ANALYSIS_TYPE_QUALITY                               0
#define RSMXO_VAL_POWER_ANALYSIS_TYPE_HARMONICS                             1

// RsMxo_rngPowerAnalysisSource
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C1                                  0
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C2                                  1
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C3                                  2
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C4                                  3
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C5                                  4
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C6                                  5
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C7                                  6
#define RSMXO_VAL_POWER_ANALYSIS_SOURCE_C8                                  7

// RsMxo_rngPowerAnalysisQualityFrequency
#define RSMXO_VAL_POWER_ANALYSIS_QUALITY_FREQUENCY_F50                      0
#define RSMXO_VAL_POWER_ANALYSIS_QUALITY_FREQUENCY_F60                      1
#define RSMXO_VAL_POWER_ANALYSIS_QUALITY_FREQUENCY_F400                     2
#define RSMXO_VAL_POWER_ANALYSIS_QUALITY_FREQUENCY_USER                     3
#define RSMXO_VAL_POWER_ANALYSIS_QUALITY_FREQUENCY_AUTO                     4

// RsMxo_rngPowerAnalysisHarmonicsStandard
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_STANDARD_ENA                     0
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_STANDARD_ENB                     1
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_STANDARD_ENC                     2
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_STANDARD_END                     3
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_STANDARD_MIL                     4
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_STANDARD_RTCA                    5

// RsMxo_rngPowerAnalysisHarmonicsFundamentalFrequencyEN
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_EN_F50     0
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_EN_F60     1
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_EN_AUTO    2

// RsMxo_rngPowerAnalysisHarmonicsFundamentalFrequencyMIL
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_MIL_F60    0
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_MIL_F400   1

// RsMxo_rngPowerAnalysisHarmonicsFundamentalFrequencyRTCA
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_RTCA_F400  0
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_RTCA_NVF   1
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_FUNDAMENTAL_FREQUENCY_RTCA_WVF   2

// RsMxo_rngPowerAnalysisHarmonicsDisplay
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_DISPLAY_ALL                      0
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_DISPLAY_EVEN                     1
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_DISPLAY_ODD                      2
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_DISPLAY_STANDARD                 3

// RsMxo_rngPowerAnalysisHarmonicsScaling
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_SCALING_LIN                      0
#define RSMXO_VAL_POWER_ANALYSIS_HARMONICS_SCALING_LOG                      1

// RsMxo_rngPowerAnalysisRefLevelRelativeLevels
#define RSMXO_VAL_POWER_ANALYSIS_REF_LEVEL_RELATIVE_LEVELS_FIVE             0
#define RSMXO_VAL_POWER_ANALYSIS_REF_LEVEL_RELATIVE_LEVELS_TEN              1
#define RSMXO_VAL_POWER_ANALYSIS_REF_LEVEL_RELATIVE_LEVELS_TWENTY           2
#define RSMXO_VAL_POWER_ANALYSIS_REF_LEVEL_RELATIVE_LEVELS_USER             3

// RsMxo_rngDigitalVoltmeterBW
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B20M                                 0
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B10M                                 1
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B5M                                  2
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B2M                                  3
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B1M                                  4
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B500                                 5
#define RSMXO_VAL_DIGITAL_VOLTMETER_BW_B200                                 6

// RsMxo_rngReferenceWaveformXAxisMode
#define RSMXO_VAL_REFERENCE_WAVEFORM_X_AXIS_MODE_LIN                        0
#define RSMXO_VAL_REFERENCE_WAVEFORM_X_AXIS_MODE_LOG                        1

// RsMxo_rngTriggerActionSignalSource
#define RSMXO_VAL_TRIGGER_ACTION_SIGNAL_SOURCE_TRIG                         0
#define RSMXO_VAL_TRIGGER_ACTION_SIGNAL_SOURCE_POST                         1
#define RSMXO_VAL_TRIGGER_ACTION_SIGNAL_SOURCE_WAIT                         2

// RsMxo_rngProtocolExportExtension
#define RSMXO_VAL_PROTOCOL_EXPORT_EXTENSION_HTML                            0
#define RSMXO_VAL_PROTOCOL_EXPORT_EXTENSION_CSV                             1
#define RSMXO_VAL_PROTOCOL_EXPORT_EXTENSION_XML                             2
#define RSMXO_VAL_PROTOCOL_EXPORT_EXTENSION_PY                              3

// RsMxo_rngVerticalLabelSignal
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C1                                  0
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C2                                  1
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C3                                  2
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C4                                  3
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C5                                  4
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C6                                  5
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C7                                  6
#define RSMXO_VAL_VERTICAL_LABEL_SIGNAL_C8                                  7

// RsMxo_rngProbeModularMeasurementMode
#define RSMXO_VAL_PROBE_MODULAR_MEASUREMENT_MODE_DMOD                       0
#define RSMXO_VAL_PROBE_MODULAR_MEASUREMENT_MODE_CMOD                       1
#define RSMXO_VAL_PROBE_MODULAR_MEASUREMENT_MODE_PMOD                       2
#define RSMXO_VAL_PROBE_MODULAR_MEASUREMENT_MODE_NMOD                       3

// RsMxo_rngProbeTerminationMode
#define RSMXO_VAL_PROBE_TERMINATION_MODE_AUTO                               0
#define RSMXO_VAL_PROBE_TERMINATION_MODE_MAN                                1

// RsMxo_rngProtocolSPMIResultsState
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_OK                            0
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_NOR                           1
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_ACK                           2
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_BPER                          3
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_PAR                           4
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_LEN                           5
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_ARB                           6
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_SSC                           7
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_CMD                           8
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_COD                           9
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_STATE_INC                           10

// RsMxo_rngProtocolSPMIResultsFrameType
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_RZWR                     0
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_RWR                      1
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_RRD                      2
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_ERWR                     3
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_ERRD                     4
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_ERWL                     5
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_ERRL                     6
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_MAWR                     7
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_MARD                     8
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_BMRD                     9
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_BSRD                     10
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_TBOW                     11
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_REST                     12
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_SLEP                     13
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_SHUT                     14
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_WAK                      15
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_AUTH                     16
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_INV                      17
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_UNKN                     18
#define RSMXO_VAL_PROTOCOL_SPMI_RESULTS_FRAME_TYPE_ARB                      19

// RsMxo_rngProtocolTNOSByteState
#define RSMXO_VAL_PROTOCOL_TNOS_BYTE_STATE_OK                               0
#define RSMXO_VAL_PROTOCOL_TNOS_BYTE_STATE_EPRM                             1
#define RSMXO_VAL_PROTOCOL_TNOS_BYTE_STATE_ESFD                             2
#define RSMXO_VAL_PROTOCOL_TNOS_BYTE_STATE_EESD                             3
#define RSMXO_VAL_PROTOCOL_TNOS_BYTE_STATE_ECRC                             4
#define RSMXO_VAL_PROTOCOL_TNOS_BYTE_STATE_INC                              5

// RsMxo_rngProtocolHBTOResultsState
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_OK                            0
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_EPRM                          1
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_ESFD                          2
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_ELEN                          3
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_ECRC                          4
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_UNC                           5
#define RSMXO_VAL_PROTOCOL_HBTO_RESULTS_STATE_INC                           6

// RsMxo_rngProtocolHBTOFrameType
#define RSMXO_VAL_PROTOCOL_HBTO_FRAME_TYPE_IDLE                             0
#define RSMXO_VAL_PROTOCOL_HBTO_FRAME_TYPE_MAC                              1
#define RSMXO_VAL_PROTOCOL_HBTO_FRAME_TYPE_FILTER                           2
#define RSMXO_VAL_PROTOCOL_HBTO_FRAME_TYPE_UNKN                             3

// RsMxo_rngProtocolHBTOMode
#define RSMXO_VAL_PROTOCOL_HBTO_MODE_MAIN                                   0
#define RSMXO_VAL_PROTOCOL_HBTO_MODE_SUB                                    1
#define RSMXO_VAL_PROTOCOL_HBTO_MODE_AUTO                                   2

// RsMxo_rngProtocolHBTOPolarity
#define RSMXO_VAL_PROTOCOL_HBTO_POLARITY_NORM                               0
#define RSMXO_VAL_PROTOCOL_HBTO_POLARITY_INV                                1

// RsMxo_rngHarmQual
#define RSMXO_VAL_HARM_QUAL_HARM                                            0
#define RSMXO_VAL_HARM_QUAL_QUAL                                            1

// RsMxo_rngProtocolTNOSResultsFrameType
#define RSMXO_VAL_PROTOCOL_TNOS_RESULTS_FRAME_TYPE_UNKNOWN                  0
#define RSMXO_VAL_PROTOCOL_TNOS_RESULTS_FRAME_TYPE_MAC                      1
#define RSMXO_VAL_PROTOCOL_TNOS_RESULTS_FRAME_TYPE_BEACON                   2

//repcap Channel
#define RSMXO_REPCAP_CHANNEL_CH1                                            1
#define RSMXO_REPCAP_CHANNEL_CH2                                            2
#define RSMXO_REPCAP_CHANNEL_CH3                                            3
#define RSMXO_REPCAP_CHANNEL_CH4                                            4
#define RSMXO_REPCAP_CHANNEL_CH5                                            5
#define RSMXO_REPCAP_CHANNEL_CH6                                            6
#define RSMXO_REPCAP_CHANNEL_CH7                                            7
#define RSMXO_REPCAP_CHANNEL_CH8                                            8

//repcap Math
#define RSMXO_REPCAP_MATH_M1                                                1
#define RSMXO_REPCAP_MATH_M2                                                2
#define RSMXO_REPCAP_MATH_M3                                                3
#define RSMXO_REPCAP_MATH_M4                                                4
#define RSMXO_REPCAP_MATH_M5                                                5
#define RSMXO_REPCAP_MATH_M6                                                6
#define RSMXO_REPCAP_MATH_M7                                                7
#define RSMXO_REPCAP_MATH_M8                                                8

//repcap TriggerEvent
#define RSMXO_REPCAP_TRIGGEREVENT_TRIGA                                     1
#define RSMXO_REPCAP_TRIGGEREVENT_TRIGB                                     2
#define RSMXO_REPCAP_TRIGGEREVENT_TRIGR                                     3

//repcap Cursor
#define RSMXO_REPCAP_CURSOR_CURSOR1                                         1
#define RSMXO_REPCAP_CURSOR_CURSOR2                                         2

//repcap Generator
#define RSMXO_REPCAP_GENERATOR_GEN1                                         1
#define RSMXO_REPCAP_GENERATOR_GEN2                                         2

//repcap SerialBus
#define RSMXO_REPCAP_SERIALBUS_SB1                                          1
#define RSMXO_REPCAP_SERIALBUS_SB2                                          2
#define RSMXO_REPCAP_SERIALBUS_SB3                                          3
#define RSMXO_REPCAP_SERIALBUS_SB4                                          4

//repcap DigitalChannel
#define RSMXO_REPCAP_DIGITALCHANNEL_D0                                      0
#define RSMXO_REPCAP_DIGITALCHANNEL_D1                                      1
#define RSMXO_REPCAP_DIGITALCHANNEL_D2                                      2
#define RSMXO_REPCAP_DIGITALCHANNEL_D3                                      3
#define RSMXO_REPCAP_DIGITALCHANNEL_D4                                      4
#define RSMXO_REPCAP_DIGITALCHANNEL_D5                                      5
#define RSMXO_REPCAP_DIGITALCHANNEL_D6                                      6
#define RSMXO_REPCAP_DIGITALCHANNEL_D7                                      7
#define RSMXO_REPCAP_DIGITALCHANNEL_D8                                      8
#define RSMXO_REPCAP_DIGITALCHANNEL_D9                                      9
#define RSMXO_REPCAP_DIGITALCHANNEL_D10                                     10
#define RSMXO_REPCAP_DIGITALCHANNEL_D11                                     11
#define RSMXO_REPCAP_DIGITALCHANNEL_D12                                     12
#define RSMXO_REPCAP_DIGITALCHANNEL_D13                                     13
#define RSMXO_REPCAP_DIGITALCHANNEL_D14                                     14
#define RSMXO_REPCAP_DIGITALCHANNEL_D15                                     15

//repcap HardcopyOutput
#define RSMXO_REPCAP_HARDCOPYOUTPUT_HARDCOPYOUTPUT1                         1
#define RSMXO_REPCAP_HARDCOPYOUTPUT_HARDCOPYOUTPUT2                         2

//repcap Zoom
#define RSMXO_REPCAP_ZOOM_ZOOM1                                             1
#define RSMXO_REPCAP_ZOOM_ZOOM2                                             2
#define RSMXO_REPCAP_ZOOM_ZOOM3                                             3
#define RSMXO_REPCAP_ZOOM_ZOOM4                                             4
#define RSMXO_REPCAP_ZOOM_ZOOM5                                             5
#define RSMXO_REPCAP_ZOOM_ZOOM6                                             6
#define RSMXO_REPCAP_ZOOM_ZOOM7                                             7
#define RSMXO_REPCAP_ZOOM_ZOOM8                                             8

//repcap LayoutSet
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT1                                      1
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT2                                      2
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT3                                      3
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT4                                      4
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT5                                      5
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT6                                      6
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT7                                      7
#define RSMXO_REPCAP_LAYOUTSET_LAYOUT8                                      8

//repcap Logic
#define RSMXO_REPCAP_LOGIC_LOGIC1                                           1
#define RSMXO_REPCAP_LOGIC_LOGIC2                                           2
#define RSMXO_REPCAP_LOGIC_LOGIC3                                           3
#define RSMXO_REPCAP_LOGIC_LOGIC4                                           4

//repcap ChannelGroup
#define RSMXO_REPCAP_CHANNELGROUP_CHANNELGROUP1                             1
#define RSMXO_REPCAP_CHANNELGROUP_CHANNELGROUP2                             2
#define RSMXO_REPCAP_CHANNELGROUP_CHANNELGROUP3                             3
#define RSMXO_REPCAP_CHANNELGROUP_CHANNELGROUP4                             4

//repcap BusWordBit
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT0                                 0
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT1                                 1
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT2                                 2
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT3                                 3
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT4                                 4
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT5                                 5
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT6                                 6
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT7                                 7
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT8                                 8
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT9                                 9
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT10                                10
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT11                                11
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT12                                12
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT13                                13
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT14                                14
#define RSMXO_REPCAP_BUSWORDBIT_BUSWORDBIT15                                15

//repcap ClockedLogic
#define RSMXO_REPCAP_CLOCKEDLOGIC_CLOCKEDLOGIC1                             1
#define RSMXO_REPCAP_CLOCKEDLOGIC_CLOCKEDLOGIC2                             2

//repcap ReferenceLevel
#define RSMXO_REPCAP_REFERENCELEVEL_REFERENCELEVEL1                         1
#define RSMXO_REPCAP_REFERENCELEVEL_REFERENCELEVEL2                         2

//repcap ReferenceWaveform
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM1                   1
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM2                   2
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM3                   3
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM4                   4
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM5                   5
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM6                   6
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM7                   7
#define RSMXO_REPCAP_REFERENCEWAVEFORM_REFERENCEWAVEFORM8                   8

//repcap Measurement
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT1                               1
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT2                               2
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT3                               3
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT4                               4
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT5                               5
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT6                               6
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT7                               7
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT8                               8
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT9                               9
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT10                              10
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT11                              11
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT12                              12
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT13                              13
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT14                              14
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT15                              15
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT16                              16
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT17                              17
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT18                              18
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT19                              19
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT20                              20
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT21                              21
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT22                              22
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT23                              23
#define RSMXO_REPCAP_MEASUREMENT_MEASUREMENT24                              24

//repcap DelayRC
#define RSMXO_REPCAP_DELAYRC_DELAY1                                         1
#define RSMXO_REPCAP_DELAYRC_DELAY2                                         2

//repcap SmartgridChild
#define RSMXO_REPCAP_SMARTGRIDCHILD_SMARTGRIDCHILD1                         1
#define RSMXO_REPCAP_SMARTGRIDCHILD_SMARTGRIDCHILD2                         2

//repcap FRAMarker
#define RSMXO_REPCAP_FRAMARKER_FRAMARKER1                                   1
#define RSMXO_REPCAP_FRAMARKER_FRAMARKER2                                   2

//repcap GateRC
#define RSMXO_REPCAP_GATERC_GATE1                                           1
#define RSMXO_REPCAP_GATERC_GATE2                                           2
#define RSMXO_REPCAP_GATERC_GATE3                                           3
#define RSMXO_REPCAP_GATERC_GATE4                                           4
#define RSMXO_REPCAP_GATERC_GATE5                                           5
#define RSMXO_REPCAP_GATERC_GATE6                                           6
#define RSMXO_REPCAP_GATERC_GATE7                                           7
#define RSMXO_REPCAP_GATERC_GATE8                                           8

//repcap DiagramRC
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM1                                     1
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM2                                     2
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM3                                     3
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM4                                     4
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM5                                     5
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM6                                     6
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM7                                     7
#define RSMXO_REPCAP_DIAGRAMRC_DIAGRAM8                                     8

//repcap PowerAnalysis
#define RSMXO_REPCAP_POWERANALYSIS_POWAN1                                   1
#define RSMXO_REPCAP_POWERANALYSIS_POWAN2                                   2
#define RSMXO_REPCAP_POWERANALYSIS_POWAN3                                   3
#define RSMXO_REPCAP_POWERANALYSIS_POWAN4                                   4
#define RSMXO_REPCAP_POWERANALYSIS_POWAN5                                   5
#define RSMXO_REPCAP_POWERANALYSIS_POWAN6                                   6

//repcap PowerHarmonics
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM1                                1
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM2                                2
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM3                                3
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM4                                4
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM5                                5
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM6                                6
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM7                                7
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM8                                8
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM9                                9
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM10                               10
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM11                               11
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM12                               12
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM13                               13
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM14                               14
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM15                               15
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM16                               16
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM17                               17
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM18                               18
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM19                               19
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM20                               20
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM21                               21
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM22                               22
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM23                               23
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM24                               24
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM25                               25
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM26                               26
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM27                               27
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM28                               28
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM29                               29
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM30                               30
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM31                               31
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM32                               32
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM33                               33
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM34                               34
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM35                               35
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM36                               36
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM37                               37
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM38                               38
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM39                               39
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM40                               40
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM41                               41
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM42                               42
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM43                               43
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM44                               44
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM45                               45
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM46                               46
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM47                               47
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM48                               48
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM49                               49
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM50                               50
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM51                               51
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM52                               52
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM53                               53
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM54                               54
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM55                               55
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM56                               56
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM57                               57
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM58                               58
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM59                               59
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM60                               60
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM61                               61
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM62                               62
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM63                               63
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM64                               64
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM65                               65
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM66                               66
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM67                               67
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM68                               68
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM69                               69
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM70                               70
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM71                               71
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM72                               72
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM73                               73
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM74                               74
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM75                               75
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM76                               76
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM77                               77
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM78                               78
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM79                               79
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM80                               80
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM81                               81
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM82                               82
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM83                               83
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM84                               84
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM85                               85
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM86                               86
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM87                               87
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM88                               88
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM89                               89
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM90                               90
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM91                               91
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM92                               92
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM93                               93
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM94                               94
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM95                               95
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM96                               96
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM97                               97
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM98                               98
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM99                               99
#define RSMXO_REPCAP_POWERHARMONICS_POWHARM100                              100

//repcap PowerReference
#define RSMXO_REPCAP_POWERREFERENCE_POWREF1                                 1
#define RSMXO_REPCAP_POWERREFERENCE_POWREF2                                 2
#define RSMXO_REPCAP_POWERREFERENCE_POWREF3                                 3
#define RSMXO_REPCAP_POWERREFERENCE_POWREF4                                 4

//repcap VoltmeterChannel
#define RSMXO_REPCAP_VOLTMETERCHANNEL_VCH1                                  1
#define RSMXO_REPCAP_VOLTMETERCHANNEL_VCH2                                  2
#define RSMXO_REPCAP_VOLTMETERCHANNEL_VCH3                                  3
#define RSMXO_REPCAP_VOLTMETERCHANNEL_VCH4                                  4

//repcap CursorLine
#define RSMXO_REPCAP_CURSORLINE_CS1                                         1
#define RSMXO_REPCAP_CURSORLINE_CS2                                         2

//repcap Spectrum
#define RSMXO_REPCAP_SPECTRUM_SPECTRUM0                                     0
#define RSMXO_REPCAP_SPECTRUM_SPECTRUM1                                     1
#define RSMXO_REPCAP_SPECTRUM_SPECTRUM2                                     2
#define RSMXO_REPCAP_SPECTRUM_SPECTRUM3                                     3
#define RSMXO_REPCAP_SPECTRUM_SPECTRUM4                                     4
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSMXO_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSMXO_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSMXO_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSMXO_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

 /****************************************************************************
  *---------------- Constant definition  ------------------------------------*
  ****************************************************************************/

/***************************************************************************
*---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rsmxo_init(ViRsrc     resourceName,
                             ViBoolean  IDQuery,
                             ViBoolean  resetDevice,
                             ViSession* instrSession);

ViStatus _VI_FUNC rsmxo_InitWithOptions(ViRsrc     resourceName,
                                        ViBoolean  IDQuery,
                                        ViBoolean  resetDevice,
                                        ViString   optionString,
                                        ViSession* instrSession);

ViStatus _VI_FUNC rsmxo_ShowChannel(ViSession instrSession,
                                    ViInt32   channel,
                                    ViBoolean showChannel);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalScale(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  verticalScale);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalRange(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  range);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalOffset(ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64  offset);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalPosition(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalSkew(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  skew);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalCoupling(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   coupling);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalInvertChannel(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean invertChannel);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalBandwidth(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bandwidth);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalExternalAttenuation(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   scale,
                                                             ViReal64  externalAttenuation);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalPowerCalculationImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  impedance);

ViStatus _VI_FUNC rsmxo_ConfigureVerticalLabel(ViSession instrSession,
                                               ViInt32   signal,
                                               ViString  label);

ViStatus _VI_FUNC rsmxo_QueryProbeState(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProbeName(ViSession instrSession,
                                       ViInt32   channel,
                                       ViInt32   bufferSize,
                                       ViChar    probeName[],
                                       ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProbeType(ViSession instrSession,
                                       ViInt32   channel,
                                       ViInt32   bufferSize,
                                       ViChar    probeType[],
                                       ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_ConfigureProbePredefinedType(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   type);

ViStatus _VI_FUNC rsmxo_QueryProbeBandwidth(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64* probeBandwidth);

ViStatus _VI_FUNC rsmxo_ConfigureProbeVerticalUnit(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   verticalUnit);

ViStatus _VI_FUNC rsmxo_ConfigureProbeManualAttenuation(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64  manualAttenuation);

ViStatus _VI_FUNC rsmxo_QueryProbeAutoAttenuation(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* autoAttenuation);

ViStatus _VI_FUNC rsmxo_SetProbeOffsetToMean(ViSession instrSession,
                                             ViInt32   channel);

ViStatus _VI_FUNC rsmxo_ProbeAutoZero(ViSession instrSession,
                                      ViInt32   channel);

ViStatus _VI_FUNC rsmxo_UseProbeAutoZero(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean useAutoZero);

ViStatus _VI_FUNC rsmxo_ConfigureProbeMicroButton(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   microButton);

ViStatus _VI_FUNC rsmxo_QueryProbeImpedance(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64* impedance);

ViStatus _VI_FUNC rsmxo_QueryProbeCapacitance(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64* capacitance);

ViStatus _VI_FUNC rsmxo_QueryProbePartNumber(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   bufferSize,
                                             ViChar    partNumber[],
                                             ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProbeProductionDate(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   bufferSize,
                                                 ViChar    productionDate[],
                                                 ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProbeSerialNumber(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   bufferSize,
                                               ViChar    serialNumber[],
                                               ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProbeSoftwareVersion(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   bufferSize,
                                                  ViChar    softwareVersion[],
                                                  ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_ConfigureProbeCMOffset(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  CMOffset);

ViStatus _VI_FUNC rsmxo_ConfigureProbeRTZA15AttenuatorEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean attenuator);

ViStatus _VI_FUNC rsmxo_ConfigureProbeDisplay(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   display);

ViStatus _VI_FUNC rsmxo_ConfigureProbeSoundEnabled(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean sound);

ViStatus _VI_FUNC rsmxo_ConfigureProbeBandwidthLimitEnabled(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean bandwidthLimit);

ViStatus _VI_FUNC rsmxo_ConfigureProbeVoltageRange(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   voltageRange);

ViStatus _VI_FUNC rsmxo_ConfigureProbeMeterEnabled(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean probeMeter);

ViStatus _VI_FUNC rsmxo_ProbeMeterSetToOffset(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rsmxo_ConfigureProbeACCouplingEnabled(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViBoolean ACCoupling);

ViStatus _VI_FUNC rsmxo_ConfigureProbeManualGain(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  gain);

ViStatus _VI_FUNC rsmxo_QueryProbePredefinedGain(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* gain);

ViStatus _VI_FUNC rsmxo_ConfigureProbeZeroAdjust(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  zeroAdjust);

ViStatus _VI_FUNC rsmxo_ProbeDeGauss(ViSession instrSession,
                                     ViInt32   channel);

ViStatus _VI_FUNC rsmxo_ProbeSaveToProbe(ViSession instrSession,
                                         ViInt32   channel);

ViStatus _VI_FUNC rsmxo_ConfigureProbeDifferentialOffset(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  differentialOffset);

ViStatus _VI_FUNC rsmxo_ConfigureProbeNegativeOffset(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64  negativeOffset);

ViStatus _VI_FUNC rsmxo_ConfigureProbePositiveOffset(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64  positiveOffset);

ViStatus _VI_FUNC rsmxo_ConfigureProbeModularMeasurementMode(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureProbeTerminationVoltageEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProbeTerminationVoltage(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  voltage);

ViStatus _VI_FUNC rsmxo_ConfigureProbeTerminationMode(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsmxo_QueryProbeMeterResults(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64* singleEnded,
                                               ViReal64* common,
                                               ViReal64* differential);

ViStatus _VI_FUNC rsmxo_QueryProbeResultsPositive(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* positive);

ViStatus _VI_FUNC rsmxo_QueryProbeResultsNegative(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* negative);

ViStatus _VI_FUNC rsmxo_ConfigureHorizontalTimeScale(ViSession instrSession,
                                                     ViReal64  timeScale);

ViStatus _VI_FUNC rsmxo_ConfigureHorizontalTimebaseRange(ViSession instrSession,
                                                         ViReal64  timebaseRange);

ViStatus _VI_FUNC rsmxo_ConfigureHorizontalPosition(ViSession instrSession,
                                                    ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureHorizontalReferencePoint(ViSession instrSession,
                                                          ViReal64  referencePoint);

ViStatus _VI_FUNC rsmxo_QueryHorizontalDivisions(ViSession instrSession,
                                                 ViReal64* divisions);

ViStatus _VI_FUNC rsmxo_ConfigureHorizontalReferenceClockSource(
                            ViSession instrSession,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_EnableHorizontalReferenceClock10MHzOutput(
                            ViSession instrSession,
                            ViBoolean output10MHz);

ViStatus _VI_FUNC rsmxo_ConfigureHorizontalRoll(ViSession instrSession,
                                                ViInt32   enabled,
                                                ViReal64  acquisitionTime);

ViStatus _VI_FUNC rsmxo_QueryHorizontalRollStatus(ViSession  instrSession,
                                                  ViBoolean* status);

ViStatus _VI_FUNC rsmxo_EnableZoom(ViSession instrSession,
                                   ViInt32   layout,
                                   ViInt32   zoom,
                                   ViBoolean state);

ViStatus _VI_FUNC rsmxo_QueryZoomCount(ViSession instrSession,
                                       ViInt32   layout,
                                       ViInt32*  zoomCount);

ViStatus _VI_FUNC rsmxo_ConfigureZoomModeHorizontal(ViSession instrSession,
                                                    ViInt32   layout,
                                                    ViInt32   zoom,
                                                    ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureZoomXAbsoluteStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureZoomXAbsolutePositionRange(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureZoomXRelativeStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureZoomXRelativePositionRange(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureZoomModeVertical(ViSession instrSession,
                                                  ViInt32   layout,
                                                  ViInt32   zoom,
                                                  ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureZoomYAbsoluteStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureZoomYAbsolutePositionRange(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureZoomYRelativeStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureZoomYRelativeRangePosition(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position);

ViStatus _VI_FUNC rsmxo_ZoomSettoScreen(ViSession instrSession,
                                        ViInt32   layout,
                                        ViInt32   zoom);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerOn(ViSession instrSession,
                                           ViInt32   triggerOn);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerMode(ViSession instrSession,
                                             ViInt32   triggerMode);

ViStatus _VI_FUNC rsmxo_TriggerForce(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSource(ViSession instrSession,
                                               ViInt32   trigger,
                                               ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerType(ViSession instrSession,
                                             ViInt32   trigger,
                                             ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerLevel(ViSession instrSession,
                                              ViInt32   trigger,
                                              ViInt32   channel,
                                              ViReal64  level);

ViStatus _VI_FUNC rsmxo_FindTriggerLevel(ViSession instrSession,
                                         ViInt32   trigger);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceType(ViSession instrSession,
                                                     ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceDelay(ViSession instrSession,
                                                      ViReal64  delay);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceBEventCount(ViSession instrSession,
                                                            ViInt32   count);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceResetSettings(
                            ViSession instrSession,
                            ViBoolean resetEvent,
                            ViBoolean resetTime,
                            ViReal64  resetTimeout);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeSlope(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerGlitchPolarity(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   polarity);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerGlitchRange(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   range);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerGlitchWidth(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthPolarity(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   polarity);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthRange(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   range);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthWidth(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthDelta(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViReal64  delta);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntPolarity(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   polarity);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntRange(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   range);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntWidth(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntDelta(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViReal64  delta);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntLimits(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   channel,
                                                   ViReal64  lowerLevel,
                                                   ViReal64  upperLevel);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowVerticalCondition(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   verticalCondition);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowLimits(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   channel,
                                                     ViReal64  lowerLevel,
                                                     ViReal64  upperLevel);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowTimeCondition(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   timeCondition);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowWidth(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowDelta(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  delta);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerTimeoutTime(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  time);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerTimeoutRange(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   range);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalSlope(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalRange(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   range);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalWidth(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalDelta(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViReal64  delta);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateSlope(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateRange(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   range);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateTime(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViReal64  time);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateDelta(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViReal64  delta);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateLimits(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   channel,
                                                       ViReal64  lowerLevel,
                                                       ViReal64  upperLevel);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateSlope(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateOperator(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   logicOperator);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateChannel(ViSession instrSession,
                                                     ViInt32   triggerEvent,
                                                     ViInt32   channel,
                                                     ViInt32   triggerStateChannel);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateDigitalStateOperator(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   operatorType);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateDigitalChannelState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   digitalChannel,
                            ViInt32   state);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternOperator(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   logicOperator);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternChannel(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   channel,
                                                       ViInt32   state);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternStateSource(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternDigitalStateOperator(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   operatorType);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternDigitalChannelState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   digitalChannel,
                            ViInt32   state);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldEdge(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   edge);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldClockLevel(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViReal64  level);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldClockSource(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldHoldTime(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViReal64  time);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldSetupTime(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViReal64  time);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeCoupling(ViSession instrSession,
                                                     ViInt32   coupling);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeLevel(ViSession instrSession,
                                                  ViReal64  level);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeFilter(ViSession instrSession,
                                                   ViInt32   filter);

ViStatus _VI_FUNC rsmxo_QueryTriggerEdgeLowPass(ViSession instrSession,
                                                ViInt32*  lowPass);

ViStatus _VI_FUNC rsmxo_QueryTriggerEdgeHighPass(ViSession instrSession,
                                                 ViInt32*  highPass);

ViStatus _VI_FUNC rsmxo_EnableTriggerNoiseReject(ViSession instrSession,
                                                 ViBoolean triggerNoiseReject);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffMode(ViSession instrSession,
                                                    ViInt32   triggerMode);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffTime(ViSession instrSession,
                                                    ViReal64  holdoffTime);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffEvents(ViSession instrSession,
                                                      ViInt32   holdoffEvents);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffRandom(ViSession instrSession,
                                                      ViReal64  minimumTime,
                                                      ViReal64  maximumTime);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffAutoTimeScaling(
                            ViSession instrSession,
                            ViReal64  autoTimeScaling);

ViStatus _VI_FUNC rsmxo_QueryTriggerHoldoffAutoTime(ViSession instrSession,
                                                    ViReal64* autoTime);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisMode(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   hysteresisMode);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisSizeMode(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   sizeMode);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisAbsolute(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViReal64  absoluteHysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisRelativeDivs(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  relativeHysteresisDivs);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisRelativePercentage(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  relativeHysteresis);

ViStatus _VI_FUNC rsmxo_QueryTriggerHWHysteresis(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* HWHysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerFilterMode(ViSession instrSession,
                                                   ViInt32   filterMode);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerFilterLFRejectBW(ViSession instrSession,
                                                         ViReal64  LFRejectBW);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerFilterRFRejectBW(ViSession instrSession,
                                                         ViReal64  RFRejectBW);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerOut(ViSession instrSession,
                                            ViBoolean triggerOut,
                                            ViInt32   polarity,
                                            ViReal64  delay,
                                            ViReal64  pulseLength);

ViStatus _VI_FUNC rsmxo_ConfigureTriggerActionSignalSource(ViSession instrSession,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsmxo_RunContinuousAcquisition(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_StopAcquisition(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_RunSingleAcquisition(ViSession instrSession,
                                             ViInt32   maximumTimeMs);

ViStatus _VI_FUNC rsmxo_RunSingleAcquisitionNoWait(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_AutoscaleAcquisition(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionSampleRateSettings(
                            ViSession instrSession,
                            ViInt32   mode,
                            ViReal64  sampleRate,
                            ViReal64  minimumSampleRate);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionRecordLengthSettings(
                            ViSession instrSession,
                            ViInt32   mode,
                            ViInt32   recordLength,
                            ViReal64  recordLengthLimit);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionNSingleAverageCount(
                            ViSession instrSession,
                            ViInt32   nSingleAverageCount);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionResolution(ViSession instrSession,
                                                       ViReal64  resolution);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionMode(ViSession instrSession,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionInterpolation(ViSession instrSession,
                                                          ViInt32   interpolation);

ViStatus _VI_FUNC rsmxo_QueryAvailableAcquisitions(ViSession instrSession,
                                                   ViInt32*  availableAcquisitions);

ViStatus _VI_FUNC rsmxo_QueryADCRate(ViSession instrSession,
                                     ViReal64* ADCRate);

ViStatus _VI_FUNC rsmxo_QueryRealSampleRate(ViSession instrSession,
                                            ViReal64* realSampleRate);

ViStatus _VI_FUNC rsmxo_QueryAcquisitionCurrent(ViSession instrSession,
                                                ViInt32*  current);

ViStatus _VI_FUNC rsmxo_QueryAcquisitionAverage(ViSession instrSession,
                                                ViInt32*  average);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionSegmented(ViSession instrSession,
                                                      ViBoolean acquireMaximum,
                                                      ViBoolean fastSegmentation);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionHighDefinition(ViSession instrSession,
                                                           ViBoolean HDEnabled,
                                                           ViReal64  bandwidth);

ViStatus _VI_FUNC rsmxo_QueryHighDefinitionResolution(ViSession instrSession,
                                                      ViReal64* HDResolution);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionRollModeOffScreenCapture(
                            ViSession instrSession,
                            ViBoolean offScreenCapture);

ViStatus _VI_FUNC rsmxo_QueryAcquisitionRollModePoints(ViSession instrSession,
                                                       ViReal64* points);

ViStatus _VI_FUNC rsmxo_ShowAcquisitionHistory(ViSession instrSession,
                                               ViBoolean showHistory);

ViStatus _VI_FUNC rsmxo_PlayAcquisitionHistory(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionHistoryReplay(ViSession instrSession,
                                                          ViBoolean replay);

ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionHistoryPlayer(ViSession instrSession,
                                                          ViInt32   start,
                                                          ViInt32   stop,
                                                          ViReal64  displayTime);

ViStatus _VI_FUNC rsmxo_SelectCurrentAcquisition(ViSession instrSession,
                                                 ViInt32   current);

ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionAbsoluteTime(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    time[],
                                                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionAbsoluteDate(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    date[],
                                                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionRelativeTime(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    relativeTime[],
                                                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionReferenceRelativeTime(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    relativeTime[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_EnableMeasurement(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_QueryMeasurementCount(ViSession instrSession,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementType(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   measurementType);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementSource(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViInt32   source,
                                                   ViInt32   source2);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementSource1(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementSource2(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementGate(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   gate);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementEnvelope(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViInt32   envelope);

ViStatus _VI_FUNC rsmxo_EnableMeasurementStatistics(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViBoolean statistics);

ViStatus _VI_FUNC rsmxo_EnableMeasurementStatisticsAllEvents(ViSession instrSession,
                                                             ViBoolean allEvents);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementStatisticsMaximumEvents(
                            ViSession instrSession,
                            ViInt32   maximumEvents);

ViStatus _VI_FUNC rsmxo_ClearMeasurementStatisticsResults(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_MeasurementFitToScreen(ViSession instrSession,
                                               ViInt32   measurement);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAutoscale(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViBoolean autoscale);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementTrack(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViBoolean enabled,
                                                  ViReal64  scale,
                                                  ViReal64  offset);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeClockSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimePulseCount(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   pulseCount);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimePulseSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   pulseSlope);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeEdgesSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeDelaySlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   delay,
                            ViInt32   slope);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeDelayDirection(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   delay,
                            ViInt32   direction);

ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeDelayToTrigger(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   delay,
                            ViInt32   delayToTrigger);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelEnabled(ViSession instrSession,
                                                       ViInt32   referenceLevel,
                                                       ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelMode(ViSession instrSession,
                                                    ViInt32   referenceLevel,
                                                    ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelAbsoluteSettings(
                            ViSession instrSession,
                            ViInt32   referenceLevel,
                            ViReal64  lowerLevel,
                            ViReal64  middleLevel,
                            ViReal64  upperLevel,
                            ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelRelativeMode(ViSession instrSession,
                                                            ViInt32   referenceLevel,
                                                            ViInt32   relativeMode);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelRelativeSettings(
                            ViSession instrSession,
                            ViInt32   referenceLevel,
                            ViReal64  lowerLevel,
                            ViReal64  middleLevel,
                            ViReal64  upperLevel,
                            ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_QueryMeasurementBounds(ViSession instrSession,
                                               ViInt32   measurement,
                                               ViReal64* start,
                                               ViReal64* stop);

ViStatus _VI_FUNC rsmxo_QueryResultsCount(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViInt32*  count);

ViStatus _VI_FUNC rsmxo_ConfigureResultsMaximumCount(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViInt32   measurementType,
                                                     ViInt32   count);

ViStatus _VI_FUNC rsmxo_ShowResultsLabels(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViInt32   measurementType,
                                          ViBoolean showLabels);

ViStatus _VI_FUNC rsmxo_EnableResultsInvertedLabel(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViBoolean inverted);

ViStatus _VI_FUNC rsmxo_ShowResultsFrequency(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   measurementType,
                                             ViBoolean showFrequency);

ViStatus _VI_FUNC rsmxo_ConfigureResultsLabelsOrder(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   layout);

ViStatus _VI_FUNC rsmxo_QueryResultsEventCount(ViSession instrSession,
                                               ViInt32   measurement,
                                               ViInt32*  eventCount);

ViStatus _VI_FUNC rsmxo_GetResultsEventStart(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   eventIndex,
                                             ViReal64* start);

ViStatus _VI_FUNC rsmxo_GetResultsEventStop(ViSession instrSession,
                                            ViInt32   measurement,
                                            ViInt32   eventIndex,
                                            ViReal64* stop);

ViStatus _VI_FUNC rsmxo_GetResultsEventValue(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   eventIndex,
                                             ViReal64* value);

ViStatus _VI_FUNC rsmxo_FetchMeasurementResultsStatistics(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   statisticsType,
                                                          ViReal64* result);

ViStatus _VI_FUNC rsmxo_ReadMeasurementResultsStatistics(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   maximumTimeMs,
                                                         ViInt32   statisticsType,
                                                         ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchMeasurementReliability(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   measurementType,
                                                    ViReal64* reliability);

ViStatus _VI_FUNC rsmxo_ConfigureGateEnabled(ViSession instrSession,
                                             ViInt32   gate,
                                             ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureGateDisplay(ViSession instrSession,
                                             ViInt32   gate,
                                             ViBoolean display);

ViStatus _VI_FUNC rsmxo_ConfigureGateCouplingMode(ViSession instrSession,
                                                  ViInt32   gate,
                                                  ViInt32   couplingMode);

ViStatus _VI_FUNC rsmxo_ConfigureGateMode(ViSession instrSession,
                                          ViInt32   gate,
                                          ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureGateAbsoluteBounds(ViSession instrSession,
                                                    ViInt32   gate,
                                                    ViReal64  start,
                                                    ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureGateRelativeBounds(ViSession instrSession,
                                                    ViInt32   gate,
                                                    ViReal64  start,
                                                    ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureGateCursor(ViSession instrSession,
                                            ViInt32   gate,
                                            ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_ConfigureGateZoomDiagram(ViSession instrSession,
                                                 ViInt32   gate,
                                                 ViString  gateName,
                                                 ViString  diagramGroup,
                                                 ViString  zoomDiagram);

ViStatus _VI_FUNC rsmxo_ShowCursor(ViSession instrSession,
                                   ViInt32   cursor,
                                   ViBoolean show);

ViStatus _VI_FUNC rsmxo_CursorDisableAll(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_QueryCursorCount(ViSession instrSession,
                                         ViInt32*  count);

ViStatus _VI_FUNC rsmxo_ConfigureCursorSource(ViSession instrSession,
                                              ViInt32   cursor,
                                              ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureCursorSecondarySource(ViSession instrSession,
                                                       ViInt32   cursor,
                                                       ViBoolean enabled,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureCursorSettings(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViInt32   style,
                                                ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureCursorXPositions(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViReal64  x1Position,
                                                  ViReal64  x2Position);

ViStatus _VI_FUNC rsmxo_ConfigureCursorYPositions(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViReal64  y1Position,
                                                  ViReal64  y2Position);

ViStatus _VI_FUNC rsmxo_ConfigureCursorEnvelope(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViInt32   envelope);

ViStatus _VI_FUNC rsmxo_ConfigureCursorEnvelope2(ViSession instrSession,
                                                 ViInt32   cursor,
                                                 ViInt32   envelope);

ViStatus _VI_FUNC rsmxo_ConfigureCursorTrackWaveform(ViSession instrSession,
                                                     ViInt32   cursor,
                                                     ViBoolean trackWaveform);

ViStatus _VI_FUNC rsmxo_ConfigureCursorCoupling(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViBoolean x,
                                                ViBoolean y);

ViStatus _VI_FUNC rsmxo_ShowCursorInAllDiagrams(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViBoolean showInAllDiagrams);

ViStatus _VI_FUNC rsmxo_ShowCursorLabel(ViSession instrSession,
                                        ViInt32   cursor,
                                        ViBoolean showLabel);

ViStatus _VI_FUNC rsmxo_ConfigureCursorShowValues(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViBoolean showValues);

ViStatus _VI_FUNC rsmxo_CursorReset(ViSession instrSession,
                                    ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_SetCursorPositionToAbsolutePeak(ViSession instrSession,
                                                        ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_SetCursorPositionToNextPeak(ViSession instrSession,
                                                    ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_SetCursorPositionToNextPeakLeft(ViSession instrSession,
                                                        ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_SetCursorPositionToNextPeakRight(ViSession instrSession,
                                                         ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_SetCursorPositionToCenterFrequency(ViSession instrSession,
                                                           ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_SetCenterFrequencyToCursor(ViSession instrSession,
                                                   ViInt32   cursor);

ViStatus _VI_FUNC rsmxo_ConfigureCursorPeakSearchThreshold(ViSession instrSession,
                                                           ViInt32   cursor,
                                                           ViReal64  threshold);

ViStatus _VI_FUNC rsmxo_ConfigureCursorPeakSearchExcursion(ViSession instrSession,
                                                           ViInt32   cursor,
                                                           ViReal64  excursion);

ViStatus _VI_FUNC rsmxo_QueryCursorResultsX(ViSession instrSession,
                                            ViInt32   cursor,
                                            ViReal64* dx,
                                            ViReal64* inverseDx);

ViStatus _VI_FUNC rsmxo_QueryCursorResultsDeltaY(ViSession instrSession,
                                                 ViInt32   cursor,
                                                 ViReal64* dy);

ViStatus _VI_FUNC rsmxo_ConfigureCursorResultsDeltaYInverse(ViSession instrSession,
                                                            ViInt32   cursor,
                                                            ViReal64  deltaYInverse);

ViStatus _VI_FUNC rsmxo_ConfigureCursorHorizontalLabel(ViSession instrSession,
                                                       ViInt32   cursor,
                                                       ViInt32   cursorLine,
                                                       ViString  label);

ViStatus _VI_FUNC rsmxo_ConfigureCursorVerticalLabel(ViSession instrSession,
                                                     ViInt32   cursor,
                                                     ViInt32   cursorLine,
                                                     ViString  label);

ViStatus _VI_FUNC rsmxo_DisplaySpectrum(ViSession instrSession,
                                        ViInt32   spectrum,
                                        ViBoolean displaySpectrum);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumSource(ViSession instrSession,
                                                ViInt32   spectrum,
                                                ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumCFSpan(ViSession instrSession,
                                                ViInt32   spectrum,
                                                ViReal64  center,
                                                ViReal64  span);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumStartStop(ViSession instrSession,
                                                   ViInt32   spectrum,
                                                   ViReal64  spectrumStart,
                                                   ViReal64  spectrumStop);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumRBWSettings(ViSession instrSession,
                                                     ViInt32   spectrum,
                                                     ViBoolean autoRBW,
                                                     ViReal64  RBW,
                                                     ViInt32   spanRBW);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumTraces(ViSession instrSession,
                                                ViInt32   spectrum,
                                                ViBoolean normal,
                                                ViBoolean minHold,
                                                ViBoolean maxHold,
                                                ViBoolean average);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumTracesAverageCount(ViSession instrSession,
                                                            ViInt32   spectrum,
                                                            ViInt32   averageCount);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumWindowType(ViSession instrSession,
                                                    ViInt32   spectrum,
                                                    ViInt32   type);

ViStatus _VI_FUNC rsmxo_SpectrumPreset(ViSession instrSession,
                                       ViInt32   spectrum);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleMagnitudeUnit(ViSession instrSession,
                                                            ViInt32   spectrum,
                                                            ViInt32   magnitudeUnit);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleVerticalMaximum(
                            ViSession instrSession,
                            ViInt32   spectrum,
                            ViReal64  verticalMaximum);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleVerticalRange(ViSession instrSession,
                                                            ViInt32   spectrum,
                                                            ViReal64  verticalRange);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleVerticalScale(ViSession instrSession,
                                                            ViInt32   spectrum,
                                                            ViReal64  verticalScale);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGateStart(ViSession instrSession,
                                                   ViInt32   spectrum,
                                                   ViReal64  start);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGateStop(ViSession instrSession,
                                                  ViInt32   spectrum,
                                                  ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGatePosition(ViSession instrSession,
                                                      ViInt32   spectrum,
                                                      ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGateWidth(ViSession instrSession,
                                                   ViInt32   spectrum,
                                                   ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListTableSettings(
                            ViSession instrSession,
                            ViInt32   spectrum,
                            ViBoolean peakTable,
                            ViReal64  threshold,
                            ViReal64  excursion,
                            ViInt32   maxResults,
                            ViInt32   resultMode,
                            ViBoolean showFrequency,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListFrameType(ViSession instrSession,
                                                           ViInt32   spectrum,
                                                           ViInt32   frameType);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListLabelMaxResults(
                            ViSession instrSession,
                            ViInt32   spectrum,
                            ViInt32   maxResults);

ViStatus _VI_FUNC rsmxo_QuerySpectrumPeakListCurrent(ViSession instrSession,
                                                     ViInt32   spectrum,
                                                     ViReal64* current);

ViStatus _VI_FUNC rsmxo_QuerySpectrumPeakListCount(ViSession instrSession,
                                                   ViInt32   spectrum,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListLabels(ViSession instrSession,
                                                        ViInt32   spectrum,
                                                        ViBoolean enabled,
                                                        ViBoolean invertColors);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListSort(ViSession instrSession,
                                                      ViInt32   spectrum,
                                                      ViInt32   sort,
                                                      ViInt32   order);

ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListDisplayPeaks(
                            ViSession instrSession,
                            ViInt32   spectrum,
                            ViBoolean peaks);

ViStatus _VI_FUNC rsmxo_DisplayMath(ViSession instrSession,
                                    ViInt32   math,
                                    ViBoolean display);

ViStatus _VI_FUNC rsmxo_DefineMathExpression(ViSession instrSession,
                                             ViInt32   math,
                                             ViInt32   source1,
                                             ViInt32   source2,
                                             ViInt32   operatorType,
                                             ViReal64  a,
                                             ViReal64  b,
                                             ViInt32   noiseReject);

ViStatus _VI_FUNC rsmxo_InputMathExpressionString(ViSession instrSession,
                                                  ViInt32   math,
                                                  ViString  mathExpression);

ViStatus _VI_FUNC rsmxo_ConfigureMathVerticalScaleMode(ViSession instrSession,
                                                       ViInt32   math,
                                                       ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureMathVerticalAxis(ViSession instrSession,
                                                  ViInt32   math,
                                                  ViReal64  scale,
                                                  ViReal64  offset);

ViStatus _VI_FUNC rsmxo_QueryMathSignalType(ViSession instrSession,
                                            ViInt32   math,
                                            ViInt32*  type);

ViStatus _VI_FUNC rsmxo_ConfigureMathEnvelopeWaveformSelection(
                            ViSession instrSession,
                            ViInt32   math,
                            ViInt32   waveformSelection);

ViStatus _VI_FUNC rsmxo_ConfigureMathLabel(ViSession instrSession,
                                           ViInt32   math,
                                           ViString  label);

ViStatus _VI_FUNC rsmxo_ConfigureMathUserUnit(ViSession instrSession,
                                              ViInt32   math,
                                              ViString  unit);

ViStatus _VI_FUNC rsmxo_EnableSerialBus(ViSession instrSession,
                                        ViInt32   serialBus,
                                        ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolType(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolDisplaySettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showDecodeTable,
                                                         ViInt32   dataFormat);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolZoomCoupling(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViBoolean zoomCoupling);

ViStatus _VI_FUNC rsmxo_ShowProtocolThresholdLines(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViBoolean showThresholdLines);

ViStatus _VI_FUNC rsmxo_SetProtocolReferenceLevels(ViSession instrSession,
                                                   ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSDASource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSDASettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSDAPosition(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSDAVerticalScale(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViReal64  scale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSCLSource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSCLSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CFrameCount(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  frameCount);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CShowSymbols(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean showSymbols);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSymbolListFile(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViString  file);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CPosition(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CScale(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViReal64  scale);

ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean filter);

ViStatus _VI_FUNC rsmxo_ProtocolI2CFilterFrameCheckAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolI2CFilterFrameClearAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolI2CFilterInvertsCurrentState(ViSession instrSession,
                                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean frameEnabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilterField(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViBoolean fieldEnabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean errorEnabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CFilterCondition(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   condition);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CFilterIndex(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   index,
                                                        ViInt32   startValue,
                                                        ViInt32   endValue);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CFilterData(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   field,
                                                       ViInt32   data,
                                                       ViString  startValue,
                                                       ViString  endValue);

ViStatus _VI_FUNC rsmxo_ProtocolI2CFilterReset(ViSession instrSession,
                                               ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerType(ViSession instrSession,
                                                        ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerNoAckSettings(
                            ViSession instrSession,
                            ViBoolean addressNack,
                            ViBoolean dataWriteNack,
                            ViBoolean dataReadNack);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerAddressSettings(
                            ViSession instrSession,
                            ViInt32   addressType,
                            ViInt32   rWBit);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerAddress(ViSession instrSession,
                                                           ViInt32   address,
                                                           ViString  addressMinimum,
                                                           ViString  addressMaximum);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerData(ViSession instrSession,
                                                        ViInt32   data,
                                                        ViString  minimum);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsDecodeTable(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32*  state,
                                                           ViReal64* frameStart,
                                                           ViReal64* frameEnd,
                                                           ViInt32*  addressType,
                                                           ViInt32*  address,
                                                           ViInt32*  RWBit,
                                                           ViReal64* dataRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsSymbol(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   bufferSize,
                                                      ViChar    symbolLabel[],
                                                      ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsAddress(ViSession  instrSession,
                                                       ViInt32    serialBus,
                                                       ViInt32    frame,
                                                       ViBoolean* complete,
                                                       ViInt32*   type,
                                                       ViInt32*   address,
                                                       ViReal64*  start);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsAddressAckBit(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViReal64* ackBitStart,
                                                             ViInt32*  ackBit);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsDeviceAddress(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32*  deviceAddress);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsRWBit(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViReal64* RWBitStart,
                                                     ViInt32*  RWBit);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsData(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViReal64  data[],
                                                    ViInt32*  pointsRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsByteCount(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  count);

ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsByte(ViSession  instrSession,
                                                    ViInt32    serialBus,
                                                    ViInt32    frame,
                                                    ViInt32    byteNumber,
                                                    ViBoolean* complete,
                                                    ViReal64*  start,
                                                    ViReal64*  ackBitStart,
                                                    ViInt32*   ackBit,
                                                    ViInt32*   value);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMOSISource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMOSISettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMOSIPosition(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMOSIScale(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViReal64  scale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMISOSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMISOSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMISOPosition(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMISOScale(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViReal64  protocolSPIMISOScale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPISCLKSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPISCLKSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPICSSource(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPICSSettings(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViReal64  threshold,
                                                       ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIPolarityValues(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   MOSIPolarity,
                                                           ViInt32   CSPolarity,
                                                           ViInt32   MISOPolarity);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIBitOrder(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   bitOrder);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIWordLength(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   wordLength);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIAdvancedSettings(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frameCondition,
                                                             ViReal64  timeout);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPIFrameCount(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  frameCount);

ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ProtocolSPIFilterFrameCheckAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolSPIFilterFrameClearAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolSPIFilterInvertsCurrentState(ViSession instrSession,
                                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilterField(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViBoolean fieldEnabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIFilterIndex(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   index,
                                                        ViInt32   startIndex,
                                                        ViInt32   endIndex);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIFilterData(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   field,
                                                       ViInt32   data,
                                                       ViString  start,
                                                       ViString  end);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIFilterCondition(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   condition);

ViStatus _VI_FUNC rsmxo_ProtocolSPIFilterReset(ViSession instrSession,
                                               ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerType(ViSession instrSession,
                                                        ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerSearchMode(
                            ViSession instrSession,
                            ViInt32   searchMode);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerData(ViSession instrSession,
                                                        ViInt32   data,
                                                        ViString  dataPattern);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  state,
                                                     ViReal64* start,
                                                     ViReal64* end,
                                                     ViInt32*  count,
                                                     ViReal64* bitRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsWordCount(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  wordCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsWord(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   word,
                                                    ViReal64* start,
                                                    ViReal64* end,
                                                    ViReal64* MOSIValue,
                                                    ViReal64* MISOValue,
                                                    ViReal64* formatedMOSI,
                                                    ViReal64* formatedMISO);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsData(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViReal64  data[],
                                                    ViInt32*  pointsRead);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTXSource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTXSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTXPosition(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTXScale(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  scale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTRXSource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTRXSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTRXPosition(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTRXScale(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  scale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTPolarity(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   polarity);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTBitRate(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  bitRate);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTBitOrder(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   bitOrder);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTDataBits(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   dataBits);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTParity(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   parity);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTStopBits(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   stopBits);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTAdvancedSettings(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   packets,
                            ViReal64  timeout);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTEndWord(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   endWord);

ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilterFrame(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViBoolean frameEnabled);

ViStatus _VI_FUNC rsmxo_ProtocolUARTFilterFrameCheckAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolUARTFilterFrameClearAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolUARTFilterInvertsCurrentState(
                            ViSession instrSession,
                            ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilterField(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViBoolean fieldEnabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilterError(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   errorNumber,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTFilterIndex(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32   index,
                                                         ViInt32   start,
                                                         ViInt32   end);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTFilterData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   data,
                                                        ViString  start,
                                                        ViString  end);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTFilterCondition(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   condition);

ViStatus _VI_FUNC rsmxo_ProtocolUARTFilterReset(ViSession instrSession,
                                                ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerType(ViSession instrSession,
                                                         ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerSource(ViSession instrSession,
                                                           ViInt32   triggerSource);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerData(ViSession instrSession,
                                                         ViInt32   data);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerPattern(ViSession instrSession,
                                                            ViString  pattern);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerOperator(ViSession instrSession,
                                                             ViInt32   operatorType);

ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   word,
                                                       ViInt32*  source);

ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsWordCount(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   word,
                                                          ViInt32*  count);

ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsWordEnd(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   word,
                                                        ViReal64* end);

ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsDecodeTableTransmitter(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   word,
                            ViInt32*  state,
                            ViReal64* start,
                            ViReal64* txValue,
                            ViReal64* dataRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsDecodeTableReciever(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   word,
                            ViInt32*  state,
                            ViReal64* start,
                            ViReal64* rxValue,
                            ViReal64* dataRate);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSource(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANType(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTransceiverMode(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSICSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFASTSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANNominalBitRate(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViReal64  nominalBitRate);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFDSettings(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViReal64  bitRate,
                                                       ViReal64  samplePoint);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANDecodedFrames(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32*  decodedFrames);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLBitrate(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   bitrate);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLSamplePoint(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   samplePoint);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANShowSymbols(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean showSymbols);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSymbolListFile(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViString  file);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANPosition(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANScale(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViReal64  scale);

ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean filter);

ViStatus _VI_FUNC rsmxo_ProtocolCANFilterFrameCheckAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolCANFilterFrameClearAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolCANFilterInvertsCurrentState(ViSession instrSession,
                                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilterFrameField(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32   field,
                                                          ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFilterFieldOperator(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   operatorType);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFilterFieldData(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   operatorType,
                                                            ViString  startData,
                                                            ViString  endData);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFilterFieldIndex(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   operatorType,
                                                             ViInt32   startIndex,
                                                             ViInt32   endIndex);

ViStatus _VI_FUNC rsmxo_ProtocolCANFilterReset(ViSession instrSession,
                                               ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerType(ViSession instrSession,
                                                        ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerFrameType(ViSession instrSession,
                                                             ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerIdentifierType(
                            ViSession instrSession,
                            ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerIdentifier(
                            ViSession instrSession,
                            ViInt32   identifier,
                            ViString  identifierMinimum,
                            ViString  identifierMax);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerData(ViSession instrSession,
                                                        ViInt32   dataPattern,
                                                        ViString  dataValue);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   index);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerErrorCondition(
                            ViSession instrSession,
                            ViBoolean checksumError,
                            ViBoolean formError,
                            ViBoolean bitStuffingError,
                            ViBoolean ackError);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerStuffCountErrorEnabled(
                            ViSession instrSession,
                            ViBoolean stuffCount);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerCANFDSettings(
                            ViSession instrSession,
                            ViInt32   BRS,
                            ViInt32   ESI,
                            ViInt32   DLCCondition,
                            ViInt32   DLC);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerSEC(ViSession instrSession,
                                                         ViInt32   SEC);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerAF(ViSession instrSession,
                                                        ViInt32   condition,
                                                        ViReal64  max[],
                                                        ViReal64  min[]);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerSDT(ViSession instrSession,
                                                         ViInt32   condition,
                                                         ViReal64  max[],
                                                         ViReal64  min[]);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerVCID(ViSession instrSession,
                                                          ViInt32   condition,
                                                          ViReal64  max[],
                                                          ViReal64  min[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  state,
                                                     ViInt32*  type,
                                                     ViReal64* start,
                                                     ViReal64* stop);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFrameSymbol(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   bufferSize,
                                                           ViChar    symbol[],
                                                           ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsIdentifier(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  state,
                                                          ViInt32*  type,
                                                          ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsACKState(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsACKValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsByteState(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   byte,
                                                         ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsByteValue(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   byte,
                                                         ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsCRCState(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsCRCValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDLCState(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDLCValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsBitStuffingErrorPosition(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* errorPosition);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFormError(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  formError);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDataBytesNumber(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  dataBytesNumber);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsData(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViChar    data[],
                                                    ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsPatternData(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   bufferSize,
                                                           ViChar    patternData[],
                                                           ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsSymbolicData(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   bufferSize,
                                                            ViChar    symbolicData[],
                                                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsSymbolicDataExport(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    dataExport[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsStuffCountField(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  stuffCountField);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsBRS(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViInt32*  BRS);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsESI(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViInt32*  ESI);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFramesCount(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32*  framesCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDataBitRate(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32*  dataBitRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsNominalBitRate(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  nominalBitRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsStuffBitCount(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32*  stuffBitCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsAcceptance(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViReal64* resultsFieldAcceptance);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsPCRC(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViInt32*  PCRC);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsSBC(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViInt32*  SBC);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsServiceDataUnit(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32*  fieldServiceDataUnit);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsSEC(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViInt32*  SEC);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsVCID(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViInt32*  VCID);

ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsFieldFrameCRC(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32*  CRC);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINStandard(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   standard);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINSource(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINSettings(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  threshold,
                                                     ViReal64  hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINPolarity(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   polarity);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINBitRate(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViReal64  bitRate);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINPosition(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINScale(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViReal64  scale);

ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ProtocolLINFilterFrameCheckAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolLINFilterFrameClearAll(ViSession instrSession,
                                                       ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolLINFilterInvertsCurrentState(ViSession instrSession,
                                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilterField(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINFilterFieldOperator(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   operatorType);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINFilterFieldData(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   operatorType,
                                                            ViString  startData,
                                                            ViString  endData);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINFilterFieldIndex(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   operatorType,
                                                             ViInt32   startIndex,
                                                             ViInt32   endIndex);

ViStatus _VI_FUNC rsmxo_ProtocolLINFilterReset(ViSession instrSession,
                                               ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerType(ViSession instrSession,
                                                        ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerErrorTypes(
                            ViSession instrSession,
                            ViBoolean parityError,
                            ViBoolean syncError,
                            ViBoolean checksumError);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerDataOperator(
                            ViSession instrSession,
                            ViInt32   operatorType);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerDataPattern(
                            ViSession instrSession,
                            ViString  dataPattern);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerIdentifier(
                            ViSession instrSession,
                            ViInt32   operatorType,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameCount(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32*  frameCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameState(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameBounds(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViReal64* start,
                                                           ViReal64* end);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameData(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  valuesReturned);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameBitrate(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32*  bitrate);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameChecksum(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32*  checksum);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameIdentifier(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  state,
                            ViInt32*  identifier,
                            ViInt32*  parity);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameProtectedIdentifier(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   *protectedIdentifier);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByteCount(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  count);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByte(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   byteNumber,
                                                         ViInt32*  state,
                                                         ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByteFormattedValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViInt32   bufferSize,
                            ViChar    formattedValue[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByteLabel(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViInt32   bufferSize,
                            ViChar    label[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIGSID(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViBoolean useGSID,
                                                  ViInt32   GSID);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIGlitchFilter(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViBoolean useGlitchFilter,
                                                          ViReal64  width);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIClockLine(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source,
                                                       ViReal64  hysteresis,
                                                       ViReal64  threshold);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMISourceData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   source,
                                                        ViReal64  hysteresis,
                                                        ViReal64  threshold);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMI(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViReal64  position,
                                              ViReal64  scale);

ViStatus _VI_FUNC rsmxo_EnableProtocolSPMIFilterFrame(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_EnableProtocolSPMIFilterField(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIFilterIndex(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32   filterIndex,
                                                         ViInt32   startIndex,
                                                         ViInt32   endIndex);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIFilterData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   data,
                                                        ViString  startData,
                                                        ViString  endData);

ViStatus _VI_FUNC rsmxo_ProtocolSPMIFilterFrameCheckAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolSPMIFilterFrameClearAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolSPMIFilterInvertsCurrentState(
                            ViSession instrSession,
                            ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIFilterCondition(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   filterCondition);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPMIFilterErrorEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ProtocolSPMIFilterReset(ViSession instrSession,
                                                ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsState(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  state);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrame(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViReal64* frameStart,
                                                      ViReal64* frameEnd);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameBitRate(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViReal64* readBitRate,
                                                             ViReal64* writeBitRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameAddress(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32*  address);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameType(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  type);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsAddress(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  address);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsBC(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32*  BC);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsData(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   bufferSize,
                                                     ViChar    resultsData[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFDCount(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  FDCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameFormatedValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bufferSize,
                            ViChar    frameFormatedValue[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameLabel(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   field,
                                                           ViInt32   bufferSize,
                                                           ViChar    label[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameState(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   field,
                                                           ViInt32*  frameState);

ViStatus _VI_FUNC rsmxo_QueryProtocolSPMIResultsFrameValue(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   field,
                                                           ViReal64* frameValue);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSClockLine(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source,
                                                       ViReal64  hysteresis,
                                                       ViReal64  thresholdLower,
                                                       ViReal64  thresholdUpper);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSPosition(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSScale(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViReal64  scale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSShowSymbols(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showSymbols);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSFrameCount(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32*  frameCount);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSSymbolListFileLoad(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  symbolListFileLoad);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSFilterFrameEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSFilterCondition(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   condition);

ViStatus _VI_FUNC rsmxo_ProtocolTNOSFilterFrameCheckAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolTNOSFilterFrameClearAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolTNOSFilterInvertsCurrentState(
                            ViSession instrSession,
                            ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSFilterFieldEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSFilterIndex(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32   filterIndex,
                                                         ViInt32   startIndex,
                                                         ViInt32   endIndex);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSFilterData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   filterData,
                                                        ViString  startData,
                                                        ViString  endData);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolTNOSFilterErrorEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ProtocolTNOSFilterReset(ViSession instrSession,
                                                ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsState(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  resultsState);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrame(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  type,
                                                      ViReal64* start,
                                                      ViReal64* end);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsCount(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  count);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsBitRate(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViReal64* bitRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsByteCount(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  byteCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameByteCount(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  byteCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameByteState(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  byteState);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameByteValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  byteValue);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameByteFormattedValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32   bufferSize,
                            ViChar    formattedValue[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameByteLabel(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32   bufferSize,
                            ViChar    byteLabel[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsData(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   bufferSize,
                                                     ViChar    resultsData[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameCRC(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  CRC);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameDestination(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* address,
                            ViReal64* symbol);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameFormatedCRC(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    formatedCRC[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameFormatedData(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    formatedData[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameFormatedDestinationAddress(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    address[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameFormatedSRCAddress(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    SRCAddress[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsFrameFormatedTypeLength(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    typeLength[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViReal64* address,
                                                       ViReal64* symbol);

ViStatus _VI_FUNC rsmxo_QueryProtocolTNOSResultsTypeLength(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32*  typeLength);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOMode(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOPolarity(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   polarity);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOPosition(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOScale(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViReal64  scale);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOSource(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOShowSymbols(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showSymbols);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOFrameCount(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32*  frameCount);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOSymbolListFileLoad(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  listFileLoad);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOFilterFrameEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOFilterCondition(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   condition);

ViStatus _VI_FUNC rsmxo_ProtocolHBTOFilterFrameCheckAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolHBTOFilterFrameClearAll(ViSession instrSession,
                                                        ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ProtocolHBTOFilterInvertsCurrentState(
                            ViSession instrSession,
                            ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOFilterFieldEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOFilterIndex(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32   index,
                                                         ViInt32   startIndex,
                                                         ViInt32   endIndex);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOFilterData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   filterData,
                                                        ViString  startData,
                                                        ViString  endData);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolHBTOFilterErrorEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ProtocolHBTOFilterReset(ViSession instrSession,
                                                ViInt32   serialBus);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsState(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  resultsState);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrame(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  type,
                                                      ViReal64* frameStart,
                                                      ViReal64* frameEnd);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsCount(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  count);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsBitRate(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViReal64* bitRate);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsByteCount(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  byteCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameByteCount(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  byteCount);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameByteState(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  byteState);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameByteValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32*  byteValue);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameByteFormattedValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32   bufferSize,
                            ViChar    formattedValue[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameByteLabel(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byte,
                            ViInt32   bufferSize,
                            ViChar    byteLabel[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsData(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   bufferSize,
                                                     ViChar    resultsData[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameCRC(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  CRC);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameDestinationAddress(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* destinationAddress);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameDestinationSymbol(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* destinationSymbol);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameFormatedCRC(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    formatedCRC[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameFormatedData(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    formatedData[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameFormatedDestinationAddress(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    destinationAddress[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameFormatedSRCAddress(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    SRCAddress[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsFrameFormatedTypeLength(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    typeLength[]);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsSourceAddress(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* sourceAddress);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsSourceSymbol(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViReal64* sourceSymbol);

ViStatus _VI_FUNC rsmxo_QueryProtocolHBTOResultsTypeLength(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32*  typeLength);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolExport(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean includeTiming,
                                                ViBoolean includeDetails);

ViStatus _VI_FUNC rsmxo_SaveProtocolExportFile(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViString  fileName);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolExportExtension(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   exportExtension);

ViStatus _VI_FUNC rsmxo_ConfigureProtocolExportPath(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViString  protocolExportPath);

ViStatus _VI_FUNC rsmxo_EnableLogic(ViSession instrSession,
                                    ViInt32   logic,
                                    ViBoolean state);

ViStatus _VI_FUNC rsmxo_ConfigureLogicSettings(ViSession instrSession,
                                               ViInt32   logic,
                                               ViBoolean showDigitalSignals,
                                               ViInt32   technology,
                                               ViBoolean levelCoupling);

ViStatus _VI_FUNC rsmxo_ConfigureLogicSkew(ViSession instrSession,
                                           ViInt32   logic,
                                           ViReal64  skew);

ViStatus _VI_FUNC rsmxo_LogicClear(ViSession instrSession,
                                   ViInt32   logic);

ViStatus _VI_FUNC rsmxo_ConfigureLogicChannelGroupThreshold(ViSession instrSession,
                                                            ViInt32   logic,
                                                            ViInt32   channelGroup,
                                                            ViReal64  threshold);

ViStatus _VI_FUNC rsmxo_ConfigureLogicChannelGroupHysteresis(ViSession instrSession,
                                                             ViInt32   logic,
                                                             ViInt32   channelGroup,
                                                             ViInt32   hysteresis);

ViStatus _VI_FUNC rsmxo_ConfigureLogicBitSettings(ViSession instrSession,
                                                  ViInt32   logic,
                                                  ViInt32   bit,
                                                  ViBoolean state,
                                                  ViString  label,
                                                  ViReal64  skew);

ViStatus _VI_FUNC rsmxo_ConfigureLogicPosition(ViSession instrSession,
                                               ViInt32   logic,
                                               ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureLogicSizeOfTheDisplay(ViSession instrSession,
                                                       ViInt32   logic,
                                                       ViReal64  sizeOfTheDisplay);

ViStatus _VI_FUNC rsmxo_ConfigureLogicDigitalChannelVerticalPosition(
                            ViSession instrSession,
                            ViInt32   logic,
                            ViReal64  position);

ViStatus _VI_FUNC rsmxo_ConfigureLogicDigitalChannelSizeOfTheDisplay(
                            ViSession instrSession,
                            ViInt32   logic,
                            ViReal64  sizeOfTheDisplay);

ViStatus _VI_FUNC rsmxo_ConfigureLogicBusShow(ViSession instrSession,
                                              ViInt32   logic,
                                              ViBoolean showBus);

ViStatus _VI_FUNC rsmxo_ConfigureLogicBusClocked(ViSession instrSession,
                                                 ViInt32   logic,
                                                 ViBoolean busClocked,
                                                 ViInt32   clockSource,
                                                 ViInt32   clockSlope);

ViStatus _VI_FUNC rsmxo_ConfigureLogicBusDataFormat(ViSession instrSession,
                                                    ViInt32   logic,
                                                    ViInt32   dataFormat);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelState(ViSession instrSession,
                                                     ViInt32   digitalChannel,
                                                     ViBoolean state);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelTechnology(ViSession instrSession,
                                                          ViInt32   digitalChannel,
                                                          ViInt32   technology);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelSkew(ViSession instrSession,
                                                    ViInt32   digitalChannel,
                                                    ViReal64  skew);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelLabel(ViSession instrSession,
                                                     ViInt32   digitalChannel,
                                                     ViString  label);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelSize(ViSession instrSession,
                                                    ViInt32   digitalChannel,
                                                    ViReal64  size);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelTHCoupling(ViSession instrSession,
                                                          ViInt32   digitalChannel,
                                                          ViBoolean THCoupling);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelThreshold(ViSession instrSession,
                                                         ViInt32   digitalChannel,
                                                         ViReal64  threshold);

ViStatus _VI_FUNC rsmxo_ConfigureLogicDecodeTableShow(ViSession instrSession,
                                                      ViInt32   logic,
                                                      ViBoolean decodeTableShow);

ViStatus _VI_FUNC rsmxo_QueryLogicDecodeTableNumberOfRows(ViSession instrSession,
                                                          ViInt32   logic,
                                                          ViInt32*  numberOfRows);

ViStatus _VI_FUNC rsmxo_LogicDecodeTableData(ViSession instrSession,
                                             ViInt32   logic,
                                             ViInt32   bufferSize,
                                             ViReal64  tableData[]);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAutoscale(
                            ViSession instrSession,
                            ViBoolean autoscale);

ViStatus _VI_FUNC rsmxo_FrequencyResponseAnalysisCalibrationStart(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisCalibrationResult(
                            ViSession instrSession,
                            ViInt32*  result);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisCalibrationState(
                            ViSession instrSession,
                            ViBoolean calibrationState);

ViStatus _VI_FUNC rsmxo_EnableFrequencyResponseAnalysis(ViSession instrSession,
                                                        ViBoolean frequencyResponseAnalysis);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisSettings(
                            ViSession instrSession,
                            ViInt32   input,
                            ViInt32   output,
                            ViInt32   generator);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisSweepBounds(
                            ViSession instrSession,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPointsMode(
                            ViSession instrSession,
                            ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPointsTotal(
                            ViSession instrSession,
                            ViInt32   points);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPointsLogarithmic(
                            ViSession instrSession,
                            ViInt32   points);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisUserLoad(
                            ViSession instrSession,
                            ViInt32   userLoad);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeMode(
                            ViSession instrSession,
                            ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitude(
                            ViSession instrSession,
                            ViReal64  amplitude);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisRepeat(
                            ViSession instrSession,
                            ViBoolean repeat);

ViStatus _VI_FUNC rsmxo_ResetFrequencyResponseAnalysis(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_RunFrequencyResponseAnalysis(ViSession instrSession,
                                                     ViInt32   action);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisDisplaySettings(
                            ViSession instrSession,
                            ViBoolean displayPoints,
                            ViBoolean resultsTable,
                            ViBoolean markers,
                            ViBoolean margin);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisMaximumPhase(
                            ViSession instrSession,
                            ViReal64  maximumPhase);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisMeasurementDelay(
                            ViSession instrSession,
                            ViBoolean enabled,
                            ViReal64  delayTime);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisRBW(
                            ViSession instrSession,
                            ViInt32   RBW);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeProfilePoint(
                            ViSession instrSession,
                            ViInt32   profilePoint,
                            ViReal64  frequency,
                            ViReal64  amplitude);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisAmplitudeProfilePointCount(
                            ViSession instrSession,
                            ViInt32*  profilePointCount);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeProfileVoltageChange(
                            ViSession instrSession,
                            ViInt32   voltageChange);

ViStatus _VI_FUNC rsmxo_SortFrequencyResponseAnalysisAmplitudeProfile(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_AddFrequencyResponseAnalysisAmplitudeProfilePoint(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_DeleteFrequencyResponseAnalysisAmplitudeProfilePoint(
                            ViSession instrSession,
                            ViInt32   profilePoint);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisGainEnabled(
                            ViSession instrSession,
                            ViBoolean gain);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisGainVerticalSettings(
                            ViSession instrSession,
                            ViReal64  verticalScale,
                            ViReal64  verticalOffset);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPhaseEnabled(
                            ViSession instrSession,
                            ViBoolean phase);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPhaseSettings(
                            ViSession instrSession,
                            ViReal64  verticalScale,
                            ViReal64  verticalOffset);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeEnabled(
                            ViSession instrSession,
                            ViBoolean amplitude);

ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeSettings(
                            ViSession instrSession,
                            ViReal64  verticalScale,
                            ViReal64  verticalOffset);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisGainMargin(
                            ViSession instrSession,
                            ViReal64* frequency,
                            ViReal64* value);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisPhaseMargin(
                            ViSession instrSession,
                            ViReal64* frequency,
                            ViReal64* value);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisGainData(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisPhaseData(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisFrequencyData(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisMarkerResults(
                            ViSession instrSession,
                            ViInt32   marker,
                            ViReal64* frequency,
                            ViReal64* gain,
                            ViReal64* phase);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisEnabled(ViSession instrSession,
                                                      ViInt32   powerAnalysis,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisType(ViSession instrSession,
                                                   ViInt32   powerAnalysis,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsmxo_PowerAnalysisAutoDeskewAdjustment(ViSession instrSession,
                                                          ViInt32   powerAnalysis);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisExportResults(ViSession instrSession,
                                                            ViInt32   powerAnalysis,
                                                            ViBoolean exportResults);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisQualityCurrentSource(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisQualityVoltageSource(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisQualityFundamentalFrequency(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   frequency,
                            ViInt32   userFrequency);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsCurrentCrestFactor(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsCurrentPeak(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsCurrentRMS(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsPowerApparent(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsPowerFactor(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsPowerPhase(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsPowerReactive(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsPowerActive(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsVoltageCrestFactor(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsVoltageFrequency(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsVoltagePeak(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisQualityResultsVoltageRMS(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   statisticsType,
                            ViReal64* result);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsCurrentSource(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsVoltageSource(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsStandard(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   standard);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsFundamentalFrequency(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   EN,
                            ViInt32   MIL,
                            ViInt32   RTCA);

ViStatus _VI_FUNC rsmxo_PowerAnalysisHarmonicsClearResults(ViSession instrSession,
                                                           ViInt32   powerAnalysis);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsDisplay(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   display);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsDisplayFrequency(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   start,
                            ViInt32   stop);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisHarmonicsScaling(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   scaling);

ViStatus _VI_FUNC rsmxo_QueryPowerAnalysisHarmonicsResultsMeasuredHarmonics(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32*  harmonics);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsTHDF(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViReal64* THDF);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsTHDRMS(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViReal64* THDRMS);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsFrequencyCurrent(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViReal64* frequencyCurrent);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsRealPower(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViReal64* realPower);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsViolation(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerHarmonics,
                            ViInt32*  violation);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsFrequency(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerHarmonics,
                            ViReal64* frequency);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsMagnitudePercent(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerHarmonics,
                            ViReal64* currentPercent,
                            ViReal64* maximumPercent,
                            ViReal64* minimumPercent);

ViStatus _VI_FUNC rsmxo_FetchPowerAnalysisHarmonicsResultsMagnitudeRMS(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerHarmonics,
                            ViReal64* currentRMS,
                            ViReal64* maximumRMS,
                            ViReal64* minimumRMS);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisRefLevelHysteresisAbsolute(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerReference,
                            ViInt32   type,
                            ViReal64  hysteresisAbsolute);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisRefLevelLevelMode(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerReference,
                            ViInt32   type,
                            ViInt32   levelMode);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisRefLevelAbsoluteLevel(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerReference,
                            ViInt32   type,
                            ViReal64  lowerLevel,
                            ViReal64  middleLevel,
                            ViReal64  upperLevel);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisRefLevelRelativeLevel(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerReference,
                            ViInt32   type,
                            ViReal64  lowerLevel,
                            ViReal64  middleLevel,
                            ViReal64  upperLevel);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisRefLevelHysteresisRelative(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerReference,
                            ViInt32   type,
                            ViInt32   hysteresisRelative);

ViStatus _VI_FUNC rsmxo_ConfigurePowerAnalysisRefLevelRelativeLevels(
                            ViSession instrSession,
                            ViInt32   powerAnalysis,
                            ViInt32   powerReference,
                            ViInt32   type,
                            ViInt32   relativeLevels);

ViStatus _VI_FUNC rsmxo_QueryPowerAnalysisDataHeader(ViSession instrSession,
                                                     ViInt32   powerAnalysis,
                                                     ViInt32   type,
                                                     ViReal64* xStart,
                                                     ViReal64* xStop,
                                                     ViInt32*  recordLength,
                                                     ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_ReadHarmonics(ViSession instrSession,
                                      ViInt32   powerAnalysis,
                                      ViInt32   waveformArraySize,
                                      ViReal64  offset,
                                      ViReal64  length,
                                      ViInt32   timeout,
                                      ViReal64  waveform[],
                                      ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchHarmonics(ViSession instrSession,
                                       ViInt32   powerAnalysis,
                                       ViInt32   waveformArraySize,
                                       ViReal64  offset,
                                       ViReal64  length,
                                       ViReal64  waveform[],
                                       ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadQuality(ViSession instrSession,
                                    ViInt32   powerAnalysis,
                                    ViInt32   waveformArraySize,
                                    ViReal64  offset,
                                    ViReal64  length,
                                    ViInt32   timeout,
                                    ViReal64  waveform[],
                                    ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchQuality(ViSession instrSession,
                                     ViInt32   powerAnalysis,
                                     ViInt32   waveformArraySize,
                                     ViReal64  offset,
                                     ViReal64  length,
                                     ViReal64  waveform[],
                                     ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalVoltmeterDCEnabled(ViSession instrSession,
                                                           ViInt32   voltmeterChannel,
                                                           ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_FetchDigitalVoltmeterDCResult(ViSession instrSession,
                                                      ViInt32   voltmeterChannel,
                                                      ViReal64* DCResult);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalVoltmeterACRMSEnabled(
                            ViSession instrSession,
                            ViInt32   voltmeterChannel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_FetchDigitalVoltmeterACRMSResult(ViSession instrSession,
                                                         ViInt32   voltmeterChannel,
                                                         ViReal64* ACRMSResult);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalVoltmeterDCRMSEnabled(
                            ViSession instrSession,
                            ViInt32   voltmeterChannel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_FetchDigitalVoltmeterDCRMSResult(ViSession instrSession,
                                                         ViInt32   voltmeterChannel,
                                                         ViReal64* DCRMSResult);

ViStatus _VI_FUNC rsmxo_QueryDigitalVoltmeterState(ViSession  instrSession,
                                                   ViInt32    voltmeterChannel,
                                                   ViBoolean* digitalVoltmeterState);

ViStatus _VI_FUNC rsmxo_ConfigureDigitalVoltmeterBandwidth(ViSession instrSession,
                                                           ViInt32   bandwidth);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformSetup(ViSession instrSession,
                                                        ViInt32   referenceWaveform,
                                                        ViBoolean show,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsmxo_CreateUpdateReferenceWaveform(ViSession instrSession,
                                                      ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_ClearReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_ResetReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_AbortReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformName(ViSession instrSession,
                                                       ViInt32   referenceWaveform,
                                                       ViString  fileName);

ViStatus _VI_FUNC rsmxo_SaveReferenceWaveform(ViSession instrSession,
                                              ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_OpenReferenceWaveform(ViSession instrSession,
                                              ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalMode(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalScale(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViReal64  verticalScale);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalPosition(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViReal64  verticalPosition);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalOffset(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViReal64  verticalOffset);

ViStatus _VI_FUNC rsmxo_SetVerticalSettingsToOriginal(ViSession instrSession,
                                                      ViInt32   referenceWaveform);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformRescaleVertical(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViBoolean enabled,
                            ViReal64  scaleFactor,
                            ViReal64  offset);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformRescaleHorizontalMode(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformRescaleHorizontal(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViBoolean enable,
                            ViReal64  scaleFactor,
                            ViReal64  offset);

ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformXAxisMode(ViSession instrSession,
                                                            ViInt32   referenceWaveform,
                                                            ViInt32   mode);

ViStatus _VI_FUNC rsmxo_EnableGenerator(ViSession instrSession,
                                        ViInt32   generator,
                                        ViBoolean state);

ViStatus _VI_FUNC rsmxo_EnableGeneratorInversion(ViSession instrSession,
                                                 ViInt32   generator,
                                                 ViBoolean inversion);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorFunctionType(ViSession instrSession,
                                                       ViInt32   generator,
                                                       ViInt32   functionType);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorFrequency(ViSession instrSession,
                                                    ViInt32   generator,
                                                    ViReal64  frequency);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorAmplitude(ViSession instrSession,
                                                    ViInt32   generator,
                                                    ViReal64  amplitude);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorOffset(ViSession instrSession,
                                                 ViInt32   generator,
                                                 ViReal64  offset);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSymmetry(ViSession instrSession,
                                                   ViInt32   generator,
                                                   ViReal64  symmetry);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorDutyCycle(ViSession instrSession,
                                                    ViInt32   generator,
                                                    ViReal64  dutyCycle);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorPeriod(ViSession instrSession,
                                                 ViInt32   generator,
                                                 ViReal64  period);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorPulseWidth(ViSession instrSession,
                                                     ViInt32   generator,
                                                     ViReal64  pulseWidth);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorNoiseLevelInPercent(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  noiseLevel);

ViStatus _VI_FUNC rsmxo_QueryGeneratorNoiseLevelAbsolute(ViSession instrSession,
                                                         ViInt32   generator,
                                                         ViReal64* absoluteNoiseLevel);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorDCSettings(ViSession instrSession,
                                                     ViInt32   generator,
                                                     ViReal64  DCLevel,
                                                     ViReal64  noiseLevel);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorVoltage(ViSession instrSession,
                                                  ViInt32   generator,
                                                  ViReal64  lowVoltage,
                                                  ViReal64  highVoltage);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorUserLoad(ViSession instrSession,
                                                   ViInt32   generator,
                                                   ViInt32   userLoad);

ViStatus _VI_FUNC rsmxo_GeneratorDefaultSetup(ViSession instrSession,
                                              ViInt32   generator);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSweepSettings(ViSession instrSession,
                                                        ViInt32   generator,
                                                        ViBoolean state,
                                                        ViInt32   type,
                                                        ViReal64  startFrequency,
                                                        ViReal64  stopFrequency,
                                                        ViReal64  sweepTime);

ViStatus _VI_FUNC rsmxo_GeneratorSave(ViSession instrSession,
                                      ViString  generatorSave);

ViStatus _VI_FUNC rsmxo_GeneratorRecall(ViSession instrSession,
                                        ViString  generatorRecall);

ViStatus _VI_FUNC rsmxo_EnableGeneratorModulation(ViSession instrSession,
                                                  ViInt32   generator,
                                                  ViBoolean modulation);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationSetup(ViSession instrSession,
                                                          ViInt32   generator,
                                                          ViInt32   type);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationCarrierSettings(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  period,
                            ViReal64  frequency);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMSignalType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signalType);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMDepth(ViSession instrSession,
                                                            ViInt32   generator,
                                                            ViReal64  depth);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMSignalType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signalType);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMDepth(ViSession instrSession,
                                                             ViInt32   generator,
                                                             ViReal64  depth);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMSignalType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signalType);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMDeviation(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  deviation);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFSKSettings(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency1,
                            ViReal64  frequency2,
                            ViReal64  FSKRate);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitraryWaveformSource(
                            ViSession instrSession,
                            ViInt32   arbitraryWaveformSource);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitraryWaveformName(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViString  name);

ViStatus _VI_FUNC rsmxo_OpenGeneratorArbitraryWaveform(ViSession instrSession,
                                                       ViInt32   generator);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitraryRunMode(ViSession instrSession,
                                                           ViInt32   generator,
                                                           ViInt32   runMode);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitrarySampleRate(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  sampleRate);

ViStatus _VI_FUNC rsmxo_QueryGeneratorArbitraryNumberOfSamples(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  numberOfSamples);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitrarySignalSource(
                            ViSession instrSession,
                            ViInt32   source);

ViStatus _VI_FUNC rsmxo_GeneratorArbitraryWaveformRunSingle(ViSession instrSession,
                                                            ViInt32   generator);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSynchronisationStart(
                            ViSession instrSession,
                            ViInt32   synchronisationStart);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorCouplingSettings(ViSession instrSession,
                                                           ViInt32   generator,
                                                           ViBoolean amplitudeParameters,
                                                           ViBoolean frequencyParameters);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSynchronisationPhaseShift(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  phaseShift);

ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSynchronisationCouplingEnabled(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorTemperatureEnabled(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorTemperatureTransition(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterGeneratorTemperature(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  condition,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorGOverloadEnabled(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorGOverloadTransition(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterGeneratorGOverload(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  condition,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_IncludeSavesetPreviewImage(ViSession instrSession,
                                                   ViBoolean includePreviewImage);

ViStatus _VI_FUNC rsmxo_SaveInstrumentSettingsFile(ViSession instrSession,
                                                   ViString  fileName);

ViStatus _VI_FUNC rsmxo_LoadInstrumentSettingsFile(ViSession instrSession,
                                                   ViString  fileName);

ViStatus _VI_FUNC rsmxo_QueryDrivesCatalog(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    drivesCatalog[],
                                           ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_QueryMemoryCatalogSize(ViSession instrSession,
                                               ViString  path,
                                               ViInt32*  catalogSize);

ViStatus _VI_FUNC rsmxo_QueryMemoryCatalog(ViSession instrSession,
                                           ViString  path,
                                           ViInt32   format,
                                           ViInt32   bufferSize,
                                           ViChar    catalog[],
                                           ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_LoadWaveformGeneratorSettings(ViSession instrSession,
                                                      ViString  waveformGeneratorSettings);

ViStatus _VI_FUNC rsmxo_StoreWaveformGeneratorSettings(ViSession instrSession,
                                                       ViString  waveformGeneratorSettings);

ViStatus _VI_FUNC rsmxo_DeleteFile(ViSession instrSession,
                                   ViString  fileName);

ViStatus _VI_FUNC rsmxo_CopyFile(ViSession instrSession,
                                 ViString  fileSource,
                                 ViString  fileDestination);

ViStatus _VI_FUNC rsmxo_MoveFile(ViSession instrSession,
                                 ViString  fileSource,
                                 ViString  fileDestination);

ViStatus _VI_FUNC rsmxo_ConfigureFileAttribute(ViSession instrSession,
                                               ViString  fileName,
                                               ViString  attributes);

ViStatus _VI_FUNC rsmxo_ConfigureDefaultDirectory(ViSession instrSession,
                                                  ViString  directory);

ViStatus _VI_FUNC rsmxo_CreateDirectory(ViSession instrSession,
                                        ViString  directory);

ViStatus _VI_FUNC rsmxo_DeleteDirectory(ViSession instrSession,
                                        ViString  directory);

ViStatus _VI_FUNC rsmxo_QueryDirectoryCatalogSize(ViSession instrSession,
                                                  ViString  path,
                                                  ViInt32*  catalogSize);

ViStatus _VI_FUNC rsmxo_QueryDirectoryCatalog(ViSession instrSession,
                                              ViString  directoryPath,
                                              ViInt32   bufferSize,
                                              ViChar    directoryCatalog[],
                                              ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_ConfigureScreenshotSettings(ViSession instrSession,
                                                    ViBoolean showSetupDialog,
                                                    ViBoolean whiteBackground,
                                                    ViBoolean includeSignalBar);

ViStatus _VI_FUNC rsmxo_ConfigureScreenshotColorSettings(ViSession instrSession,
                                                         ViInt32   reserved,
                                                         ViBoolean invertColor);

ViStatus _VI_FUNC rsmxo_ConfigureScreenshotFilePath(ViSession instrSession,
                                                    ViString  filePath,
                                                    ViInt32   fileExtension);

ViStatus _VI_FUNC rsmxo_SaveScreenshot(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_SaveScreenshotNext(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureWaveformExportSettings(ViSession instrSession,
                                                        ViInt32   source,
                                                        ViInt32   mode);

ViStatus _VI_FUNC rsmxo_ConfigureWaveformExportManualRange(ViSession instrSession,
                                                           ViReal64  start,
                                                           ViReal64  stop);

ViStatus _VI_FUNC rsmxo_SelectWaveformExportGate(ViSession instrSession,
                                                 ViInt32   gate);

ViStatus _VI_FUNC rsmxo_SelectWaveformExportCursorSet(ViSession instrSession,
                                                      ViInt32   cursorSet);

ViStatus _VI_FUNC rsmxo_ConfigureWaveformFileName(ViSession instrSession,
                                                  ViString  filePath);

ViStatus _VI_FUNC rsmxo_SaveWaveformToFile(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_AbortWaveformSave(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureResultsExportSettings(ViSession instrSession,
                                                       ViBoolean includeCurrentMeasurement,
                                                       ViBoolean includeCursor);

ViStatus _VI_FUNC rsmxo_ConfigureResultsExportFileName(ViSession instrSession,
                                                       ViString  fileName);

ViStatus _VI_FUNC rsmxo_ResultsExportSaveToFile(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureResultsExportFRA(ViSession instrSession,
                                                  ViBoolean margin,
                                                  ViBoolean marker,
                                                  ViBoolean result);

ViStatus _VI_FUNC rsmxo_ConfigureSystemHostName(ViSession instrSession,
                                                ViString  deviceName);

ViStatus _VI_FUNC rsmxo_ConfigureSystemDate(ViSession instrSession,
                                            ViInt32   year,
                                            ViInt32   month,
                                            ViInt32   day);

ViStatus _VI_FUNC rsmxo_QuerySystemDate(ViSession instrSession,
                                        ViInt32*  year,
                                        ViInt32*  month,
                                        ViInt32*  day);

ViStatus _VI_FUNC rsmxo_ConfigureSystemTime(ViSession instrSession,
                                            ViInt32   hours,
                                            ViInt32   minutes,
                                            ViInt32   seconds);

ViStatus _VI_FUNC rsmxo_QuerySystemTime(ViSession instrSession,
                                        ViInt32*  hour,
                                        ViInt32*  minutes,
                                        ViInt32*  seconds);

ViStatus _VI_FUNC rsmxo_SystemExit(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_SystemShutdown(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_SystemPreset(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureSystemFilenameFirmwareInstallationFile(
                            ViSession instrSession,
                            ViString  firmwareInstallationFile);

ViStatus _VI_FUNC rsmxo_SystemStartFirmwareUpdate(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureTransferDataFormat(ViSession instrSession,
                                                    ViInt32   transferDataFormat);

ViStatus _VI_FUNC rsmxo_ConfigureBitpatternFormat(ViSession instrSession,
                                                  ViInt32   bitpatternFormat);

ViStatus _VI_FUNC rsmxo_ConfigureDisplaySettings(ViSession instrSession,
                                                 ViBoolean displayUpdate,
                                                 ViBoolean displayMessage,
                                                 ViString  message);

ViStatus _VI_FUNC rsmxo_QuerySignalNameCatalog(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    signalNames[],
                                               ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_UseColorTable(ViSession instrSession,
                                      ViString  signalName,
                                      ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_QueryColorTableUse(ViSession  instrSession,
                                           ViString   signalName,
                                           ViBoolean* enabled);

ViStatus _VI_FUNC rsmxo_AssignColorTable(ViSession instrSession,
                                         ViString  signalName,
                                         ViInt32   colorTable);

ViStatus _VI_FUNC rsmxo_QueryAssignedColorTable(ViSession instrSession,
                                                ViString  signalName,
                                                ViInt32*  colorTable);

ViStatus _VI_FUNC rsmxo_SelectSignalColor(ViSession instrSession,
                                          ViString  signalName,
                                          ViInt32   color);

ViStatus _VI_FUNC rsmxo_QuerySelectedSignalColor(ViSession instrSession,
                                                 ViString  signalName,
                                                 ViInt32*  color);

ViStatus _VI_FUNC rsmxo_ConfigureGridAppearance(ViSession instrSession,
                                                ViBoolean showGrid,
                                                ViBoolean showLabels,
                                                ViBoolean showFineGridScale,
                                                ViBoolean showCrosshair,
                                                ViBoolean keepYGridFixed);

ViStatus _VI_FUNC rsmxo_ConfigureGridKeepXGridFixed(ViSession instrSession,
                                                    ViBoolean xGridFixed);

ViStatus _VI_FUNC rsmxo_EnableSmartGridNode(ViSession instrSession,
                                            ViInt32   layout,
                                            ViInt32   node,
                                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_QuerySmartGridNodeCount(ViSession instrSession,
                                                ViInt32   layout,
                                                ViInt32   node,
                                                ViInt32*  count);

ViStatus _VI_FUNC rsmxo_AddSmartGridLayout(ViSession instrSession,
                                           ViInt32   layout,
                                           ViBoolean enabled,
                                           ViString  label);

ViStatus _VI_FUNC rsmxo_QuerySmartGridLayoutCount(ViSession instrSession,
                                                  ViInt32*  layoutCount);

ViStatus _VI_FUNC rsmxo_ConfigureSmartGridLayoutActive(ViSession instrSession,
                                                       ViInt32   active);

ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeID(ViSession instrSession,
                                                 ViInt32   layout,
                                                 ViInt32   node,
                                                 ViInt32   child,
                                                 ViInt32   content,
                                                 ViInt32   ID);

ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeType(ViSession instrSession,
                                                   ViInt32   layout,
                                                   ViInt32   node,
                                                   ViInt32   child,
                                                   ViInt32   content,
                                                   ViInt32   smartGridType);

ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeSplitRatio(ViSession instrSession,
                                                         ViInt32   layout,
                                                         ViInt32   node,
                                                         ViReal64  splitRatio);

ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeSplitType(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   node,
                                                        ViInt32   splitType);

ViStatus _VI_FUNC rsmxo_AddSmartGridDiagram(ViSession instrSession,
                                            ViInt32   layout,
                                            ViInt32   diagram,
                                            ViBoolean enabled,
                                            ViString  label);

ViStatus _VI_FUNC rsmxo_QuerySmartGridDiagramCount(ViSession instrSession,
                                                   ViInt32   layout,
                                                   ViInt32*  diagramCount);

ViStatus _VI_FUNC rsmxo_ConfigureSmartGridDiagramSource(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   diagram,
                                                        ViString  source);

ViStatus _VI_FUNC rsmxo_ConfigureDialogFontSize(ViSession instrSession,
                                                ViInt32   fontSize);

ViStatus _VI_FUNC rsmxo_ConfigureDialogResultFontSize(ViSession instrSession,
                                                      ViInt32   fontSize);

ViStatus _VI_FUNC rsmxo_ConfigureDialogTransparency(ViSession instrSession,
                                                    ViInt32   transparency);

ViStatus _VI_FUNC rsmxo_ConfigureDisplaySignalSettings(ViSession instrSession,
                                                       ViInt32   style,
                                                       ViReal64  intensity);

ViStatus _VI_FUNC rsmxo_ConfigureDisplayPersistenceSettings(ViSession instrSession,
                                                            ViBoolean enable,
                                                            ViBoolean infinitePersistence,
                                                            ViReal64  time);

ViStatus _VI_FUNC rsmxo_ConfigureDisplayBacklightBrightness(ViSession instrSession,
                                                            ViInt32   backlightBrightness);

ViStatus _VI_FUNC rsmxo_ConfigureDisplayBacklightDimmOnUserInactivity(
                            ViSession instrSession,
                            ViInt32   dimmAfter);

ViStatus _VI_FUNC rsmxo_DisplayClearResults(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ResetDisplayPersistenceSettings(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_QueryNumberOfTools(ViSession instrSession,
                                           ViInt32*  tools);

ViStatus _VI_FUNC rsmxo_ToolbarRemoveAllTools(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ToolbarReset(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_EnableAutoPowerUp(ViSession instrSession,
                                          ViBoolean autoPowerUp);

ViStatus _VI_FUNC rsmxo_ExecuteAlignment(ViSession instrSession,
                                         ViInt32   maximumTimeMs);

ViStatus _VI_FUNC rsmxo_QueryAlignmentDate(ViSession instrSession,
                                           ViChar    date[]);

ViStatus _VI_FUNC rsmxo_QueryAlignmentTime(ViSession instrSession,
                                           ViChar    time[]);

ViStatus _VI_FUNC rsmxo_QueryAlignmentResult(ViSession instrSession,
                                             ViInt32*  result);

ViStatus _VI_FUNC rsmxo_CreateServiceReport(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureCSVDelimiter(ViSession instrSession,
                                              ViInt32   delimiter);

ViStatus _VI_FUNC rsmxo_ConfigureAutosaveSettings(ViSession instrSession,
                                                  ViBoolean autosave,
                                                  ViInt32   interval);

ViStatus _VI_FUNC rsmxo_ConfigureAutonamingPattern(ViSession instrSession,
                                                   ViBoolean userText,
                                                   ViBoolean prefix,
                                                   ViBoolean dateTime,
                                                   ViBoolean index);

ViStatus _VI_FUNC rsmxo_ConfigureAutonamingUserText(ViSession instrSession,
                                                    ViString  userText);

ViStatus _VI_FUNC rsmxo_ConfigureDefaultPathForAllFileOperations(
                            ViSession instrSession,
                            ViString  path);

ViStatus _VI_FUNC rsmxo_ResetPath(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ResetAllAutonamingSettings(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_reset(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rsmxo_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[]);

ViStatus _VI_FUNC rsmxo_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[]);

ViStatus _VI_FUNC rsmxo_ErrorList(ViSession instrSession,
                                  ViInt32   bufferSize,
                                  ViChar    errors[]);

ViStatus _VI_FUNC rsmxo_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking);

ViStatus _VI_FUNC rsmxo_SetOPCTimeout(ViSession instrSession,
                                      ViInt32   OPCTimeout);

ViStatus _VI_FUNC rsmxo_GetOPCTimeout(ViSession instrSession,
                                      ViInt32*  timeout);

ViStatus _VI_FUNC rsmxo_SetVISATimeout(ViSession instrSession,
                                       ViInt32   VISATimeout);

ViStatus _VI_FUNC rsmxo_GetVISATimeout(ViSession instrSession,
                                       ViInt32*  VISATimeout);

ViStatus _VI_FUNC rsmxo_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_IDQueryResponse(ViSession instrSession,
                                        ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rsmxo_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC);

ViStatus _VI_FUNC rsmxo_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rsmxo_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rsmxo_OPCSyncWriteEnable(ViSession instrSession,
                                           ViBoolean enable);

ViStatus _VI_FUNC rsmxo_OPCSyncQueryEnable(ViSession instrSession,
                                           ViBoolean enable);

ViStatus _VI_FUNC rsmxo_SetOpcSyncQueryMechanism(ViSession instrSession,
                                                 ViBoolean useESB,
                                                 ViBoolean CLSBefore,
                                                 ViBoolean useMAV);

ViStatus _VI_FUNC rsmxo_GetError(ViSession instrSession,
                                 ViStatus* code,
                                 ViInt32   bufferSize,
                                 ViChar    description[]);

ViStatus _VI_FUNC rsmxo_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer);

ViStatus _VI_FUNC rsmxo_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value);

ViStatus _VI_FUNC rsmxo_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value);

ViStatus _VI_FUNC rsmxo_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value);

ViStatus _VI_FUNC rsmxo_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[]);

ViStatus _VI_FUNC rsmxo_WriteCommandWithOPCSync(ViSession instrSession,
                                                ViString  writeBuffer,
                                                ViInt32   timeout);

ViStatus _VI_FUNC rsmxo_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  sourceInstrumentFile,
                                                 ViString  destinationPCFile);

ViStatus _VI_FUNC rsmxo_WriteFromFileToInstrument(ViSession instrSession,
                                                  ViString  sourcePCFile,
                                                  ViString  destinationInstrumentFile);

ViStatus _VI_FUNC rsmxo_FetchChannelWaveformHeader(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64* xStart,
                                                   ViReal64* xStop,
                                                   ViInt32*  recordLength,
                                                   ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchChannelWaveform(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   waveformArraySize,
                                             ViReal64  waveformData[],
                                             ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchChannelWaveformFloat(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   waveformArraySize,
                                                  ViReal32  waveformData[],
                                                  ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchDigitalWaveformHeader(ViSession instrSession,
                                                   ViInt32   digitalChannel,
                                                   ViReal64* xStart,
                                                   ViReal64* xStop,
                                                   ViInt32*  recordLength,
                                                   ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchDigitalWaveform(ViSession instrSession,
                                             ViInt32   digitalChannel,
                                             ViInt32   waveformArraySize,
                                             ViInt32   waveformData[],
                                             ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchLogicHeader(ViSession instrSession,
                                         ViInt32   logic,
                                         ViReal64* xStart,
                                         ViReal64* xStop,
                                         ViInt32*  recordLength,
                                         ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchLogicWaveform(ViSession instrSession,
                                           ViInt32   logic,
                                           ViInt32   waveformArraySize,
                                           ViInt32   waveformData[],
                                           ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchMathWaveformHeader(ViSession instrSession,
                                                ViInt32   math,
                                                ViReal64* xStart,
                                                ViReal64* xStop,
                                                ViInt32*  recordLength,
                                                ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchMathWaveform(ViSession instrSession,
                                          ViInt32   math,
                                          ViInt32   waveformArraySize,
                                          ViReal64  waveformData[],
                                          ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchMathWaveformFloat(ViSession instrSession,
                                               ViInt32   math,
                                               ViInt32   waveformArraySize,
                                               ViReal32  waveformData[],
                                               ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchReferenceWaveformHeader(ViSession instrSession,
                                                     ViInt32   referenceWaveform,
                                                     ViReal64* xStart,
                                                     ViReal64* xStop,
                                                     ViInt32*  recordLength,
                                                     ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform,
                                               ViInt32   waveformArraySize,
                                               ViReal64  waveformData[],
                                               ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchReferenceWaveformFloat(ViSession instrSession,
                                                    ViInt32   referenceWaveform,
                                                    ViInt32   waveformArraySize,
                                                    ViReal32  waveformData[],
                                                    ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchSpectrumWaveformHeader(ViSession instrSession,
                                                    ViInt32   spectrum,
                                                    ViInt32   trace,
                                                    ViReal64* xStart,
                                                    ViReal64* xStop,
                                                    ViInt32*  recordLength,
                                                    ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchSpectrumWaveform(ViSession instrSession,
                                              ViInt32   spectrum,
                                              ViInt32   trace,
                                              ViInt32   waveformArraySize,
                                              ViReal64  waveformData[],
                                              ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchSpectrumWaveformFloat(ViSession instrSession,
                                                   ViInt32   spectrum,
                                                   ViInt32   trace,
                                                   ViInt32   waveformArraySize,
                                                   ViReal32  waveformData[],
                                                   ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchMeasurementTrackDataHeader(ViSession instrSession,
                                                        ViInt32   measurement,
                                                        ViReal64* xStart,
                                                        ViReal64* xStop,
                                                        ViInt32*  recordLength,
                                                        ViReal64* valuesPerSample);

ViStatus _VI_FUNC rsmxo_FetchMeasurementTrackData(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViInt32   waveformArraySize,
                                                  ViReal64  waveformData[],
                                                  ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchMeasurementTrackDataFloat(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViInt32   waveformArraySize,
                                                       ViReal32  waveformData[],
                                                       ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchWaveformDouble(ViSession instrSession,
                                            ViInt32   source,
                                            ViInt32   waveformArraySize,
                                            ViReal64  waveformData[],
                                            ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchWaveformFloat(ViSession instrSession,
                                           ViInt32   source,
                                           ViInt32   waveformArraySize,
                                           ViReal32  waveformData[],
                                           ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_FetchWaveformInt(ViSession instrSession,
                                         ViInt32   source,
                                         ViInt32   waveformArraySize,
                                         ViInt32   waveformData[],
                                         ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_QueryReferenceWaveformDataSource(ViSession instrSession,
                                                         ViInt32   referenceWaveform,
                                                         ViInt32   bufferSize,
                                                         ViChar    waveformDataSource[],
                                                         ViInt32*  bytesRead);

ViStatus _VI_FUNC rsmxo_ReadChannelWaveform(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   maximumTimeMs,
                                            ViInt32   waveformArraySize,
                                            ViReal64  waveformData[],
                                            ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadChannelWaveformFloat(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   maximumTimeMs,
                                                 ViInt32   waveformArraySize,
                                                 ViReal32  waveformData[],
                                                 ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadDigitalWaveform(ViSession instrSession,
                                            ViInt32   digitalChannel,
                                            ViInt32   maximumTimeMs,
                                            ViInt32   waveformArraySize,
                                            ViInt32   waveformData[],
                                            ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadLogicWaveform(ViSession instrSession,
                                          ViInt32   logic,
                                          ViInt32   maximumTimeMs,
                                          ViInt32   waveformArraySize,
                                          ViInt32   waveformData[],
                                          ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadMathWaveform(ViSession instrSession,
                                         ViInt32   math,
                                         ViInt32   maximumTimeMs,
                                         ViInt32   waveformArraySize,
                                         ViReal64  waveformData[],
                                         ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadMathWaveformFloat(ViSession instrSession,
                                              ViInt32   math,
                                              ViInt32   maximumTimeMs,
                                              ViInt32   waveformArraySize,
                                              ViReal32  waveformData[],
                                              ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadReferenceWaveform(ViSession instrSession,
                                              ViInt32   referenceWaveform,
                                              ViInt32   maximumTimeMs,
                                              ViInt32   waveformArraySize,
                                              ViReal64  waveformData[],
                                              ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadReferenceWaveformFloat(ViSession instrSession,
                                                   ViInt32   referenceWaveform,
                                                   ViInt32   maximumTimeMs,
                                                   ViInt32   waveformArraySize,
                                                   ViReal32  waveformData[],
                                                   ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadSpectrumWaveform(ViSession instrSession,
                                             ViInt32   spectrum,
                                             ViInt32   trace,
                                             ViInt32   maximumTimeMs,
                                             ViInt32   waveformArraySize,
                                             ViReal64  waveformData[],
                                             ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadSpectrumWaveformFloat(ViSession instrSession,
                                                  ViInt32   spectrum,
                                                  ViInt32   trace,
                                                  ViInt32   maximumTimeMs,
                                                  ViInt32   waveformArraySize,
                                                  ViReal32  waveformData[],
                                                  ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadMeasurementTrackData(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   maximumTimeMs,
                                                 ViInt32   waveformArraySize,
                                                 ViReal64  waveformData[],
                                                 ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadMeasurementTrackDataFloat(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViInt32   maximumTimeMs,
                                                      ViInt32   waveformArraySize,
                                                      ViReal32  waveformData[],
                                                      ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadWaveformDouble(ViSession instrSession,
                                           ViInt32   source,
                                           ViInt32   maximumTimeMs,
                                           ViInt32   waveformArraySize,
                                           ViReal64  waveformData[],
                                           ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadWaveformFloat(ViSession instrSession,
                                          ViInt32   source,
                                          ViInt32   maximumTimeMs,
                                          ViInt32   waveformArraySize,
                                          ViReal32  waveformData[],
                                          ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_ReadWaveformInt(ViSession instrSession,
                                        ViInt32   source,
                                        ViInt32   maximumTimeMs,
                                        ViInt32   waveformArraySize,
                                        ViInt32   waveformData[],
                                        ViInt32*  returnedPoints);

ViStatus _VI_FUNC rsmxo_IsMeasurementComplete(ViSession  instrSession,
                                              ViBoolean* isMeasurementComplete);

ViStatus _VI_FUNC rsmxo_WaitForMeasurementComplete(ViSession instrSession,
                                                   ViInt32   timeout);

ViStatus _VI_FUNC rsmxo_IsWaitingForTrigger(ViSession  instrSession,
                                            ViBoolean* isWaitingForTrigger);

ViStatus _VI_FUNC rsmxo_WaitForWaitingForTrigger(ViSession instrSession,
                                                 ViInt32   timeout);

ViStatus _VI_FUNC rsmxo_StatusRegisterReset(ViSession instrSession);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelNegativeClippingEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negativeClipping);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelNegativeClippingTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelNegativeClipping(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  condition,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPositiveClippingEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean positiveClipping);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPositiveClippingTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelPositiveClipping(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  condition,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelOverloadEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean overload);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelOverloadTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelOverload(ViSession  instrSession,
                                                           ViInt32    channel,
                                                           ViInt32*   condition,
                                                           ViBoolean* event);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelWarnOverloadEvent(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelWarnOverloadEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean overloadEnabled);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelWarnOverloadTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelWarnOverload(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  condition,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPPSEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPPSTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelPPS(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32*  condition,
                                                      ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementImpreciseEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean imprecise);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementImpreciseTransition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterMeasurementImprecise(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32*  condition,
                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementLimitEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean limit);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementLimitTransition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterMeasurementLimit(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32*  condition,
                                                            ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementMarginEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean margin);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementMarginTransition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean negative,
                            ViBoolean positive);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterMeasurementMargin(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32*  condition,
                                                             ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerActionEnabled(
                            ViSession instrSession,
                            ViBoolean triggerAction);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerActionTransition(
                            ViSession instrSession,
                            ViInt32   positive,
                            ViInt32   negative);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterTriggerAction(ViSession instrSession,
                                                         ViInt32*  condition,
                                                         ViInt32*  event);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerEdgeEnabled(
                            ViSession instrSession,
                            ViBoolean triggerEdge);

ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerEdgeTransition(
                            ViSession instrSession,
                            ViInt32   positive,
                            ViInt32   negative);

ViStatus _VI_FUNC rsmxo_QueryStatusRegisterTriggerEdge(ViSession instrSession,
                                                       ViInt32*  condition,
                                                       ViInt32*  event);

ViStatus _VI_FUNC rsmxo_SetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt32   attributeValue);

ViStatus _VI_FUNC rsmxo_SetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt64   attributeValue);

ViStatus _VI_FUNC rsmxo_SetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViReal64  attributeValue);

ViStatus _VI_FUNC rsmxo_SetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViString  attributeValue);

ViStatus _VI_FUNC rsmxo_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  repeatedCapability,
                                              ViAttr    attributeId,
                                              ViBoolean attributeValue);

ViStatus _VI_FUNC rsmxo_GetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt32*  attributeValue);

ViStatus _VI_FUNC rsmxo_GetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt64*  attributeValue);

ViStatus _VI_FUNC rsmxo_GetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViReal64* attributeValue);

ViStatus _VI_FUNC rsmxo_GetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[]);

ViStatus _VI_FUNC rsmxo_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   repeatedCapability,
                                              ViAttr     attributeId,
                                              ViBoolean* attributeValue);

ViStatus _VI_FUNC rsmxo_GetAttributeViStringWithRealLen(ViSession instrSession,
                                                        ViString  repeatedCapability,
                                                        ViAttr    attributeId,
                                                        ViInt32   bufferSize,
                                                        ViChar    attributeValue[],
                                                        ViInt32*  responseLength);

ViStatus _VI_FUNC rsmxo_GetAttributeRawStringWithRealLen(ViSession instrSession,
                                                         ViString  repeatedCapability,
                                                         ViAttr    attributeId,
                                                         ViInt32   bufferSize,
                                                         ViChar    attributeValue[],
                                                         ViInt32*  responseLength);

ViStatus _VI_FUNC rsmxo_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeId,
                                               ViString  repCapNameID,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[]);

ViStatus _VI_FUNC rsmxo_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeId,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rsmxo_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rsmxo_close(ViSession instrSession);

    /****************************************************************************
     *------------------------ Error And Completion Codes ----------------------*
     ****************************************************************************/

#define RSMXO_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSMXO_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)
#define RSMXO_WARN_DATA_NOT_AVAILABLE      (RS_CLASS_WARN_BASE + 0x0003L)

#define RSMXO_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSMXO_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSMXO_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSMXO_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSMXO_WARNMSG_OVER_RANGE           "Measurement overrange"
#define RSMXO_WARNMSG_DATA_NOT_AVAILABLE   "Measurement data not available"

#define RSMXO_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSMXO_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSMXO_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSMXO_ERROR_CODES_AND_MSGS \
    {RSMXO_WARN_MEASURE_UNCALIBRATED,  RSMXO_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSMXO_WARN_OVER_RANGE,            RSMXO_WARNMSG_OVER_RANGE},\
    {RSMXO_WARN_DATA_NOT_AVAILABLE,    RSMXO_WARNMSG_DATA_NOT_AVAILABLE},\
    {RSMXO_ERROR_MARKER_NOT_ENABLED,   RSMXO_ERRMSG_MARKER_NOT_ENABLED},\
    {RSMXO_ERROR_NOT_DELTA_MARKER,     RSMXO_ERRMSG_NOT_DELTA_MARKER},\
    {RSMXO_ERROR_NOT_DELTA_MARKER,     RSMXO_ERRMSG_NOT_DELTA_MARKER},\
    {RSMXO_ERROR_MAX_TIME_EXCEEDED,    RSMXO_ERRMSG_MAX_TIME_EXCEEDED}

     /****************************************************************************
      *---------------------------- End Include File ----------------------------*
      ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSMXO_HEADER */

